@@ -32,33 +32,30 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ICONFIGURE_H
 
 //
-//  Suported extensions
-//
-//  DESCRIPTION:
-//  Extensions in IFRIT must be associated with power-of-two ids, so that they can be ORed together.
+//  Supported extensions
 //
 #define IEXTENSION_NONE		0
-#define IEXTENSION_HART		1
-#define IEXTENSION_MV		2
-#define IEXTENSION_GADGET	4
+#define IEXTENSION_MV		0x80000000
+
+#include "iextensiondefines.h"
 
 //
 //  Supported shells
 //
 #define ISHELL_CL			1
-#define ISHELL_GG			0xFFFE
+#define ISHELL_GG			0xFFFFFFFE
 #define ISHELL_QT			2
 //#define ISHELL_FX	4
 
 //
 //  Multiple extensions can be included, they are not exclusive
 //
-#define IEXTENSION_INCLUDED(_Type_)  (IEXTENSION & _Type_)
+#define IEXTENSION_INCLUDED(_Type_)  ((IEXTENSION & _Type_) != 0)
 
 //
 //  Multiple shells can be included, they are not exclusive
 //
-#define ISHELL_INCLUDED(_Type_)  (ISHELL & _Type_)
+#define ISHELL_INCLUDED(_Type_)  ((ISHELL & _Type_) != 0)
 
 //
 //  ******************************************************************************
@@ -68,8 +65,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef I_EXTERNAL_CONFIGURATION
 #include "iconfiguresettings.ext.h"
 #else
-#define IEXTENSION	0xFFFF
-#define ISHELL		0xFFFF
+#define IEXTENSION	0xFFFFFFFF
+#define ISHELL		0xFFFFFFFF
 #endif
 //
 //  ******************************************************************************
@@ -88,6 +85,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Additional defines that control styles but not operations
 //
-#undef IFRIT_NO_CONSOLEIO
+//#undef I_NO_CONSOLEIO
+//#undef I_OFFSCREEN
 
 #endif // ICONFIGURE_H
