@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iAppendPolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkAppendPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iAppendPolyDataFilter);
+	IGENERICFILTER_DECLARE(iAppendPolyDataFilter,vtkAppendPolyData);
 
 protected:
 
