@@ -39,7 +39,7 @@ class iArray
 
 public:
 
-	iArray(const T &n, int inc = 10);
+	iArray(int inc = 10);
 	virtual ~iArray();
 
     T& operator[](int i);
@@ -63,9 +63,14 @@ protected:
 
 	void Extend(int len);
 
-	T mNull;
 	T* mArr;
-	int mNum, mLen, mInc;
+	int mNum, mLen;
+	const int mInc;
+
+private:
+
+	iArray(const iArray<T>&); // not implemented
+	void operator=(const iArray<T>&); // not implemented
 };
 
 
@@ -78,11 +83,16 @@ class iSearchableArray : public iArray<T>
 
 public:
 
-	iSearchableArray(const T &n, int inc = 10);
+	iSearchableArray(int inc = 10);
 
 	virtual int Find(const T &val) const;
 	void AddUnique(const T &val);
 	bool Remove(const T &val);
+
+private:
+
+	iSearchableArray(const iSearchableArray<T>&); // not implemented
+	void operator=(const iSearchableArray<T>&); // not implemented
 };
 
 
@@ -95,11 +105,16 @@ class iOrderedArray : public iSearchableArray<T>
 
 public:
 
-	iOrderedArray(const T &n, int inc = 10);
+	iOrderedArray(int inc = 10);
 
 	virtual int Find(const T &val) const;
 	virtual void Add(const T &val);
 	virtual bool Less(const T& v1, const T& v2) const;
+
+private:
+
+	iOrderedArray(const iOrderedArray<T>&); // not implemented
+	void operator=(const iOrderedArray<T>&); // not implemented
 };
 
 	
@@ -120,9 +135,14 @@ class iPointerArray : public iOrderedArray<T*>
 
 public:
 
-	iPointerArray(int inc = 10) : iOrderedArray<T*>((T*)0,inc){}
+	iPointerArray(int inc = 10) : iOrderedArray<T*>(inc){}
 
 	virtual bool Less(const T* &v1, const T* &v2) const;
+
+private:
+
+	iPointerArray(const iPointerArray<T>&); // not implemented
+	void operator=(const iPointerArray<T>&); // not implemented
 };
 
 
