@@ -36,11 +36,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //  iArray class
 //
 template<class T>
-iArray<T>::iArray(const T &n, int inc)
+iArray<T>::iArray(int inc) : mInc((inc<1) ? 1 : inc)
 {
-	this->mNull = n;
 	this->mNum = 0;
-	this->mInc = (inc<1) ? 1 : inc;
 	this->mLen = this->mInc;
 	this->mArr = new T[this->mLen]; IERROR_ASSERT(this->mArr);
 }
@@ -58,8 +56,8 @@ T& iArray<T>::operator[](int i)
 {
 	if(i>=0 && i<this->mNum) return this->mArr[i]; else
 	{
-		IERROR_FINISH("Accessing iArray outside of boundaries.");
-		return this->mNull;
+		IERROR_FATAL("Accessing iArray outside of boundaries.");
+		return this->mArr[0];
 	}
 }
 
@@ -67,7 +65,11 @@ T& iArray<T>::operator[](int i)
 template<class T>
 const T& iArray<T>::operator[](int i) const
 {
-	if(i>=0 && i<this->mNum) return this->mArr[i]; else return this->mNull;
+	if(i>=0 && i<this->mNum) return this->mArr[i]; else
+	{
+		IERROR_LOW("Accessing iArray outside of boundaries.");
+		return this->mArr[0];
+	}
 }
 
 
@@ -102,13 +104,12 @@ void iArray<T>::Remove(int n)
 {
 	if(n<0 || n>=this->mNum)
 	{
-		IERROR_FINISH("Accessing iArray outside of boundaries.");
+		IERROR_FATAL("Accessing iArray outside of boundaries.");
 	}
 
-	int i, m = this->mNum-1;
+	int i, m = --this->mNum;
 	T *arr = this->mArr;  // dereference for speed
 	for(i=n; i<m; i++) arr[i] = arr[i+1];
-	arr[--this->mNum] = this->mNull;
 }
 
 
@@ -117,8 +118,8 @@ T iArray<T>::RemoveLast()
 {
 	if(this->mNum == 0)
 	{
-		IERROR_FINISH("Accessing iArray outside of boundaries.");
-		return this->mNull;
+		IERROR_FATAL("Accessing iArray outside of boundaries.");
+		return this->mArr[0];
 	}
 
 	this->mNum--;
@@ -149,7 +150,7 @@ void iArray<T>::Resize(int n)
 //  iSearchableArray class
 //
 template<class T>
-iSearchableArray<T>::iSearchableArray(const T &n, int inc) : iArray<T>(n,inc)
+iSearchableArray<T>::iSearchableArray(int inc) : iArray<T>(inc)
 {
 }
 
@@ -188,7 +189,7 @@ bool iSearchableArray<T>::Remove(const T &val)
 //  iOrderedArray class
 //
 template<class T>
-iOrderedArray<T>::iOrderedArray(const T &n, int inc) : iSearchableArray<T>(n,inc)
+iOrderedArray<T>::iOrderedArray(int inc) : iSearchableArray<T>(inc)
 {
 }
 
