@@ -48,11 +48,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 iClipPlane* iClipPlane::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iClipPlane(vm);
 }
 
 
-iClipPlane::iClipPlane(iViewModule *vm) : iViewModuleComponent(vm)
+iClipPlane::iClipPlane(iViewModule *vm) : mViewModule(vm)
 {
 	int i, j;
 	//
