@@ -30,67 +30,71 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ICOLORBARS_H
 
 
-#include <vtkActor2D.h>
 #include "iobject.h"
-#include "ioverlaybase.h"
-#include "iviewmodulecomponent.h"
 
 
 #include "iarray.h"
 #include "iparameter.h"
 
-class iColorBarsLabel;
+class iColorBarActor;
+class iColorBarLabel;
+struct iColorBarItem;
 class iDataType;
 class iPalette;
-class iTextActor;
 
-class vtkRenderer;
-class vtkScalarBarActor;
+class vtkActor2D;
 
 
-class iColorBars: public vtkActor2D, public iObject, protected iOverlayBase, protected iViewModuleComponent
+struct iColorBarItem
+{
+	int Var;
+	int Palette;
+	int DataTypeId;
+	int Priority;
+	int Count;
+	bool operator<(const iColorBarItem &item) const;
+	bool operator==(const iColorBarItem &item) const;
+};
+
+
+class iColorBars: public iObject
 {
 	
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 	
-	IOBJECT_DECLARE_SELF(iColorBars,iObject);
-
-	static iColorBars* New(iViewModule *vm);
+	vtkTypeMacro(iColorBars,iObject);
+	static iColorBars* New(iViewModule *vm = 0);
 	static const iObjectType& Type();
 	
 	IOBJECT_DECLARE_GETSET1(Color,iColor);
 	//virtual void SetColor(iColor c);
 	//inline iColor GetColor() const { return mColor; }
 
-	IOBJECT_DECLARE_GETSET(SideOffset,mXOff[1],float);
+	IOBJECT_DECLARE_GETSET2(SideOffset,float);
 	//virtual void SetSideOffset(float v);
-	//inline float GetSideOffset() const { return mXOff[1]; }
+	//float GetSideOffset() const;
 
 	IOBJECT_DECLARE_GETSET1(Automatic,bool);
 	//virtual void SetAutomatic(bool);
 	//inline bool GetAutomatic() const { return mAutomatic; }
 
-	virtual void SetBar(int bar, int v, int id, int p); 
-	virtual void GetBar(int bar, int &v, int &id, int &p) const; 
+	void SetBar(int bar, int v, int id, int p); 
+	void GetBar(int bar, int &v, int &id, int &p) const; 
 	static const iObjectKey& KeyBarLeft();
 	static const iObjectKey& KeyBarRight();
 
-	virtual void SetFontScale(int s);
+	void SetFontType(int t);
+	int GetFontType() const;
 
-	virtual void SetFontType(int t);
-	inline int GetFontType() const { return mFontType; }
+	void ShowBar(int priority, int v, const iDataType &dt, int p, bool s);
 
-	virtual int RenderOverlay(vtkViewport*);
-	virtual int RenderOpaqueGeometry(vtkViewport*);
-	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
-	
-	virtual void ReleaseGraphicsResources(vtkWindow *win);
-
-	virtual void ShowBar(int priority, int v, const iDataType &dt, int p, bool s);
+	const iColorBarItem* GetItem(bool left);
+	vtkActor2D* GetActor(bool left) const;
 
 protected:
 	
-	iColorBars(iViewModule *vm);
 	virtual ~iColorBars();
 	
 	virtual void PackStateBody(iString &s) const;
@@ -98,43 +102,23 @@ protected:
 
 private:
 
-	struct QueueItem
-	{
-		int Var;
-		int Palette;
-		int DataTypeId;
-		int Priority;
-		int Count;
-		bool operator<(const QueueItem &item) const;
-		bool operator==(const QueueItem &item) const;
-	};
+	iColorBars(iViewModule *vm);
 
-	iOrderedArray<QueueItem>& Queue();
-
-	int mFontType;
-
-	bool mStarted, mAutomatic;
-	float mScale;
-
-	float mHeight, mWidth;
-	float mXOff[2], mYOff;
-	float mTextOff[2], mTitleOff[2];
-	int mJmax;
+	iOrderedArray<iColorBarItem>& Queue();
 
+	bool mAutomatic;
 	iColor mColor;
 
-	iOrderedArray<QueueItem> mAutomaticBars;
-	iOrderedArray<QueueItem> mManualBars;
+	iOrderedArray<iColorBarItem> mAutomaticBars;
+	iOrderedArray<iColorBarItem> mManualBars;
 
-	static const QueueItem NullQueueItem;
+	static const iColorBarItem NullItem;
 
-	vtkScalarBarActor *mBarActor[2];
-	iTextActor *mTitleActor[2];
-	iArray<iColorBarsLabel*> mLabels;
+	iColorBarActor *mActors[2];
 };
 
 
-inline iOrderedArray<iColorBars::QueueItem>& iColorBars::Queue()
+inline iOrderedArray<iColorBarItem>& iColorBars::Queue()
 {
 	return mAutomatic ? mAutomaticBars : mManualBars;
 }
