@@ -32,6 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ianimator.h"
 #include "icamera.h"
 #include "icolorbars.h"
+#include "icommoneventobservers.h"
 #include "icontrolscript.h"
 #include "icrosssectionviewsubject.h"
 #include "idata.h"
@@ -39,6 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatasubject.h"
 #include "ierror.h"
 #include "ieventobserver.h"
+#include "ierrorstatus.h"
 #include "iextensionfactory.h"
 #include "ifile.h"
 #include "iimagecomposer.h"
@@ -62,7 +64,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ivolumeviewsubject.h"
 
 #include <vtkCamera.h>
-#include <vtkCommand.h>
+#include <vtkDataObject.h>
+#include <vtkMapper.h>
 #include <vtkRenderer.h>
 #include <vtkRenderWindow.h>
 #include <vtkRenderWindowInteractor.h>
@@ -73,11 +76,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 #include "iviewfamilytemplate.h"
 
-//
-//  macros
-//
-#include "icontrolmodulemacro.h"
-
 
 using namespace iParameter;
 
@@ -114,22 +112,129 @@ namespace iControlModule_Private
 	iPalette* Palette_Starlight();
 	iPalette* Palette_3color();
 	iPalette* Palette_4color();
+
+	template<class Family>
+	bool SetCurrentObject(Family *fam, int obj)
+	{
+		if(obj>=0 && obj<=fam->GetMaxMemberIndex())
+		{
+			fam->SetCurrentMemberIndex(obj);
+			return true;
+		}
+		else return false;
+	}
+
+	template<class Family>
+	void ExecuteForObject(Family *fam, const iString &command, int objOption, bool &executeOk)
+	{
+		switch(objOption)
+		{
+		case _ObjectOptionOne:
+			{
+				fam->GetCurrentMember()->UnPackState(command);
+				executeOk = fam->GetCurrentMember()->UnPackedSomething();
+				break;
+			}
+		case _ObjectOptionAll:
+			{
+				int j;
+				for(j=0; j<=fam->GetMaxMemberIndex(); j++)
+				{
+					fam->GetMember(j)->UnPackState(command);
+					executeOk = executeOk || fam->GetMember(j)->UnPackedSomething();
+				}
+				break;
+			}
+		}
+	}
+
+	template<class Family>
+	bool CreateObject(Family *fam, iViewModule *module)
+	{
+		int	i = fam->CreateMember();
+		if(i == -1) return false;
+		fam->GetMember(i)->CopyState(fam->GetCurrentMember());
+		fam->Show(fam->IsVisible());
+		fam->SetCurrentMemberIndex(i);
+		module->ClearCache();
+		return true;
+	}
+
+	template<class Family>
+	bool DeleteObject(Family *fam, iViewModule *module, int obj)
+	{
+		if(obj == -1) obj = fam->GetCurrentMemberIndex();
+		if(!fam->DeleteMember(obj)) return false;
+		module->ClearCache();
+		return true;
+	}
+
+	template<class Family>
+	bool SaveObject(Family *fam, const iObjectType &type, iFile &F, const iString &prefix, int k)
+	{
+		int i;
+		iString ws, state;
+
+		for(i=0; i<=fam->GetMaxMemberIndex(); i++)
+		{
+			ws = prefix + type.FullName() + " " + iString::FromNumber(k) + " " + iString::FromNumber(i) + " ";
+			fam->GetMember(i)->PackCompleteState(state);
+			ws += state;
+			if(!F.WriteLine(ws)) return false;
+		}
+		return true;
+	}
+
+	bool Error(iFile &F)
+	{
+		F.Close();
+		return false;
+	}
 };
 
 
 using namespace iControlModule_Private;
 
 
+//
+//
+#define LOAD_OBJECT(_getfam_,_type_,_show_) \
+	if(ws == _type_.FullName()) \
+	{ \
+		k = line.Section(" ",1,1).ToInt(ok); \
+		if(!ok) return Error(F); \
+		if(k>=0 && k<nvm) \
+		{ \
+			iViewModule *vm = mViewModules->GetMember(k); \
+			i = line.Section(" ",2,2).ToInt(ok); \
+			if(!ok) return Error(F); \
+			while(i > vm->_getfam_->GetMaxMemberIndex()) if(vm->_getfam_->CreateMember()==-1) return Error(F); \
+			vm->_getfam_->GetMember(i)->UnPackCompleteState(line.Section(" ",3)); \
+			this->GetShell()->OnInitAtom(); \
+			if(_show_) \
+			{ \
+				vm->_getfam_->Show(_show_); \
+				this->GetShell()->OnLoadStateFileAtom(60+(20*(kk+1)/nvm)); \
+				k++; \
+			} \
+		} \
+	}
+
+
 //
 //  Helper class. Probably should not be here.
 //
-class iInteractorEventObserver : public vtkCommand, protected iControlModuleComponent
+class iInteractorEventObserver : public iEventObserver
 {
 
+	IPOINTER_AS_PART(ControlModule);
+
 public:
 	
-	static iInteractorEventObserver* New(iControlModule *cm)
+	vtkTypeMacro(iInteractorEventObserver,iEventObserver);
+	static iInteractorEventObserver* New(iControlModule *cm = 0)
 	{
+		IERROR_ASSERT(cm);
 		return new iInteractorEventObserver(cm);
 	}
 
@@ -138,7 +243,14 @@ public:
 		mActive = s;
 	}
 
-	virtual void Execute(vtkObject *caller, unsigned long event, void *callData)
+protected:
+
+	iInteractorEventObserver(iControlModule *cm) : iEventObserver(cm->GetShell()), mControlModule(cm)
+	{
+		mInUpdate = mActive = false;
+	}
+
+	virtual void ExecuteBody(vtkObject *caller, unsigned long event, void *callData)
 	{
 		if(!mActive || mInUpdate) return;
 
@@ -159,13 +271,6 @@ public:
 		}
 	}
 
-protected:
-
-	iInteractorEventObserver(iControlModule *cm) : iControlModuleComponent(cm)
-	{
-		mInUpdate = mActive = false;
-	}
-
 	bool mInUpdate, mActive;
 };
 
@@ -175,17 +280,17 @@ protected:
 //
 iControlModule* iControlModule::New(iShell *s)
 {
+	IERROR_ASSERT(s);
 	iControlModule *cm = new iControlModule(s);
 	if(cm != 0)
 	{
 		cm->FinishInitialization();
-		iExtensionFactory::InstallExtensions(cm);
 	}
 	return cm;
 }
 
 
-iControlModule::iControlModule(iShell *s) : iShellComponent(s), mPalList(0)
+iControlModule::iControlModule(iShell *s) : iObject("ControlModule"), mShell(s)
 {
 	mId = mIdCounter++;
 
@@ -194,8 +299,6 @@ iControlModule::iControlModule(iShell *s) : iShellComponent(s), mPalList(0)
 	mBlockBroadcasts = true;
 	mAutoRender = mSyncInteractors = mExecuteOk = false;
 
-	this->UpdateDataDir();
-
 	//
 	//  Palettes must be created before the ViewModule family is created, since they are used then
 	//
@@ -228,15 +331,14 @@ void iControlModule::FinishInitialization()
 	//
 	mControlScript = iControlScript::New(this);
 	//
+	//  Composer must be created before view modules
+	//
+	mComposer = iImageComposer::New(this); IERROR_ASSERT(mComposer);
+	//
 	//  ViewModule family must be created after ControlModule is fully created
 	//
 	mViewModules = iFamily<iViewModule,iControlModule>::New(this); IERROR_ASSERT(mViewModules);
 	//
-	//  Composer must be created after view modules
-	//
-	mComposer = iImageComposer::New(this,this->GetShell()); IERROR_ASSERT(mComposer);
-	mViewModules->GetMember(0)->SetImageComposer(mComposer);
-	//
 	//  Allow broadcasts
 	//
 	mBlockBroadcasts = false;
@@ -273,13 +375,8 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 	int j;
 	mExecuteOk = false;
 
-	if(option == 0)
-	{
-		//
-		//  Default options
-		//
-		option = _ObjectModeCurrent | _ModuleModeCurrent | _RenderModeAuto;
-	}
+	render = render || mAutoRender;
+
 	//
 	//  Is it a ControlModule command?
 	//
@@ -291,7 +388,7 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 		iObject::ReportMissingKeys(true);
 		mExecuteOk = true;
 
-		if(render || mAutoRender)
+		if(render)
 		{
 			for(j=0; j<=mViewModules->GetMaxMemberIndex(); j++) 
 			{
@@ -301,26 +398,29 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 		mInExecute = false;
 		return mExecuteOk;
 	}
+
 	//
 	//  Set modes
 	//
-	int objMode = option & _ObjectModeMask;
-	int modMode = option & _ModuleModeMask;
-	int renMode = option & _RenderModeMask;
+	int objOption = option & _ObjectOptionMask;
+	int modOption = option & _ModuleOptionMask;
+	int renOption = option & _RenderOptionMask;
 
-	if(objMode==_ObjectModeInvalid || modMode==_ModuleModeInvalid || renMode==_RenderModeInvalid)
+	//
+	//  Check that modes are valid
+	//
+	if(
+		(objOption!=_ObjectOptionOne && objOption!=_ObjectOptionAll) ||
+		(modOption!=_ModuleOptionOne && modOption!=_ModuleOptionAll && modOption!=_ModuleOptionClones) || 
+		(renOption!=_RenderOptionOne && renOption!=_RenderOptionAll && renOption!=_RenderOptionClones && renOption!=_RenderOptionAuto))
 	{
-		IERROR_REPORT("Invalid option.");
-		mExecuteOk = false;
-		mInExecute = false;
-		return mExecuteOk;
-	}
-
-	render = render || mAutoRender;
-
-	if(mod>=0 && mod<mViewModules->GetMaxMemberIndex())
-	{
-		renMode = _ModuleModeInvalid;
+		IERROR_LOW("Invalid option.");
+		//
+		//  Continue after an error with default ones
+		//
+		objOption = _ObjectOptionOne;
+		modOption = _ModuleOptionOne;
+		renOption = _RenderOptionAuto;
 	}
 
 	//
@@ -330,32 +430,28 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 
 	iObject::ReportMissingKeys(false); //commands are not complete states
 	//
-	//  Execute and Set renMode to prefered value if it is Set to Auto initially
+	//  Execute and Set renOption to prefered value if it is Set to Auto initially
 	//
+	if(mod == -1) mod = mViewModules->GetCurrentMemberIndex();
 	for(j=0; j<=mViewModules->GetMaxMemberIndex(); j++) 
 	{
-		switch(modMode)
+		switch(modOption)
 		{
-		case _ModuleModeCurrent:
+		case _ModuleOptionOne:
 			{
-				if(j == mViewModules->GetCurrentMemberIndex()) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objMode,renMode);
+				if(j == mod) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objOption,renOption);
 				break;
 			}
-		case _ModuleModeAll:
+		case _ModuleOptionAll:
 			{
-				if(renMode == _RenderModeAuto) renMode = _RenderModeAll;
-				this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objMode,renMode);
+				if(renOption == _RenderOptionAuto) renOption = _RenderOptionAll;
+				this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objOption,renOption);
 				break;
 			}
-		case _ModuleModeClones:
+		case _ModuleOptionClones:
 			{
-				if(renMode == _RenderModeAuto) renMode = _RenderModeClones;
-				if(r == mViewModules->GetMember(j)->GetReader()) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objMode,renMode);
-				break;
-			}
-		case _ModuleModeInvalid:
-			{
-				if(j == mod) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objMode,renMode);
+				if(renOption == _RenderOptionAuto) renOption = _RenderOptionClones;
+				if(r == mViewModules->GetMember(j)->GetReader()) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objOption,renOption);
 				break;
 			}
 		}
@@ -363,7 +459,7 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 
 	iObject::ReportMissingKeys(true);
 #ifdef I_CHECK1
-	if(renMode == _RenderModeAuto) IERROR_REPORT("Improper RenderMode.");
+	if(renOption == _RenderOptionAuto) IERROR_LOW("Improper RenderOption.");
 #endif
 
 	//
@@ -389,19 +485,19 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 	//
 	for(j=0; j<=mViewModules->GetMaxMemberIndex(); j++) 
 	{
-		switch(renMode)
+		switch(renOption)
 		{
-		case _RenderModeCurrent:
+		case _RenderOptionOne:
 			{
-				if(j == mViewModules->GetCurrentMemberIndex()) mViewModules->GetMember(j)->Render();
+				if(j == mod) mViewModules->GetMember(j)->Render();
 				break;
 			}
-		case _RenderModeAll:
+		case _RenderOptionAll:
 			{
 				mViewModules->GetMember(j)->Render();
 				break;
 			}
-		case _RenderModeClones:
+		case _RenderOptionClones:
 			{
 				if(r == mViewModules->GetMember(j)->GetReader()) mViewModules->GetMember(j)->Render();
 				break;
@@ -510,27 +606,26 @@ iViewSubject* iControlModule::FindViewSubject(const iObjectType &type, iViewModu
 }
 
 
-void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &command, bool /*render*/, int objMode, int &renMode)
+void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &command, bool /*render*/, int objOption, int &renOption)
 {
-	int j;
-	
 	const iObjectType *ptype = iObjectTypeRegistry::FindType(command.Section(iObjectKey::PrefixSeparator(),0,0));
 	if(ptype == 0)
 	{
-		if(renMode == _RenderModeAuto) renMode = _RenderModeCurrent;
+		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
 		return;
 	}
 
 	iObject *object = this->FindSingleObject(*ptype,module);
 	if(object != 0)
 	{
+		this->GetErrorStatus()->Monitor(object->GetErrorStatus());
 		object->UnPackState(command);
 		mExecuteOk = object->UnPackedSomething();
-		if(renMode == _RenderModeAuto) renMode = _RenderModeCurrent;
+		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
 
 		if(ptype->IsMatch(iDataReader::Type()) || ptype->IsMatch(iDataSubject::Type()))
 		{
-			if(renMode == _RenderModeAuto) renMode = _RenderModeClones;
+			if(renOption == _RenderOptionAuto) renOption = _RenderOptionClones;
 		}
 
 		return;
@@ -539,27 +634,27 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 	if(ptype->IsMatch(iMarker::Type()))
 	{
 		iMarkerFamily *fam = module->GetMarkerFamily();
-		ICONTROLMODULE_EXECUTE_FOR_OBJECT(fam,Member);
+		ExecuteForObject(fam,command,objOption,mExecuteOk);
 		if(mExecuteOk) module->BuildMarkerLegend(module->GetMarkerFamily()->GetCurrentMemberIndex());
-		if(renMode == _RenderModeAuto) renMode = _RenderModeCurrent;
+		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
 		return;
 	}
 
 	if(ptype->IsMatch(iParticleGroup::Type()))
 	{
 		iParticlesViewSubject *fam = module->GetParticlesViewSubject();
-		ICONTROLMODULE_EXECUTE_FOR_OBJECT(fam,Group);
-		if(renMode == _RenderModeAuto) renMode = _RenderModeCurrent;
+		ExecuteForObject(fam,command,objOption,mExecuteOk);
+		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
 		return;
 	}
 
 	iViewObjectFamily *fam = this->FindViewObjectFamily(*ptype,module);
 	if(fam != 0)
 	{
-		ICONTROLMODULE_EXECUTE_FOR_OBJECT(fam,Member);
+		ExecuteForObject(fam,command,objOption,mExecuteOk);
 	}
 
-	if(renMode == _RenderModeAuto) renMode = _RenderModeCurrent;
+	if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
 }
 
 
@@ -576,7 +671,6 @@ bool iControlModule::CreateObject(const iObjectType &type, bool render, int mod,
 		int i = mViewModules->CreateMember(); 
 		if(i != -1) 
 		{
-			mViewModules->GetMember(i)->SetImageComposer(mComposer);
 			//
 			//  Set the type of the instance created
 			//
@@ -607,11 +701,13 @@ bool iControlModule::CreateObject(const iObjectType &type, bool render, int mod,
 		if(fam->GetMaxMemberIndex()==0 && !fam->IsVisible())
 		{
 			fam->Show(true);
+			module->ClearCache();
 		}
 		else
 		{
-			ICONTROLMODULE_CREATE_OBJECT(fam);
+			if(!iControlModule_Private::CreateObject(fam,module)) return false;
 		}
+		fam->GetCurrentMember()->SetPosition(_LocationFocalPoint);
 		module->BuildMarkerLegend();
 		if(render) module->Render();
 		return true;
@@ -629,12 +725,11 @@ bool iControlModule::CreateObject(const iObjectType &type, bool render, int mod,
 	iViewObjectFamily *fam = this->FindViewObjectFamily(type,module);
 	if(fam!=0 && !fam->IsSingleInstance())
 	{
-		ICONTROLMODULE_CREATE_OBJECT(fam);
-		return true;
+		return iControlModule_Private::CreateObject(fam,module);
 	}
 
 #ifdef I_CHECK1
-	IERROR_REPORT("This object cannot be created.");
+	IERROR_LOW("This object cannot be created.");
 #endif
 	return false;
 }
@@ -693,10 +788,11 @@ bool iControlModule::DeleteObject(const iObjectType &type, bool render, int mod,
 		if(fam->GetMaxMemberIndex()==0 && fam->IsVisible())
 		{
 			fam->Show(false);
+			module->ClearCache();
 		}
 		else
 		{
-			ICONTROLMODULE_DELETE_OBJECT(fam);
+			iControlModule_Private::DeleteObject(fam,module,obj);
 		}
 		module->BuildMarkerLegend();
 		if(render) module->Render();
@@ -715,12 +811,12 @@ bool iControlModule::DeleteObject(const iObjectType &type, bool render, int mod,
 	iViewObjectFamily *fam = this->FindViewObjectFamily(type,module);
 	if(fam!=0 && !fam->IsSingleInstance())
 	{
-		ICONTROLMODULE_DELETE_OBJECT(fam);
+		iControlModule_Private::DeleteObject(fam,module,obj);
 		return true;
 	}
 
 #ifdef I_CHECK1
-	IERROR_REPORT("This object cannot be deleted.");
+	IERROR_LOW("This object cannot be deleted.");
 #endif
 	return false;
 }
@@ -741,7 +837,7 @@ bool iControlModule::SetCurrentViewModuleIndex(int mod)
 }
 
 
-void iControlModule::Show(const iObjectType &type, bool show, int mod)
+void iControlModule::Show(const iObjectType &type, bool show, bool render, int mod)
 {
 	if(mod == -1) mod = mViewModules->GetCurrentMemberIndex();
 	iViewModule *module = mViewModules->GetMember(mod);
@@ -750,7 +846,7 @@ void iControlModule::Show(const iObjectType &type, bool show, int mod)
 	if(type.IsMatch(iMarker::Type()))
 	{
 		module->GetMarkerFamily()->Show(show);
-		module->Render();
+		if(render || mAutoRender) module->Render();
 		return;
 	}
 
@@ -758,7 +854,7 @@ void iControlModule::Show(const iObjectType &type, bool show, int mod)
 	if(fam != 0)
 	{
 		fam->Show(show);
-		module->Render();
+		if(render || mAutoRender) module->Render();
 		return;
 	}
 }
@@ -811,11 +907,11 @@ void iControlModule::FlyTo(const iObjectType &type, float time, int mod, int obj
 		if(type == iPicker::Type()) pos = module->GetPicker()->GetPosition(); else return;
 	}
 
-	this->FlyTo(pos,time,mod,obj);
+	this->FlyTo(pos,time,mod);
 }
 
 
-void iControlModule::FlyTo(const double *pos, float time, int mod, int /*obj*/) const
+void iControlModule::FlyTo(const double *pos, float time, int mod) const
 {
 	if(mod == -1) mod = mViewModules->GetCurrentMemberIndex();
 	iViewModule *module = mViewModules->GetMember(mod);
@@ -851,7 +947,7 @@ void iControlModule::FlyTo(const double *pos, float time, int mod, int /*obj*/)
 }
 
 
-void iControlModule::ExtendableObjectPackStateBody(iString &s) const
+void iControlModule::PackStateBody(iString &s) const
 {
 	this->PackValue(s,KeyAutoRender(),mAutoRender);
 	this->PackValue(s,KeySynchronizeInteractors(),mSyncInteractors);
@@ -859,7 +955,7 @@ void iControlModule::ExtendableObjectPackStateBody(iString &s) const
 }
 
 
-void iControlModule::ExtendableObjectUnPackStateBody(const iString &s)
+void iControlModule::UnPackStateBody(const iString &s)
 {
 	int i; bool b;
 
@@ -989,10 +1085,17 @@ bool iControlModule::QueryValueAsString(const iObjectKey &key, iString &val, int
 	{
 		iString ws;
 		o->PackState(ws);
-		int index, ind = FindUnPackKey(ws,key,index);
+		int index, ind = key.FindInString(ws,index);
 		if(ind >=0)
 		{
-			val = ws.Part(ind).Section(key.FieldSeparator(),1,1);
+			if(index < 0)
+			{
+				val = key.FieldSeparator() + ws.Part(ind).Section(key.FieldSeparator(),1).Section(key.FieldSeparator()+key.Delimiter(),0,0) + key.FieldSeparator();
+			}
+			else
+			{
+				val = ws.Part(ind).Section(key.FieldSeparator(),index+1,index+1);
+			}
 			return true;
 		}
 		else return false;
@@ -1073,80 +1176,6 @@ ICONTROLMODULE_PACKCOMMAND_DEFINITION(iColor,iColor);
 ICONTROLMODULE_PACKCOMMAND_DEFINITION(iString,const iString&);
 
 
-//
-//  Environment querying
-//
-const iString& iControlModule::GetEnvironment(int key) const
-{
-	int i;
-
-	switch(key)
-	{
-	case _EnvironmentScalarFieldData:
-		{
-			return mEnvScalarFieldDataDir;
-		}
-	case _EnvironmentParticleSetData:
-		{
-			return mEnvParticleSetDataDir;
-		}
-	case _EnvironmentVectorFieldData:
-		{
-			return mEnvVectorFieldDataDir;
-		}
-	case _EnvironmentTensorFieldData:
-		{
-			return mEnvTensorFieldDataDir;
-		}
-	}
-
-	for(i=0; i<mExtensions.Size(); i++)
-	{
-		const iString &s(iControlModuleExtension::RequiredCast(mExtensions[i])->GetEnvironment(key));
-		if(!s.IsEmpty()) return s;
-	}
-
-	return this->GetShell()->GetEnvironment(key);
-}
-
-
-iString iControlModule::GetFileName(int key, const iString &fname) const
-{
-	return this->GetEnvironment(key) + fname;
-}
-
-
-void iControlModule::UpdateDataDir()
-{
-	int i;
-	char *e;
-
-	const iString &d(this->GetShell()->GetEnvironment(_EnvironmentData));
-
-    mEnvScalarFieldDataDir = d;
-    mEnvParticleSetDataDir = d;
-    mEnvVectorFieldDataDir = d;
-    mEnvTensorFieldDataDir = d;
-
-#ifdef BACKWARD_COMPATIBLE
-    e = getenv("IFRIT_MESH_DATA_DIR");          if(e != 0) mEnvScalarFieldDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-    e = getenv("IFRIT_PARTICLE_DATA_DIR");      if(e != 0) mEnvParticleSetDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-    e = getenv("IFRIT_VECTOR_DATA_DIR");        if(e != 0) mEnvVectorFieldDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-    e = getenv("IFRIT_TENSOR_DATA_DIR");        if(e != 0) mEnvTensorFieldDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-#endif
-
-    e = getenv("IFRIT_SCALAR_FIELD_DATA_DIR");  if(e != 0) mEnvScalarFieldDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-    e = getenv("IFRIT_PARTICLE_SET_DATA_DIR");  if(e != 0) mEnvParticleSetDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-    e = getenv("IFRIT_VECTOR_FIELD_DATA_DIR");  if(e != 0) mEnvVectorFieldDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-    e = getenv("IFRIT_TENSOR_FIELD_DATA_DIR");  if(e != 0) mEnvTensorFieldDataDir = iString(e) + this->GetShell()->GetDirSeparator();
-
-	for(i=0; i<mExtensions.Size(); i++)
-	{
-		((iControlModuleExtension *)mExtensions[i])->UpdateDataDir();
-	}
-}
-
-
 //
 // Palette manipulation
 //
@@ -1201,20 +1230,24 @@ bool iControlModule::SaveStateToFile(const iString &filename) const
 	iFile F(filename);
 	
 	if(!F.Open(iFile::_Write,iFile::_Text)) return false;
+	
+	this->GetShell()->OnLoadStateFileAtom(0);
+
 	//
 	//  Compatibility mode
 	//
-	if(!F.WriteLine("CompatibilityMode "+iString::FromNumber(COMPATIBILITY_MODE))) { F.Close(); return false; }
+	if(!F.WriteLine("CompatibilityMode "+iString::FromNumber(COMPATIBILITY_MODE))) return Error(F);
 	//
 	//  Save the state of this ControlModule
 	//
 	this->PackCompleteState(state);
 	ws = prefix + iControlModule::Type().FullName() + " " + state;
-	if(!F.WriteLine(ws)) { F.Close(); return false; }
+	if(!F.WriteLine(ws)) return Error(F);
 	//
 	//  Save ViewModules with their window geometries, animators, data readers, limits,
 	//  particle splitters, and all view objects
 	//
+	this->GetShell()->OnLoadStateFileAtom(5);
 	for(k=0; k<=mViewModules->GetMaxMemberIndex(); k++) 
 	{
 		//
@@ -1226,61 +1259,73 @@ bool iControlModule::SaveStateToFile(const iString &filename) const
 		//
 		mViewModules->GetMember(k)->PackCompleteState(state);
 		ws += state;
-		if(!F.WriteLine(ws)) { F.Close(); return false; }
+		if(!F.WriteLine(ws)) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+5)/(mViewModules->GetMaxMemberIndex()+1));
 		//
 		//  Animator
 		//
 		ws = prefix + iAnimator::Type().FullName() + " " + iString::FromNumber(k) + " ";
 		mViewModules->GetMember(k)->GetAnimator()->PackCompleteState(state);
 		ws += state;
-		if(!F.WriteLine(ws)) { F.Close(); return false; }
+		if(!F.WriteLine(ws)) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+10)/(mViewModules->GetMaxMemberIndex()+1));
 		//
 		//  Camera
 		//
 		ws = prefix + iCamera::Type().FullName() + " " + iString::FromNumber(k) + " ";
 		mViewModules->GetMember(k)->GetRenderTool()->GetCamera()->PackCompleteState(state);
 		ws += state;
-		if(!F.WriteLine(ws)) { F.Close(); return false; }
+		if(!F.WriteLine(ws)) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+15)/(mViewModules->GetMaxMemberIndex()+1));
 		//
 		//  Color Bars
 		//
 		ws = prefix + iColorBars::Type().FullName() + " " + iString::FromNumber(k) + " ";
 		mViewModules->GetMember(k)->GetColorBars()->PackCompleteState(state);
 		ws += state;
-		if(!F.WriteLine(ws)) { F.Close(); return false; }
+		if(!F.WriteLine(ws)) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+20)/(mViewModules->GetMaxMemberIndex()+1));
 		//
 		//  Data reader
 		//
 		ws = prefix + iDataReader::Type().FullName() + " " + iString::FromNumber(k) + " ";
 		mViewModules->GetMember(k)->GetReader()->PackCompleteState(state);
 		ws += state;
-		if(!F.WriteLine(ws)) { F.Close(); return false; }
+		if(!F.WriteLine(ws)) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+25)/(mViewModules->GetMaxMemberIndex()+1));
 		//
 		//  Picker
 		//
 		ws = prefix + iPicker::Type().FullName() + " " + iString::FromNumber(k) + " ";
 		mViewModules->GetMember(k)->GetPicker()->PackCompleteState(state);
 		ws += state;
-		if(!F.WriteLine(ws)) { F.Close(); return false; }
+		if(!F.WriteLine(ws)) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+30)/(mViewModules->GetMaxMemberIndex()+1));
 		//
 		//  Save view objects
 		//
-		j = 0;
-		while((fam = mViewModules->GetMember(k)->GetViewObjectFamily(j++)) != 0)
+		for(j=0; j<mViewModules->GetMember(k)->GetNumberOfViewObjectFamilies(); j++)
 		{
-			ICONTROLMODULE_SAVE_OBJECT(fam,fam->GetParent()->GetObjectType());
+			fam = mViewModules->GetMember(k)->GetViewObjectFamily(j); 
+			if(!SaveObject(fam,fam->GetParent()->GetObjectType(),F,prefix,k)) return Error(F);
+			this->GetShell()->OnLoadStateFileAtom(5+(75*k+30+(40*(j+1))/mViewModules->GetMember(k)->GetNumberOfViewObjectFamilies())/(mViewModules->GetMaxMemberIndex()+1));
 		}
 		//
 		//  Don't save single invisible marker
 		//
-		if(mViewModules->GetMember(k)->GetMarkerFamily()->GetMaxMemberIndex()>0 || mViewModules->GetMember(k)->GetMarkerFamily()->GetMember(0)->IsVisible()) ICONTROLMODULE_SAVE_OBJECT(mViewModules->GetMember(k)->GetMarkerFamily(),iMarker::Type());
+		if(mViewModules->GetMember(k)->GetMarkerFamily()->GetMaxMemberIndex()>0 || mViewModules->GetMember(k)->GetMarkerFamily()->GetMember(0)->IsVisible())
+		{
+			if(!SaveObject(mViewModules->GetMember(k)->GetMarkerFamily(),iMarker::Type(),F,prefix,k)) return Error(F);
+		}
+		this->GetShell()->OnLoadStateFileAtom(5+(75*k+75)/(mViewModules->GetMaxMemberIndex()+1));
 	}
 	//
 	//  Save the state of ImageComposer
 	//
 	mComposer->PackCompleteState(state);
 	ws = prefix + iImageComposer::Type().FullName() + " " + state;
-	if(!F.WriteLine(ws)) { F.Close(); return false; }
+	if(!F.WriteLine(ws)) return Error(F);
+	this->GetShell()->OnLoadStateFileAtom(85);
 	//
 	//  Save the palettes
 	//
@@ -1295,8 +1340,12 @@ bool iControlModule::SaveStateToFile(const iString &filename) const
 		}
 	}
 	
+	this->GetShell()->OnLoadStateFileAtom(90);
+
 	bool ret = this->GetShell()->SaveShellStateToFile(F);
 
+	this->GetShell()->OnLoadStateFileAtom(100);
+
 	F.Close();	
 	return ret;
 }
@@ -1305,7 +1354,7 @@ bool iControlModule::SaveStateToFile(const iString &filename) const
 bool iControlModule::LoadStateFromFile(const iString &filename)
 {
 	bool ok;
-	int k, joff, i, j, i1, i2;
+	int k, i, j, i1, i2;
 	int CompatibilityMode = 0;
 	iViewObjectFamily *fam;
 	iString line, ws;
@@ -1327,21 +1376,22 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 		if(ws == "CompatibilityMode")
 		{
 			i = line.Section(" ",1,1).ToInt(ok);
-			if(!ok || i<10 || i>COMPATIBILITY_MODE) { F.Close(); return false; }
+			if(!ok || i<10 || i>COMPATIBILITY_MODE) return Error(F);
 			CompatibilityMode = i;
 			break;
 		}
 
 		if(ws == iControlModule::Type().FullName()) 
 		{
-			joff = 1; 
-			ICONTROLMODULE_UNPACK_STATE(this);
+			this->UnPackCompleteState(line.Section(" ",1));
+			this->GetShell()->OnInitAtom();
 		}
 	}
+	this->GetShell()->OnLoadStateFileAtom(5);
 	//
 	// ***************** Pass 1 ****************************
 	//
-	//  Count the number of view modules and create them with default Settings. 
+	//  Count the number of view modules.
 	//
 	F.Rewind();
 	int nvm = 0, kvmMax = 0;
@@ -1353,29 +1403,40 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 		if(ws == iViewModule::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k > kvmMax) kvmMax = k;
-			if(nvm > 0) mViewModules->CreateMember();
 			nvm++;
 		}
 	}
 	
-	if(kvmMax+1 != nvm) { F.Close(); return false; }
+	if(kvmMax+1 != nvm) return Error(F);
+	//
+	//  Create missing view modules, destroy extra ones.
+	//
+	while(mViewModules->GetMaxMemberIndex() > kvmMax)
+	{
+		if(!mViewModules->DeleteMember(mViewModules->GetMaxMemberIndex())) return Error(F);
+	}
+	this->GetShell()->OnLoadStateFileAtom(10);
+
+	while(mViewModules->GetMaxMemberIndex() < kvmMax)
+	{
+		if(mViewModules->CreateMember() == -1) return Error(F);
+		this->GetShell()->OnLoadStateFileAtom(10+(30*(mViewModules->GetMaxMemberIndex()+1)/nvm));
+	}
 	//
 	//  set all window numbers
 	//
-	if(nvm > 1)
+	for(k=0; k<nvm; k++)
 	{
-		for(k=0; k<nvm; k++)
-		{
-			mViewModules->GetMember(k)->UpdateWindowNumber();
-		}
+		mViewModules->GetMember(k)->UpdateWindowNumber();
 	}
 	//
 	// ***************** Pass 2 ****************************
 	//
 	//  Restore view modules
 	//
+	int kk = 0;
 	F.Rewind();
 	while(F.ReadLine(line)) 
 	{
@@ -1385,30 +1446,34 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 		if(ws == iViewModule::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k>=0 && k<nvm)
 			{		
 				//
 				//  Visual module position
 				//
 				i1 = line.Section(" ",2,2).ToInt(ok);
-				if(!ok) { F.Close(); return false; }
+				if(!ok) return Error(F);
 				i2 = line.Section(" ",3,3).ToInt(ok);
-				if(!ok) { F.Close(); return false; }
+				if(!ok) return Error(F);
 				mViewModules->GetMember(k)->GetRenderWindow()->SetPosition(i1,i2);
 				//
-				//  Visual module parameters
+				//  View module parameters
 				//
-				joff = 4;
-				ICONTROLMODULE_UNPACK_STATE(mViewModules->GetMember(k));
+				mViewModules->GetMember(k)->UnPackCompleteState(line.Section(" ",4));
+				this->GetShell()->OnInitAtom();
+				this->GetShell()->OnLoadStateFileAtom(40+(10*(kk+1)/nvm));
+				kk++;
 			}
 		}
 	}
+	this->GetShell()->OnLoadStateFileAtom(50);
 	//	
 	// ***************** Pass 3 ****************************
 	//
-	//  Restore animators, color bars, data reader, and limits
+	//  Restore animators, cameras, color bars, data readers, and pickers
 	//
+	kk = 0;
 	F.Rewind();
 	while(F.ReadLine(line)) 
 	{
@@ -1418,63 +1483,66 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 		if(ws == iAnimator::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k>=0 && k<nvm)
 			{		
-				joff = 2; 
-				ICONTROLMODULE_UNPACK_STATE(mViewModules->GetMember(k)->GetAnimator());
+				mViewModules->GetMember(k)->GetAnimator()->UnPackCompleteState(line.Section(" ",2));
+				this->GetShell()->OnInitAtom();
 			}
 		}		
 	
 		if(ws == iCamera::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k>=0 && k<nvm)
 			{		
-				joff = 2; 
-				ICONTROLMODULE_UNPACK_STATE(mViewModules->GetMember(k)->GetRenderTool()->GetCamera());
+				mViewModules->GetMember(k)->GetRenderTool()->GetCamera()->UnPackCompleteState(line.Section(" ",2));
+				this->GetShell()->OnInitAtom();
 			}
 		}		
 		
 		if(ws == iColorBars::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k>=0 && k<nvm)
 			{		
-				joff = 2; 
-				ICONTROLMODULE_UNPACK_STATE(mViewModules->GetMember(k)->GetColorBars());
+				mViewModules->GetMember(k)->GetColorBars()->UnPackCompleteState(line.Section(" ",2));
+				this->GetShell()->OnInitAtom();
 			}
 		}		
 		
 		if(ws == iDataReader::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k>=0 && k<nvm)
 			{		
-				joff = 2; 
-				ICONTROLMODULE_UNPACK_STATE(mViewModules->GetMember(k)->GetReader());
+				mViewModules->GetMember(k)->GetReader()->UnPackCompleteState(line.Section(" ",2));
+				this->GetShell()->OnInitAtom();
 			}
 		}		
 
 		if(ws == iPicker::Type().FullName()) 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			if(k>=0 && k<nvm)
 			{		
-				joff = 2; 
-				ICONTROLMODULE_UNPACK_STATE(mViewModules->GetMember(k)->GetPicker());
+				mViewModules->GetMember(k)->GetPicker()->UnPackCompleteState(line.Section(" ",2));
+				this->GetShell()->OnInitAtom();
+				this->GetShell()->OnLoadStateFileAtom(50+(10*(kk+1)/nvm));
 			}
 		}		
 	}
+	this->GetShell()->OnLoadStateFileAtom(60);
 	//	
 	// ***************** Pass 4 ****************************
 	//
 	//  Restore view objects, palettes, and the image composer
 	//
+	kk = 0;
 	F.Rewind();
 	while(F.ReadLine(line)) 
 	{
@@ -1484,16 +1552,16 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 		j = 0;
 		while((fam = mViewModules->GetMember(0)->GetViewObjectFamily(j)) != 0)
 		{
-			ICONTROLMODULE_LOAD_OBJECT(GetViewObjectFamily(j),fam->GetParent()->GetObjectType(),false);
+			LOAD_OBJECT(GetViewObjectFamily(j),fam->GetParent()->GetObjectType(),false);
 			j++;
 		}
 
-		ICONTROLMODULE_LOAD_OBJECT(GetMarkerFamily(),iMarker::Type(),true);
+		LOAD_OBJECT(GetMarkerFamily(),iMarker::Type(),true);
 		
 		if(ws == "Palette") 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
-			if(!ok) { F.Close(); return false; }
+			if(!ok) return Error(F);
 			ok = true;
 			if(k<0 || k>=100000) ok = false;
 	
@@ -1509,17 +1577,19 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 			if(ok)
 			{
 				ws = line.Section(" ",2);
-				if(!this->UnPackValuePalette(ws,mPalList[k])) { F.Close(); return false; }
+				if(!this->UnPackValuePalette(ws,mPalList[k])) return Error(F);
 			}
 		}		
 
 		if(ws == iImageComposer::Type().FullName()) 
 		{
-			joff = 1; 
-			ICONTROLMODULE_UNPACK_STATE(mComposer);
+			mComposer->UnPackCompleteState(line.Section(" ",1));
+			this->GetShell()->OnInitAtom();
 		}
 	}
 
+	this->GetShell()->OnLoadStateFileAtom(80);
+
 	for(k=0; k<=mViewModules->GetMaxMemberIndex(); k++) 
 	{
 		j = 0;
@@ -1529,8 +1599,12 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 		}
 	}
 
+	this->GetShell()->OnLoadStateFileAtom(90);
+
 	bool ret = this->GetShell()->LoadShellStateFromFile(F);
 
+	this->GetShell()->OnLoadStateFileAtom(100);
+
 	F.Close();
 	return ret;
 }
@@ -1591,7 +1665,7 @@ bool iControlModule::UnPackValuePalette(const iString &s, iPalette *p)
 }
 
 
-vtkCommand* iControlModule::GetInteractorObserver() const
+iEventObserver* iControlModule::GetInteractorObserver() const
 {
 	return mInteractorObserver;
 }
@@ -1667,6 +1741,9 @@ void iControlModule::SetSynchronizeInteractors(bool s)
 void iControlModule::SetOptimizationMode(int m)
 {
 	iDataConsumer::SetGlobalOptimizationMode(m);
+	vtkMapper::SetGlobalImmediateModeRendering((m==_DataConsumerOptimizeForMemory)?1:0);
+	vtkDataObject::SetGlobalReleaseDataFlag((m==_DataConsumerOptimizeForMemory)?1:0);
+
 	this->ClearCache();
 	//
 	//  We need to reset everything
@@ -2054,13 +2131,3 @@ namespace iControlModule_Private
 	}
 };
 
-
-//
-//  Helper class
-//
-IOBJECTEXTENSION_DEFINE_ABSTRACT(iControlModule);
-
-void iControlModuleExtension::Define()
-{
-}
-
