@@ -30,20 +30,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ICONTROLMODULE_H
 
 
-#include "iextendableobject.h"
-#include "ishellcomponent.h"
-#include "ideletable.h"
+#include "iobject.h"
 
 
 #include "iarray.h"
 #include "iimage.h"
 #include "iparameter.h"
 
+#include "ipointermacro.h"
 
 class iAnimatorScript;
 class iControlScript;
 class iDataType;
 class iDataSubject;
+class iEventObserver;
 class iFile;
 template<class O, class C>class iFamily;
 class iFunctionMapping;
@@ -63,8 +63,6 @@ class iViewObject;
 class iViewObjectFamily;
 class iViewSubject;
 
-class vtkCommand;
-
 #define ICONTROLMODULE_QUERYVALUE_DECLARATION(_type_) \
 	bool QueryValue(const iObjectKey &key, _type_ *val, int n, int mod = -1, int obj = -1); \
 	bool QueryValue(const iObjectKey &key, int index, _type_ &val, int n, int mod = -1, int obj = -1); \
@@ -76,16 +74,17 @@ class vtkCommand;
 	void PackCommand(iString &s, const iObjectKey &key, int index, _type2_ val) const;
 
 
-class iControlModule : public iExtendableObject, public iShellComponent, public iDeletable
+class iControlModule : public iObject
 {
 
 	friend class iExtensionFactory;
 
+	IPOINTER_AS_PART(Shell);
+
 public:
 
-	IOBJECT_DECLARE_SELF(iControlModule,iExtendableObject);
-
-	static iControlModule* New(iShell *s);
+	vtkTypeMacro(iControlModule,iObject);
+	static iControlModule* New(iShell *s = 0);
 	static const iObjectType& Type();
 		
 	IOBJECT_DECLARE_GETSET1(AutoRender,bool);
@@ -112,12 +111,12 @@ public:
 	//
 	//  Execute a packed command
 	//
-	bool Execute(const iString &command, bool render, int option = 0, int mod = -1);
+	bool Execute(const iString &command, bool render, int option = iParameter::_DefaultOption, int mod = -1);
 	
 	//
 	//  A simple wrapper
 	//
-	inline void Render(int renMode = iParameter::_RenderModeAuto) { this->Execute("",true, iParameter::_ObjectModeCurrent | iParameter::_ModuleModeCurrent | renMode); }
+	inline void Render(int renMode = iParameter::_RenderOptionAuto) { this->Execute("",true, iParameter::_ObjectOptionOne | iParameter::_ModuleOptionOne | renMode); }
 	
 	//
 	//  Manipulating objects
@@ -130,7 +129,7 @@ public:
 
 //	virtual bool SetCurrentDataType(const iDataType &type, int mod = -1);
 
-	virtual void Show(const iObjectType &type, bool show, int mod = -1);
+	virtual void Show(const iObjectType &type, bool show, bool render, int mod = -1);
 
 	//
 	//  Get the value corresponding to the key - shortcuts for Getting and unpacking the state
@@ -169,7 +168,7 @@ public:
 	//  Additional commands
 	//
 	void FlyTo(const iObjectType &type, float time, int mod = -1, int obj = -1) const;
-	void FlyTo(const double *pos, float time, int mod = -1, int obj = -1) const;
+	void FlyTo(const double *pos, float time, int mod = -1) const;
 
 	//
 	//  mod = -2: sum up all view modules
@@ -178,12 +177,6 @@ public:
 	float GetUpdateTime(int mod = -1) const;
 	float GetMemorySize(int mod = -2) const;
 
-	//
-	//  Environment & output
-	//
-	virtual const iString& GetEnvironment(int key) const;
-	virtual iString GetFileName(int key, const iString &fname) const;
-	
 	//
 	//  Palette interface (cannot remove palettes since there is no elegant way to
 	//  notify view objects that their palettes changed)
@@ -211,27 +204,29 @@ public:
 	inline iImageComposer* GetImageComposer() const { return mComposer; }
 	inline iControlScript* GetControlScript() const { return mControlScript; }
 	inline iParallelManager* GetParallelManager() const { return mParallelManager; } 
-	vtkCommand* GetInteractorObserver() const;
+	iEventObserver* GetInteractorObserver() const;
 
 protected:
 
-    iControlModule(iShell *s);
 	virtual ~iControlModule();
+
+	virtual void PackStateBody(iString &s) const;
+	virtual void UnPackStateBody(const iString &s);
+
+private:
+
+    iControlModule(iShell *s);
 	void FinishInitialization();
 
-	virtual void ExtendableObjectPackStateBody(iString &s) const;
-	virtual void ExtendableObjectUnPackStateBody(const iString &s);
-
-	virtual void UpdateDataDir();
-	virtual void ExecuteForViewModule(iViewModule *module, const iString &command, bool render, int objMode, int &renMode);
-	virtual iObject* FindSingleObject(const iObjectType &type, iViewModule *module);
+	void ExecuteForViewModule(iViewModule *module, const iString &command, bool render, int objMode, int &renMode);
+	iObject* FindSingleObject(const iObjectType &type, iViewModule *module);
 
 	iObject* FindObject(const iObjectKey &key, int mod = -1, int obj = -1);
 	iObject* FindObject(const iObjectType &type, int mod = -1, int obj = -1);
 	iViewSubject* FindViewSubject(const iObjectType &type, iViewModule *module, int obj = -1) const;
 	iViewObjectFamily* FindViewObjectFamily(const iObjectType &type, iViewModule *module) const;
 
-	virtual void CreateDefaultPalettes();
+	void CreateDefaultPalettes();
 
 	iFamily<iViewModule,iControlModule> *mViewModules;
 	bool mAutoRender, mSyncInteractors, mBlockBroadcasts, mExecuteOk, mInExecute;
@@ -255,14 +250,6 @@ protected:
 	iParallelUpdateEventObserver *mParallelObserver;
 	iParallelManager *mParallelManager;
 
-	//
-	//  Environment
-	//
-	iString mEnvScalarFieldDataDir;
-	iString mEnvParticleSetDataDir;
-	iString mEnvVectorFieldDataDir;
-	iString mEnvTensorFieldDataDir;
-
 	//
 	//  Palettes
 	//
@@ -282,17 +269,4 @@ inline iObject* iControlModule::FindObject(const iObjectKey &key, int mod, int o
 	return this->FindObject(key.Type(),mod,obj);
 }
 
-
-class iControlModuleExtension : public iObjectExtension
-{
-
-	IOBJECTEXTENSION_DECLARE_ABSTRACT(iControlModule);
-
-public:
-
-	virtual const iString& GetEnvironment(int key) const = 0;
-	virtual void UpdateDataDir() = 0;
-};
-
-
 #endif  // ICONTROLMODULE_H
