@@ -33,15 +33,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ICONTROLSCRIPT_H
 
 
-#include "ibasescript.h"
+#include "ibasicscript.h"
 
 
 #include "ipointermacro.h"
 
 class iControlModule;
+class iObjectKey;
 
 
-class iControlScript: public iBaseScript
+class iControlScript: public iBasicScript
 {
 
 	IPOINTER_AS_PART(ControlModule);
@@ -58,7 +59,7 @@ public:
 		_Control = 5
 	};
 
-	vtkTypeMacro(iControlScript,iBaseScript);
+	vtkTypeMacro(iControlScript,iBasicScript);
 	static iControlScript* New(iControlModule *cm = 0, iScript *parent = 0);
 
 	virtual const iString& GetHelpString(_HelpId id) const;
@@ -71,48 +72,52 @@ protected:
 	iControlScript(iControlModule *cm, iScript *parent);
 	virtual ~iControlScript();
 
-private:
+	//
+	//  Factory method: replace the calculator with the one that understands key values
+	//
+	virtual iScriptKit::Calculator* CreateCalculator();
 
-	virtual iValue* TransformUnknownTokenToValue(const iString &s, bool acceptArrays = true, bool forceFloat = false);
+	//
+	//  Convert keys into calculator variables
+	//
+	virtual bool SatisfyRequestForVariables(const iString &vars);
+
+private:
 
 	//
 	//  Own console functions for re-directing the output into special windows
 	//
-	virtual void OutputText(const iString &s) = 0;
-	virtual void OutputError(const iString &s) = 0;
+	virtual void OutputText(const iString &s) const = 0;
+	virtual void OutputError(const iString &s) const = 0;
+
+	//
+	//  Helper for using object keys as script variables
+	//
+	void UpdateObjectKey(const iObjectKey *key) const;
+	void UpdateObjectKeyVariable(const iObjectKey *key, iScriptKit::Value *val) const;
+
+	static bool ExecBody(iScript *self, const iString &request, int mode);
 
 	bool mAutoRender;
 
-	static void ExecBody(iScript *me, iValue* v, int mode);
 	//
 	//  Basic functions
 	//
-	static void Exec(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Show(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Hide(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Print(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Create(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Remove(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Render(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Current(iScript *me, iValue* v, iValue::Assignment rel);
-	static void Animate(iScript *me, iValue* v, iValue::Assignment rel);
-	static void ExecAllObjects(iScript *me, iValue* v, iValue::Assignment rel);
-	static void ExecAllWindows(iScript *me, iValue* v, iValue::Assignment rel);
-
-	static void SaveState(iScript *me, iValue* v, iValue::Assignment rel);
-	static void LoadState(iScript *me, iValue* v, iValue::Assignment rel);
-
-	static void EmbedAnimatorScript(iScript *me, iValue* v, iValue::Assignment rel);
+	static bool Exec(iScript *self, const iString &request);
+	static bool ExecAllObjects(iScript *self, const iString &request);
+	static bool ExecAllWindows(iScript *self, const iString &request);
+	static bool Print(iScript *self, const iString &arg);
+	static bool Animate(iScript *self, const iString &arg);
+	static bool EmbedAnimatorScript(iScript *self, const iString &arg);
 	//
 	//  Help functions
 	//
-	static void Help(iScript *me, iValue* v, iValue::Assignment rel);
-	static void HelpObject(iScript *me, iValue* v, iValue::Assignment rel);
-	static void HelpProperty(iScript *me, iValue* v, iValue::Assignment rel);
-
-	static void ListObjects(iScript *me);
-	static void ListProperties(iScript *me, iValue* v, iValue::Assignment rel);
+	static bool Help(iScript *self, const iString &arg);
+	static bool HelpObject(iScript *self, const iString &arg);
+	static bool HelpProperty(iScript *self, const iString &arg);
 
+	static bool ListObjects(iScript *self);
+	static bool ListProperties(iScript *self, const iString &arg);
 };
 
 #endif // ICONTROLCRIPT_H
