@@ -29,12 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  The different kinds of data are distinguished by an associated class DataType. One instance
 //  of DataType class describes a specific type of data loaded from a single data file (like 
-//  UniformScalars, BasicParticles, etc). DataType(s) can be queried by string keywords. A
-//  keyword must be in the form <qualifier>:<specifier>[,specifier...], where a specifier
-//  is one of followig four strings: "ScalarField", "VectorFied", "TensorField", and 
-//  "ParticleSet". A qualifier can be any string. Quailifiers are registered as new DataType(s)
-//  are created, and are associated with an unsigned int index. Keywords and names of DataType(s)
-//  have to be unique.
+//  UniformScalars, BasicParticles, etc). DataType(s) can be queried by string keywords. 
 //  
 //  A group of DataType(s) forms a DataInfo.
 //
@@ -44,57 +39,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iarray.h"
+#include "ipointer.h"
 #include "istring.h"
 
 
-class iDataClass;
 class iDataInfo;
 class iDataType;
-
-
-namespace iData
-{
-	const iDataType& None();
-	const iDataInfo& Any();
-
-	const iDataClass& ScalarField();
-	const iDataClass& VectorField();
-	const iDataClass& TensorField();
-	const iDataClass& ParticleSet();
-
-	const iDataType& UniformScalars();
-	const iDataType& UniformVectors();
-	const iDataType& UniformTensors();
-	const iDataType& BasicParticles();
-};
-
-
-class iDataClass
-{
-
-	friend const iDataClass& iData::ScalarField();
-	friend const iDataClass& iData::VectorField();
-	friend const iDataClass& iData::TensorField();
-	friend const iDataClass& iData::ParticleSet();
-
-public:
-
-	inline const iString& GetName() const { return mName; }
-	inline const iString& GetTextName() const { return mTextName; }
-
-	inline bool IsOfType(const iString &name) const { return name == mName; }
-
-private:
-
-	iDataClass(const iString& tname);
-	~iDataClass();
-
-	iString mName, mTextName;
-
-	iDataClass(); // not implemented
-	iDataClass(const iDataClass &kind); // not implemented
-	void operator=(const iDataClass&); // not implemented
-};
+class iShell;
 
 
 class iDataType
@@ -102,7 +53,9 @@ class iDataType
 
 public:
 
-	iDataType(int id, const iString& tname, const iString& sname, int priority, const iString &keywords, bool primary = true, unsigned int rank = 0U);
+	static const iDataType& Null();
+
+	iDataType(int id, const iString& tname, const iString& sname, const iString &keywords, const iString &environment = "");
 	~iDataType();
 
 	bool operator==(const iDataType &type) const;
@@ -110,34 +63,25 @@ public:
 
 	inline int GetId() const { return mId; }
 	inline bool IsNull() const { return mId == 0; }
-	inline unsigned int GetRank() const { return mRank; }
 
-	inline int GetPriority() const { return mPriority; }
 	inline const iString& GetName() const { return mName; }
 	inline const iString& GetTextName() const { return mTextName; }
 	inline const iString& GetShortName() const { return mShortName; }
 
+	iString GetEnvironment(iShell *shell) const;
+
 	inline bool IsOfType(const iString &name) const { return name==mName || name==mShortName; }
-
-	inline bool IsPrimary() const { return mIsPrimary; }
-
-	bool IsOfClass(const iDataClass &c) const;
+	bool MatchesKeyword(const iString &str) const;
+	static void FindTypesByKeywords(iDataInfo &info, const iString &str);
 
 	static const iDataType& FindTypeById(int id);
 	static const iDataType& FindTypeByName(const iString &name);
 
-	static const iDataType& ReSpecifyType(const iDataType &type, const iString &specifier);
-	static const iDataType& FindTypeByKeyword(const iString &keyword);
-	static void FindAllTypesByKeywords(iDataInfo &info, const iString &keywords);
-
 private:
 
 	const int mId;
-	const int mPriority;
-	const bool mIsPrimary;
-	const unsigned int mRank;
 	const iString mTextName, mShortName, mKeywords;
-	iString mName;
+	iString mName, mEnv;
 
 	iDataType(); // not implemented
 	iDataType(const iDataType &type); // not implemented
@@ -145,11 +89,26 @@ private:
 };
 
 
+//
+//  Helper class
+//
+class iDataTypePointer : public iPointer::Ordered<const iDataType>
+{
+
+public:
+
+	iDataTypePointer(const iDataType *ptr = 0) : iPointer::Ordered<const iDataType>(ptr){}
+};
+
+
 class iDataInfo
 {
 
 public:
 
+	static const iDataInfo& None();
+	static const iDataInfo& Any();
+
 	iDataInfo();
 	iDataInfo(const iDataInfo &info);
 	iDataInfo(const iDataType &type);
@@ -169,7 +128,7 @@ public:
 
 private:
 
-	iSearchableArray<const iDataType*> mArr;
+	iOrderedArray<iDataTypePointer> mArr;
 };
 
 
