@@ -59,7 +59,8 @@ public:
 		const iPosition *PosMin, *PosMax;
 	};
 
-	static iDataExplorer* New(iViewModule *vm);
+	vtkTypeMacro(iDataExplorer,vtkObject);
+	static iDataExplorer* New(iViewModule *vm = 0);
 	static const iObjectType& Type();
 
 	//
@@ -73,7 +74,6 @@ public:
 
 protected:
 	
-	iDataExplorer(iViewModule *vm);
 	virtual ~iDataExplorer();
 
 	virtual void Execute();
@@ -81,6 +81,10 @@ protected:
 
 	virtual void UpdateDataType(int prev);
 
+private:
+
+	iDataExplorer(iViewModule *vm);
+
 	bool mComputeRangeOnly;
 	int mComponent, mStretch;
 	Info mInfo;
@@ -90,4 +94,3 @@ protected:
 
 #endif  // IDATAEXPLORER_H
 
-
