@@ -29,16 +29,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatahandler.h"
 
 
+#include "icontrolmodule.h"
 #include "idataconsumer.h"
 #include "ierror.h"
+#include "ishell.h"
+#include "iviewmodule.h"
 
 
-iDataHandler::iDataHandler(iDataConsumer *consumer) : iViewModuleComponent((consumer==0)?0:consumer->GetViewModule())
+iDataHandler::iDataHandler(iDataConsumer *consumer) : mViewModule((consumer==0)?0:consumer->GetViewModule())
 {
 	IERROR_ASSERT(consumer);
 
 	mConsumer = consumer;
 	mConsumer->RegisterDataHandler(this);
+
+	if(mViewModule != 0) mViewModule->GetControlModule()->GetShell()->OnInitAtom();
 }
 
 
