@@ -120,7 +120,7 @@ protected:
 
 	virtual void NotifyDependencies(int var);
 
-	void Configure(int num, const iString &name);
+	void Configure(int num);
 	void Initialize(Var &v);
 	void AdjustMinMax(Var &v);
 
