@@ -198,10 +198,10 @@ void iDataSubject::UnPackCompleteState(const iString &s)
 	//
 	//  Save the currently loaded Vars
 	//
-	limits->BackupVars();
-	limits->BlockNotifications(true);
-	limits->AssignVars();
-	limits->BlockNotifications(false);
+	if(this->IsThereData())
+	{
+		limits->BackupVars();
+	}
 	//
 	//  Unpack state and clear the cache
 	//
@@ -210,7 +210,10 @@ void iDataSubject::UnPackCompleteState(const iString &s)
 	//
 	//  Restore the currently loaded Vars
 	//
-	limits->RestoreVars();
+	if(this->IsThereData())
+	{
+		limits->RestoreVars();
+	}
 }
 
 
