@@ -36,40 +36,45 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iconsole.h"
 
 
-#define IERROR_ASSERT(_p_)		{ if((_p_) == 0) iConsole::Instance()->DisplayFatalErrorMessage("Null pointer.",__FILE__,__LINE__); }
-#define IERROR_FINISH(_m_)		{ iConsole::Instance()->DisplayFatalErrorMessage(_m_,__FILE__,__LINE__); }
-#define IERROR_REPORT(_m_)		{ iConsole::Instance()->DisplayErrorMessage(_m_,__FILE__,__LINE__); }
-#ifdef I_CHECK1
-#define IERROR_REPORT_BUG		{ iConsole::Instance()->DisplayErrorMessage("Bug detected.",__FILE__,__LINE__); }
+#define IERROR_LOW(_m_)			{ iConsole::Display(iConsole::_LowError,_m_,__FILE__,__LINE__); }
+#define IERROR_HIGH(_m_)		{ iConsole::Display(iConsole::_LowError,_m_,__FILE__,__LINE__); }
+#define IERROR_FATAL(_m_)		{ iConsole::Display(iConsole::_FatalError,_m_,__FILE__,__LINE__); }
+#define IERROR_ASSERT(_p_)		{ if((_p_) == 0) iConsole::Display(iConsole::_FatalError,"Invalid use of a null pointer.",__FILE__,__LINE__); }
+
+#if defined(I_CHECK1) || defined(I_CHECK2)
+#define IERROR_REPORT_BUG		{ iConsole::Display(iConsole::_HighError,"Bug detected.",__FILE__,__LINE__); }
 #endif
 #ifdef I_DEBUG
-#define IERROR_BREAKPOINT		{ iConsole::Instance()->BreakPoint(__FILE__,__LINE__); }
+#define IERROR_BREAKPOINT		{ iConsole::BreakPoint(__FILE__,__LINE__); }
 #endif
 
 //
 //  error-reporting dynamic_cast - make it a global function to reduce de-referencing
+//  (ideally we would avoid using it all - use iRequiredCast(INFO,vtkObject*) function whenever possible).
 //
 template<class O, class I>
-inline O* iPointerCast(I* p)
+inline O* iDynamicCast(int line, const char *file, I* p)
 {
 	if(p == 0) return 0;
 	O* tmp = dynamic_cast<O*>(p);
-	if(tmp == 0) iConsole::Instance()->DisplayFatalErrorMessage("Invalid cast.",__FILE__,__LINE__);
+	if(tmp == 0) iConsole::Display(iConsole::_FatalError,"Invalid cast.",file,line);
 	return tmp;
 }
 
 //
-//  RequiredCast for VTK Objects
+//  RequiredCast for children of vtkObjectBase (which must be all cast-able objects)
 //
-class vtkObject;
+class vtkObjectBase;
 template<class O>
-inline O* iRequiredCast(vtkObject *p)
+inline O* iRequiredCast(int line, const char *file, vtkObjectBase *p)
 {
 	if(p == 0) return 0;
 	O* tmp = O::SafeDownCast(p);
-	if(tmp == 0) iConsole::Instance()->DisplayFatalErrorMessage("Invalid cast.",__FILE__,__LINE__);
+	if(tmp == 0) iConsole::Display(iConsole::_FatalError,"Invalid cast.",file,line);
 	return tmp;
 }
 
+#define INFO __LINE__,__FILE__
+
 #endif  // IERROR_H
 
