@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iFlipNormalsFilter : public iGenericPolyDataToPolyDataFilter<vtkReverseSense>
 {
 	
-	IGENERICFILTER_DECLARE(iFlipNormalsFilter);
+	IGENERICFILTER_DECLARE(iFlipNormalsFilter,vtkReverseSense);
 	
 protected:
 
