@@ -48,7 +48,7 @@ iImage::iImage(int depth)
 {
 	if(depth<1 || depth>4)
 	{
-		IERROR_REPORT("Incorrect number of image components");
+		IERROR_LOW("Incorrect number of image components");
 		depth = 3;
 	}
 	mData = 0;
@@ -87,7 +87,7 @@ vtkImageData* iImage::CreateData(int depth)
 
 	if(depth<1 || depth>4)
 	{
-		IERROR_REPORT("Incorrect number of image components");
+		IERROR_LOW("Incorrect number of image components");
 		depth = 3;
 	}
 	tmp = vtkImageData::New(); IERROR_ASSERT(tmp);
@@ -333,8 +333,8 @@ bool operator==(const iImage &s1, const iImage &s2)
 	if(s1.mData == s2.mData) return true;
 	if(s1.mData==0 || s2.mData==0) return false;
 	unsigned long i, n = s1.mDepth*s1.mWidth*s1.mHeight;
-	char *p1 = (char *)s1.mData->GetScalarPointer();
-	char *p2 = (char *)s2.mData->GetScalarPointer();
+	unsigned char *p1 = (unsigned char *)s1.mData->GetScalarPointer();
+	unsigned char *p2 = (unsigned char *)s2.mData->GetScalarPointer();
 	if(p1 == p2) return true;
 	if(p1==0 || p2==0) return false;
 	for(i=0; i<n; i++)
@@ -367,8 +367,7 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 	{
 		mWidth = w;
 		mHeight = h;
-		if(mData == 0) mData = CreateData(3);
-		mDepth = mData->GetNumberOfScalarComponents();
+		if(mData == 0) mData = CreateData(mDepth);
 		Allocate(mData,w,h);
 		memset(mData->GetScalarPointer(),0,mDepth*w*h);
 		return;
@@ -442,7 +441,7 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 		j0l[j] = round(y0-0.5);
 		if(j0l[j]<0 || j0l[j]>=mHeight)
 		{
-			IERROR_REPORT("Corrupted image.");
+			IERROR_LOW("Corrupted image.");
 			return;
 		}
 		dy = y0 - 0.5 - j0l[j]; 
@@ -469,7 +468,7 @@ void iImage::Scale(int w, int h, ScaleMode m, ScaleFilter f)
 		i0l[i] = round(x0-0.5);
 		if(i0l[i]<0 || i0l[i]>=mWidth)
 		{
-			IERROR_REPORT("Corrupted image.");
+			IERROR_LOW("Corrupted image.");
 			return;
 		}
 		dx = x0 - 0.5 - i0l[i]; 
@@ -542,3 +541,108 @@ void iImage::Smooth(float dx, float dy)
 }
 
 
+bool iImage::CombineInPseudoColor(const iImage &imRed, const iImage &imGreen, const iImage &imBlue)
+{
+	bool rIn(!imRed.IsEmpty()), gIn(!imGreen.IsEmpty()), bIn(!imBlue.IsEmpty());
+	int d = 0, w = 0, h = 0;
+
+	if(rIn)
+	{
+		d = imRed.Depth();
+		w = imRed.Width();
+		h = imRed.Height();
+	}
+
+	if(gIn)
+	{
+		if(d == 0)
+		{
+			d = imGreen.Depth();
+			w = imGreen.Width();
+			h = imGreen.Height();
+		}
+		else
+		{
+			if(d != imGreen.Depth()) return false;
+			if(w != imGreen.Width()) return false;
+			if(h != imGreen.Height()) return false;
+		}
+	}
+
+	if(bIn)
+	{
+		if(d == 0)
+		{
+			d = imBlue.Depth();
+			w = imBlue.Width();
+			h = imBlue.Height();
+		}
+		else
+		{
+			if(d != imBlue.Depth()) return false;
+			if(w != imBlue.Width()) return false;
+			if(h != imBlue.Height()) return false;
+		}
+	}
+
+	if((d!=3 && d!=4) || w==0 || h==0) return false; // no non-empty image is specified
+
+	//
+	//  Reset the data
+	//
+	this->Clear();
+	mWidth = w;
+	mHeight = h;
+	mDepth = d;
+	mData = CreateData(d);
+	Allocate(mData,w,h);
+
+	unsigned char *dPtr1, *dPtr2, *dPtr = this->DataPointer(); 
+	unsigned char *rPtr1, *rPtr2, *rPtr = imRed.DataPointer();
+	unsigned char *gPtr1, *gPtr2, *gPtr = imGreen.DataPointer();
+	unsigned char *bPtr1, *bPtr2, *bPtr = imBlue.DataPointer();
+
+	//
+	//  Fill in the data
+	//
+	int i, j, a[3], aMax;
+	for(j=0; j<h; j++)
+	{
+		dPtr1 = dPtr + d*w*j;
+		rPtr1 = rPtr + d*w*j;
+		gPtr1 = gPtr + d*w*j;
+		bPtr1 = bPtr + d*w*j;
+		for(i=0; i<w; i++)
+		{
+			dPtr2 = dPtr1 + d*i;
+			rPtr2 = rPtr1 + d*i;
+			gPtr2 = gPtr1 + d*i;
+			bPtr2 = bPtr1 + d*i;
+			//
+			//  Opacity
+			//
+			if(d > 3)
+			{
+				a[0] = rIn ? rPtr2[3] : 0;
+				a[1] = gIn ? gPtr2[3] : 0;
+				a[2] = bIn ? bPtr2[3] : 0;
+				aMax = (a[0] > a[1]) ? a[0] : a[1];
+				aMax = (a[2] > aMax) ? a[2] : aMax;
+			}
+			else
+			{
+				aMax = a[0] = a[1] = a[2] = 255;
+			}
+			//
+			//  Combine
+			//
+			dPtr2[0] = rIn ? (a[0]*(int(rPtr2[0])+int(rPtr2[1])+int(rPtr2[2])))/(3*aMax) : 0;
+			dPtr2[1] = gIn ? (a[1]*(int(gPtr2[0])+int(gPtr2[1])+int(gPtr2[2])))/(3*aMax) : 0;
+			dPtr2[2] = bIn ? (a[2]*(int(bPtr2[0])+int(bPtr2[1])+int(bPtr2[2])))/(3*aMax) : 0;
+			if(d > 3) dPtr2[3] = aMax;
+		}
+	}
+
+	return true;
+}
+
