@@ -657,9 +657,10 @@ iImageComposerForegroundWindow::iImageComposerForegroundWindow(iViewModule *vm,
 	mPosX = mPosY = 0;
 
 	mZoomX = mZoomY = 0.5f;
-	mZoomHeight = 0.2f;
+	mZoomFactor = 0.2f;
 	mZoomSource = 0;
 	mZoomFlag = _4Lines;
+	mZoomAuto = false;
 }
 
 
@@ -749,7 +750,7 @@ int iImageComposerForegroundWindow::GetWindowHeight() const
 void iImageComposerForegroundWindow::UpdateWindow()
 {
 	this->iImageComposerWindow::UpdateWindow();
-	this->SyncZoom();
+	mZoomAuto = this->SyncZoom();
 }
 
 
@@ -774,10 +775,10 @@ void iImageComposerForegroundWindow::Draw(iStereoImage &outIm) const
 			int bw = this->GetBorderWidth();
 			iColor bc(this->GetBorderColor());
 
-			int zx1 = round(mZoomSource->GetContentsX()+(mZoomX-0.5*this->GetZoomWidth())*mZoomSource->GetContentsWidth());
-			int zy1 = round(mZoomSource->GetContentsY()+(mZoomY-0.5*this->GetZoomHeight())*mZoomSource->GetContentsHeight());
-			int zx2 = round(mZoomSource->GetContentsX()+(mZoomX+0.5*this->GetZoomWidth())*mZoomSource->GetContentsWidth());
-			int zy2 = round(mZoomSource->GetContentsY()+(mZoomY+0.5*this->GetZoomHeight())*mZoomSource->GetContentsHeight());
+			int zx1 = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()-0.5*this->GetZoomWidth()));
+			int zy1 = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()-0.5*this->GetZoomHeight()));
+			int zx2 = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()+0.5*this->GetZoomWidth()));
+			int zy2 = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()+0.5*this->GetZoomHeight()));
 
 			int i;
 			for(i=0; i<bw; i++)
@@ -911,20 +912,13 @@ void iImageComposerForegroundWindow::SetZoomPosition(float x, float y)
 }
 
 
-void iImageComposerForegroundWindow::SetZoomHeight(float height)
+void iImageComposerForegroundWindow::SetZoomFactor(float factor)
 {
-	if(height>0.0f && height<1.0f && fabs(height-mZoomHeight)>1.0e-5)
+	if(factor>0.0f && factor<1.0f && fabs(factor-mZoomFactor)>1.0e-5)
 	{
-		mZoomHeight = height;
+		mZoomFactor = factor;
 		mComposer->ClearCache();
-		if(mZoomSource != 0)
-		{
-			if(this->GetZoomWidth() > 1.0)
-			{
-				mZoomHeight *= 1.0/this->GetZoomWidth();
-			}
-			this->UpdateZoomPosition();
-		}
+		if(mZoomSource != 0) this->UpdateZoomPosition();
 	}
 }
 
@@ -990,10 +984,10 @@ void iImageComposerForegroundWindow::UpdateZoomFlag()
 	bool ok;
 	int i, j, s, d, pz[4][2], pw[4][2], n[2];
 
-	pz[0][0] = pz[2][0] = round(mZoomSource->GetContentsX()+(mZoomX-0.5*this->GetZoomWidth())*mZoomSource->GetContentsWidth());
-	pz[1][0] = pz[3][0] = round(mZoomSource->GetContentsX()+(mZoomX+0.5*this->GetZoomWidth())*mZoomSource->GetContentsWidth());
-	pz[0][1] = pz[1][1] = round(mZoomSource->GetContentsY()+(mZoomY-0.5*this->GetZoomHeight())*mZoomSource->GetContentsHeight());
-	pz[2][1] = pz[3][1] = round(mZoomSource->GetContentsY()+(mZoomY+0.5*this->GetZoomHeight())*mZoomSource->GetContentsHeight());
+	pz[0][0] = pz[2][0] = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()-0.5*this->GetZoomWidth()));
+	pz[1][0] = pz[3][0] = round(mZoomSource->GetContentsX()+(mZoomX*mZoomSource->GetContentsWidth()+0.5*this->GetZoomWidth()));
+	pz[0][1] = pz[1][1] = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()-0.5*this->GetZoomHeight()));
+	pz[2][1] = pz[3][1] = round(mZoomSource->GetContentsY()+(mZoomY*mZoomSource->GetContentsHeight()+0.5*this->GetZoomHeight()));
 
 	pw[0][0] = pw[2][0] = mPosX;
 	pw[1][0] = pw[3][0] = mPosX + this->GetImageWidth() - 1;
@@ -1051,15 +1045,24 @@ void iImageComposerForegroundWindow::UpdateZoomFlag()
 
 void iImageComposerForegroundWindow::UpdateZoomPosition()
 {
-	if(mZoomSource==0 || this->GetViewModule()==0 || this->SyncZoom()) return;
-	
-	float dx = 0.5*this->GetZoomWidth();
-	float dy = 0.5*mZoomHeight;
+	if(mZoomSource==0 || this->GetViewModule()==0 || (mZoomAuto=this->SyncZoom())) return;
 
-	if(mZoomX < dx) mZoomX = dx;
-	if(mZoomY < dy) mZoomY = dy;
-	if(mZoomX > 1.0f-dx) mZoomX = 1.0f - dx;
-	if(mZoomY > 1.0f-dy) mZoomY = 1.0f - dy;
+	if(this->GetWindowWidth()*mZoomFactor > mZoomSource->GetContentsWidth())
+	{
+		mZoomFactor = float(mZoomSource->GetContentsWidth())/this->GetWindowWidth();
+	}
+	if(this->GetWindowHeight()*mZoomFactor > mZoomSource->GetContentsHeight())
+	{
+		mZoomFactor = float(mZoomSource->GetContentsHeight())/this->GetWindowHeight();
+	}
+
+	float w = 0.5*this->GetWindowWidth()*mZoomFactor/mZoomSource->GetContentsWidth();
+	float h = 0.5*this->GetWindowHeight()*mZoomFactor/mZoomSource->GetContentsHeight();
+
+	if(mZoomX < w) mZoomX = w;
+	if(mZoomY < h) mZoomY = h;
+	if(mZoomX > 1.0f-w) mZoomX = 1.0f - w;
+	if(mZoomY > 1.0f-h) mZoomY = 1.0f - h;
 
 	this->UpdateZoomFlag();
 }
@@ -1071,10 +1074,6 @@ bool iImageComposerForegroundWindow::SyncZoom()
 
 	iViewModule *source = mZoomSource->GetViewModule();
 	iViewModule *target = this->GetViewModule();
-	//
-	//  Are we clones?
-	//
-	if(!source->IsClone(target) && !target->IsClone(source)) return false;
 
 	//
 	//  Do we have the same projections?
@@ -1082,15 +1081,38 @@ bool iImageComposerForegroundWindow::SyncZoom()
 	if(source->GetRenderer()->GetActiveCamera()->GetParallelProjection() != target->GetRenderer()->GetActiveCamera()->GetParallelProjection()) return false;
 
 	//
-	//  In perspective projections camera positions must coincide
+	//  ViewUp vectors must coincide
 	//
 	int i;
+	double sPos[3], tPos[3];
+	source->GetRenderer()->GetActiveCamera()->GetViewUp(sPos);
+	target->GetRenderer()->GetActiveCamera()->GetViewUp(tPos);
+	for(i=0; i<3; i++) if(fabs(sPos[i]-tPos[i]) > iMath::_DoubleTolerance)
+	{
+		return false;
+	}
+
+	//
+	//  In perspective projection camera focal points, view angles, and directions must coincide
+	//
 	if(source->GetRenderer()->GetActiveCamera()->GetParallelProjection() == 0)
 	{
-		double sPos[3], tPos[3];
-		source->GetRenderer()->GetActiveCamera()->GetPosition(sPos);
-		target->GetRenderer()->GetActiveCamera()->GetPosition(tPos);
-		for(i=0; i<3; i++) if(fabs(sPos[i]-tPos[i]) > iMath::_DoubleTolerance) return false;
+		source->GetRenderer()->GetActiveCamera()->GetFocalPoint(sPos);
+		target->GetRenderer()->GetActiveCamera()->GetFocalPoint(tPos);
+		for(i=0; i<3; i++) if(fabs(sPos[i]-tPos[i]) > iMath::_DoubleTolerance)
+		{
+			return false;
+		}
+		source->GetRenderer()->GetActiveCamera()->GetDirectionOfProjection(sPos);
+		target->GetRenderer()->GetActiveCamera()->GetDirectionOfProjection(tPos);
+		for(i=0; i<3; i++) if(fabs(sPos[i]-tPos[i]) > iMath::_DoubleTolerance)
+		{
+			return false;
+		}
+		if(fabs(source->GetRenderer()->GetActiveCamera()->GetViewAngle()-target->GetRenderer()->GetActiveCamera()->GetViewAngle()) > iMath::_DoubleTolerance)
+		{
+			return false;
+		}
 	}
 
 	//
@@ -1137,7 +1159,7 @@ bool iImageComposerForegroundWindow::SyncZoom()
 	//
 	if(r[0][0]<0.0 || r[0][0]>1.0 || r[0][1]<0.0 || r[0][1]>1.0 || r[3][0]<0.0 || r[3][0]>1.0 || r[3][1]<0.0 || r[3][1]>1.0) return false;
 
-	mZoomHeight = r[3][1] - r[0][1];
+	mZoomFactor = (r[3][1]-r[0][1])*mZoomSource->GetContentsHeight()/this->GetWindowHeight();
 	mZoomX = 0.5*(r[0][0]+r[3][0]);
 	mZoomY = 0.5*(r[0][1]+r[3][1]);
 
