@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iOptimizePolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkStripper>
 {
 	
-	IGENERICFILTER_DECLARE(iOptimizePolyDataFilter);
+	IGENERICFILTER_DECLARE(iOptimizePolyDataFilter,vtkStripper);
 	
 protected:
 	
