@@ -39,11 +39,11 @@ class vtkCellArray;
 class iOrthoPolygonPlaneFilter : public iGenericFilter<vtkStructuredPointsToPolyDataFilter,vtkImageData,vtkPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iOrthoPolygonPlaneFilter);
+	IGENERICFILTER_DECLARE(iOrthoPolygonPlaneFilter,vtkStructuredPointsToPolyDataFilter);
 
 public:
 
-	void SetCorrectForFlatShading(bool s);
+	void SetInterpolation(bool s);
 
 protected:
 
@@ -51,9 +51,11 @@ protected:
 
 	virtual void ProduceOutput();
 
-	bool mCorrectFlat;
-    int mQuadMode, mOldAxis, mOldDim[3];
-    vtkCellArray *mNewStrips, *mNewQuads;
+private:
+
+	bool mInterpolate;
+    int mOldDimU, mOldDimV;
+    vtkCellArray *mNewQuads;
 };
 
 #endif // IORTHOPOLYGONPLANEFILTER_H
