@@ -31,11 +31,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "idata.h"
 #include "ierror.h"
+#include "iuniformgriddata.h"
 #include "iviewmodule.h"
 
+#include <vtkCellData.h>
 #include <vtkFloatArray.h>
 #include <vtkPointData.h>
-#include <vtkStructuredPoints.h>
+
+#include "iparameter.h"
+using namespace iParameter;
 
 //
 //  Templates
@@ -98,25 +102,82 @@ void iOrthoSlicer::SetDir(int d)
 
 void iOrthoSlicer::ProduceOutput()
 {
-    int dim[3], dim0[3], numPts;
-    double org[3], spa[3];
+    int numCellsIn[3], dimsIn[3], dimsOut[3];
+    double orgIn[3], spaIn[3];
     double orgOut[3], spaOut[3];
-    int Uidx, Vidx;
-	iOrthoSlicer::GetUV(mDir,Uidx,Vidx);
+    int u, v;
 
-	vtkImageData *input = this->GetInput();
+	iOrthoSlicer::GetUV(mDir,u,v);
+
+	iUniformGridData *input = iUniformGridData::SafeDownCast(this->GetInput());
 	vtkImageData *output = this->GetOutput();
 
 	output->Initialize();
 
-    input->GetOrigin(org);
-    input->GetSpacing(spa);
-    input->GetDimensions(dim0);
+	if(input == 0) return;
 
+	input->GetNumCells(numCellsIn);
+	if(numCellsIn[u]<1 || numCellsIn[v]<1) return;
+
+	//
+	//  Get info about out configuration
+	//
+    input->GetSpacing(spaIn);
+    input->GetGlobalOrigin(orgIn);
+	input->GetDimensions(dimsIn);
+
+	//
+	//  Compute the sub-sampling factor
+	//
+	int step = mSampleRate;
+	step = (numCellsIn[u]/8 > step) ? step : numCellsIn[u]/8;
+	step = (numCellsIn[v]/8 > step) ? step : numCellsIn[u]/8;
+	if(step < 1) step = 1;
+
+	//
+	//  Decide what we do: cell vs point data, how many points, etc.
+	//
+	if(input->GetVoxelLocation() == _VoxelLocationVertex)
+	{
+		//
+		//  Place points as we get them
+		//
+		dimsOut[u] = numCellsIn[u]/step + 1;
+		dimsOut[v] = numCellsIn[v]/step + 1;
+
+		if(dimsOut[u]<2 || dimsOut[v]<2) return;
+
+		spaOut[u] = (spaIn[u]*numCellsIn[u])/(dimsOut[u]-1);
+		spaOut[v] = (spaIn[v]*numCellsIn[v])/(dimsOut[v]-1);
+	}
+	else	
+	{
+		//
+		//  Create points around cells, but throw away periodic offsets
+		//
+		dimsOut[u] = numCellsIn[u]/step;
+		dimsOut[v] = numCellsIn[v]/step;
+
+		if(dimsOut[u]<1 || dimsOut[v]<1) return;
+
+		spaOut[u] = (spaIn[u]*numCellsIn[u])/dimsOut[u];
+		spaOut[v] = (spaIn[v]*numCellsIn[v])/dimsOut[v];
+	}
+
+	dimsOut[mDir] = 1;
+	spaOut[mDir] = 1.0;
+
+	orgOut[u] = orgIn[u];
+	orgOut[v] = orgIn[v];
+	orgOut[mDir] = mPos[mDir];
+
+	//
+	//  Find the intersection
+	//
 	int ijk[3], ijk1[3], ijk2[3];
-    float ht = (mPos[mDir]-org[mDir])/spa[mDir];	//Normalized height
-    ijk[mDir] = (int)floor(ht);						//Grid Point below
-    float ss1, ss2 = (ht-ijk[mDir]);				//interpolation factor
+    float ht = (mPos[mDir]-orgIn[mDir])/spaIn[mDir];	//Normalized height
+    ijk[mDir] = int(ht);								//Grid Point below
+    float ss1, ss2 = (ht-ijk[mDir]);					//interpolation factor
 
 	//
 	//  Add a little bit of a cushion
@@ -127,9 +188,9 @@ void iOrthoSlicer::ProduceOutput()
 		ss2 = 0.0;
 	}
 
-	if(ijk[mDir]==dim0[mDir]-1 && ss2<0.01)
+	if(ijk[mDir]==numCellsIn[mDir] && ss2<0.01)
 	{
-		ijk[mDir] = dim0[mDir] - 2;
+		ijk[mDir] = numCellsIn[mDir] - 1;
 		ss2 = 1.0;
 	}
 	ss1 = 1.0 - ss2;
@@ -137,36 +198,16 @@ void iOrthoSlicer::ProduceOutput()
 	//
 	//  Must do that for parallel work
 	//
-	if(ijk[mDir]<0 || ijk[mDir]>=dim0[mDir]-1) return;
+	if(ijk[mDir]<0 || ijk[mDir]>=numCellsIn[mDir]) return;
 	
-	int step = mSampleRate;
-	step = ( dim0[Uidx]/8 > step ) ? step : dim0[Uidx]/8;
-	step = ( dim0[Vidx]/8 > step ) ? step : dim0[Uidx]/8;
-	if(step < 1) step = 1;
-
-	dim[Uidx] = dim0[Uidx]/step;
-	dim[Vidx] = dim0[Vidx]/step;
-	dim[mDir] = 1;
-
-	float Ufact = (dim0[Uidx]-1.0)/(dim[Uidx]-1.0);
-	float Vfact = (dim0[Vidx]-1.0)/(dim[Vidx]-1.0);
-
-	spaOut[Uidx] = spa[Uidx]*Ufact;
-	spaOut[Vidx] = spa[Vidx]*Vfact;
-	spaOut[mDir] = spa[mDir];
-
-	orgOut[Uidx] = org[Uidx];
-	orgOut[Vidx] = org[Vidx];
-	orgOut[mDir] = mPos[mDir];
-
-	output->SetDimensions(dim);
+	output->SetDimensions(dimsOut);
 	output->SetOrigin(orgOut);
 	output->SetSpacing(spaOut);
 
 	//
 	//  Prepare output scalars
 	//
-    numPts = dim[Uidx]*dim[Vidx];
+    vtkIdType numPts = dimsOut[u]*dimsOut[v];
 	if(!this->ScalarsInit(input->GetPointData(),numPts,1)) return;
 
 	wScalarPtrIn += mCurVar;
@@ -175,24 +216,24 @@ void iOrthoSlicer::ProduceOutput()
 
 	ijk1[mDir] = ijk[mDir];
 	ijk2[mDir] = ijk[mDir] + 1;
-	for(ijk[Vidx]=0; ijk[Vidx]<dim[Vidx]; ijk[Vidx]++)
+	for(ijk[v]=0; ijk[v]<dimsOut[v]; ijk[v]++)
 	{
-		this->UpdateProgress((float)ijk[Vidx]/dim[Vidx]);
+		this->UpdateProgress((float)ijk[v]/dimsOut[v]);
 		if(this->GetAbortExecute()) break;
 
-		for(ijk[Uidx]=0; ijk[Uidx]<dim[Uidx]; ijk[Uidx]++)
+		for(ijk[u]=0; ijk[u]<dimsOut[u]; ijk[u]++)
 		{
-//			loffOut = wScalarDimOut*(ijk[Uidx]+ijk[Vidx]*(vtkIdType)dim[Uidx]);
-			loffOut = ijk[Uidx] + ijk[Vidx]*(vtkIdType)dim[Uidx];  //  wScalarDimOut = 1
+//			loffOut = wScalarDimOut*(ijk[u]+ijk[v]*(vtkIdType)dim[u]);
+			loffOut = ijk[u] + ijk[v]*(vtkIdType)dimsOut[u];  //  wScalarDimOut = 1
 
 			if(mInterpolate)
 			{
-				ijk1[Uidx] = ijk[Uidx]*step + step/2;
-				ijk1[Vidx] = ijk[Vidx]*step + step/2;
-				loffIn1 = wScalarDimIn*(ijk1[0]+(vtkIdType)dim0[0]*(ijk1[1]+(vtkIdType)dim0[1]*ijk1[2]));
-				ijk2[Uidx] = ijk1[Uidx];
-				ijk2[Vidx] = ijk1[Vidx];
-				loffIn2 = wScalarDimIn*(ijk2[0]+(vtkIdType)dim0[0]*(ijk2[1]+(vtkIdType)dim0[1]*ijk2[2]));
+				ijk1[u] = ijk[u]*step + step/2;
+				ijk1[v] = ijk[v]*step + step/2;
+				loffIn1 = wScalarDimIn*(ijk1[0]+(vtkIdType)dimsIn[0]*(ijk1[1]+(vtkIdType)dimsIn[1]*ijk1[2]));
+				ijk2[u] = ijk1[u];
+				ijk2[v] = ijk1[v];
+				loffIn2 = wScalarDimIn*(ijk2[0]+(vtkIdType)dimsIn[0]*(ijk2[1]+(vtkIdType)dimsIn[1]*ijk2[2]));
 //				for(j=0; j<wScalarDimOut; j++)
 //				{
 //					wScalarPtrOut[loffOut+j] = ss1*wScalarPtrIn[loffIn1+j] + ss2*wScalarPtrIn[loffIn2+j];
@@ -203,15 +244,15 @@ void iOrthoSlicer::ProduceOutput()
 			{
 				if(ss2 < 0.5f)
 				{
-					ijk1[Uidx] = ijk[Uidx]*step + step/2;
-					ijk1[Vidx] = ijk[Vidx]*step + step/2;
-					loffIn1 = wScalarDimIn*(ijk1[0]+(vtkIdType)dim0[0]*(ijk1[1]+(vtkIdType)dim0[1]*ijk1[2]));
+					ijk1[u] = ijk[u]*step + step/2;
+					ijk1[v] = ijk[v]*step + step/2;
+					loffIn1 = wScalarDimIn*(ijk1[0]+(vtkIdType)dimsIn[0]*(ijk1[1]+(vtkIdType)dimsIn[1]*ijk1[2]));
 				}
 				else
 				{
-					ijk2[Uidx] = ijk[Uidx]*step + step/2;
-					ijk2[Vidx] = ijk[Vidx]*step + step/2;
-					loffIn1 = wScalarDimIn*(ijk2[0]+(vtkIdType)dim0[0]*(ijk2[1]+(vtkIdType)dim0[1]*ijk2[2]));
+					ijk2[u] = ijk[u]*step + step/2;
+					ijk2[v] = ijk[v]*step + step/2;
+					loffIn1 = wScalarDimIn*(ijk2[0]+(vtkIdType)dimsIn[0]*(ijk2[1]+(vtkIdType)dimsIn[1]*ijk2[2]));
 				}
 //				for(j=0; j<wScalarDimOut; j++)
 //				{
@@ -222,30 +263,37 @@ void iOrthoSlicer::ProduceOutput()
 		}
     }
     
-    this->ScalarsDone(output->GetPointData());
+	if(input->GetVoxelLocation() == _VoxelLocationVertex)
+	{
+	    this->ScalarsDone(output->GetPointData());
+	}
+	else
+	{
+	    this->ScalarsDone(output->GetCellData());
+	}
 }
 
 
-void iOrthoSlicer::GetUV(int Axis, int &Uidx, int &Vidx)
+void iOrthoSlicer::GetUV(int Axis, int &u, int &v)
 {
 	switch(Axis)
 	{
 	case 0:
 		{
-			Uidx = 1;
-			Vidx = 2;
+			u = 1;
+			v = 2;
 			return;
 		}
 	case 1:
 		{
-			Uidx = 0;
-			Vidx = 2;
+			u = 0;
+			v = 2;
 			return;
 		}
 	case 2:
 		{
-			Uidx = 0;
-			Vidx = 1;
+			u = 0;
+			v = 1;
 			return;
 		}
 	}
