@@ -37,7 +37,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparticlegroup.h"
 #include "ipiecewisefunction.h"
 #include "ipointglyph.h"
-#include "itune.h"
 #include "iviewmodule.h"
 
 #include <vtkCellArray.h>
@@ -169,12 +168,12 @@ void iParticleDataConverter::ProduceOutput()
 	vtkFloatArray *srcNmls = 0;
 	if(mPoint->GetOutput()->GetPointData()->GetNormals() != 0) 
 	{
-		srcNmls = iRequiredCast<vtkFloatArray>(mPoint->GetOutput()->GetPointData()->GetNormals());
+		srcNmls = iRequiredCast<vtkFloatArray>(INFO,mPoint->GetOutput()->GetPointData()->GetNormals());
 		sSrcNmls = 1;
 	}
 	else if(mPoint->GetOutput()->GetCellData()->GetNormals() != 0) 
 	{
-		srcNmls = iRequiredCast<vtkFloatArray>(mPoint->GetOutput()->GetCellData()->GetNormals());
+		srcNmls = iRequiredCast<vtkFloatArray>(INFO,mPoint->GetOutput()->GetCellData()->GetNormals());
 		sSrcNmls = -1;
 	}
 	float *srcNmlsArr = 0;
@@ -216,7 +215,7 @@ void iParticleDataConverter::ProduceOutput()
 #ifdef I_CHECK1
 				if(nCell1 != 2)
 				{
-					IERROR_REPORT("Line contains more than 2 points!");
+					IERROR_LOW("Line contains more than 2 points!");
 					break;
 				}
 #endif
@@ -307,10 +306,10 @@ void iParticleDataConverter::ProduceOutput()
 	int catt;
 	float cattLo = 0.0, cattHi = 0.0;
 	int cattSt = 0;
-	catt = iParticleGroup::RequiredCast(this->GetViewSubject())->GetAttributeToSize();
+	catt = iRequiredCast<iParticleGroup>(INFO,this->GetViewSubject())->GetAttributeToSize();
 	if(catt>=0 && this->GetLimits()->GetNumVars())
 	{
-		iParticleGroup *pg = iParticleGroup::RequiredCast(this->GetViewSubject());
+		iParticleGroup *pg = iRequiredCast<iParticleGroup>(INFO,this->GetViewSubject());
 		cattSt = pg->GetStretchToSize();
 		cattLo = iDataStretch::ApplyStretch(pg->GetLowerLimitToSize(),cattSt,false);
 		cattHi = iDataStretch::ApplyStretch(pg->GetUpperLimitToSize(),cattSt,true);
@@ -327,7 +326,7 @@ void iParticleDataConverter::ProduceOutput()
 	if(nOutPntsOff > 0) 
 	{
 		memcpy(outPnts->GetVoidPointer(0),inpPnts->GetVoidPointer(0),nInpPnts*3*sop);
-		if(wScalarDimIn > 0) iTune::CopyFloatPointers(wScalarPtrOut,wScalarPtrIn,nInpPnts*wScalarDimIn);
+		if(wScalarDimIn > 0) memcpy(wScalarPtrOut,wScalarPtrIn,nInpPnts*wScalarDimIn*sizeof(float));
 		if(sSrcNmls != 0) 
 		{
 			memset(outNmlsArr,0,nInpPnts*3*sizeof(float));
@@ -340,7 +339,7 @@ void iParticleDataConverter::ProduceOutput()
 	//
 	//  Prepare for direct scaling
 	//
-	iParticleGroup *myParticles = iParticleGroup::RequiredCast(this->GetViewSubject());
+	iParticleGroup *myParticles = iRequiredCast<iParticleGroup>(INFO,this->GetViewSubject());
 	iPiecewiseFunction *pFun = myParticles->GetSizeFunction()->GetFunction();
 
 	bool doDirect = myParticles->GetAttributeSizeDirect();
@@ -369,7 +368,7 @@ void iParticleDataConverter::ProduceOutput()
 #ifdef I_CHECK1
 		if(nCell1 != 1)
 		{
-			IERROR_REPORT("Vert contains more than 1 point!");
+			IERROR_LOW("Vert contains more than 1 point!");
 			break;
 		}
 #endif
@@ -442,7 +441,7 @@ void iParticleDataConverter::ProduceOutput()
 			outClls->InsertNextCell(nCell1,pCell2);
 			if(sSrcNmls < 0) // cell normals
 			{
-				iTune::CopyFloatPointers(outNmlsArr+3*llClls,srcNmlsArr+3*i,3);
+				for(j=0; j<3; j++) outNmlsArr[3*llClls+j] = srcNmlsArr[3*i+j];
 			}
 			llClls++;
 		}
@@ -453,17 +452,17 @@ void iParticleDataConverter::ProduceOutput()
 			if(rotate)
 			{
 				vtkMath::Multiply3x3(mat,x1,x2);
-				iTune::CopyDoublePointers(x1,x2,3); // this is the fastest assignment
+				for(j=0; j<3; j++) x1[j] = x2[j]; // this is the fastest assignment
 			}
 			for(j=0; j<3; j++) x1[j] = s*x1[j] + x0[j];
 			outPnts->SetPoint(llPnts,x1);
 			if(wScalarDimIn > 0) 
 			{
-				iTune::CopyFloatPointers(wScalarPtrOut+wScalarDimOut*llPnts,s0,wScalarDimIn);
+				for(j=0; j<wScalarDimIn; j++) wScalarPtrOut[wScalarDimOut*llPnts+j] = s0[j];
 			}
 			if(sSrcNmls > 0) // point normals 
 			{
-				iTune::CopyFloatPointers(outNmlsArr+3*llPnts,srcNmlsArr+3*i,3);
+				for(j=0; j<3; j++) outNmlsArr[3*llPnts+j] = srcNmlsArr[3*i+j];
 			}
 			llPnts++;
 		}
