@@ -29,8 +29,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparticlegroup.h"
 
 
-#include "ibasicdatadistributor.h"
+#include "icommondatadistributors.h"
+#include "icommoneventobservers.h"
+#include "icontrolmodule.h"
 #include "idatalimits.h"
+#include "idatasubject.h"
 #include "ierror.h"
 #include "ieventobserver.h"
 #include "ifunctionmapping.h"
@@ -46,8 +49,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodule.h"
 #include "iviewsubjectparallelpipeline.h"
 
+#include <vtkCamera.h>
 #include <vtkPolyData.h>
 #include <vtkProperty.h>
+#include <vtkRenderer.h>
 
 //
 //  Templates (needed for some compilers)
@@ -65,6 +70,7 @@ IOBJECT_DEFINE_KEY(iParticleGroup,AttributeSizeExtraFactor,ae,Float,1);
 IOBJECT_DEFINE_KEY(iParticleGroup,AttributeToSize,as,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iParticleGroup,AttributeToConnect,atc,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iParticleGroup,AttributeToSeparate,ats,OffsetInt,1);
+IOBJECT_DEFINE_KEY(iParticleGroup,AutoScaled,au,Bool,1);
 IOBJECT_DEFINE_KEY(iParticleGroup,StretchToColor,stc,Int,1);
 IOBJECT_DEFINE_KEY(iParticleGroup,LowerLimitToColor,ltc,Float,1);
 IOBJECT_DEFINE_KEY(iParticleGroup,UpperLimitToColor,utc,Float,1);
@@ -90,16 +96,19 @@ IVIEWSUBJECT_DEFINE_INHERITED_KEYS_PALETTE(iParticleGroup,1);
 namespace iParticleGroup_Private
 {
 	//
-	//  Helper class
+	//  Helper classes
 	//
-	class SizeFunctionEventObserver : public vtkCommand
+	class SizeFunctionEventObserver : public iEventObserver
 	{
 
 	public:
 
-		static SizeFunctionEventObserver* New(iPiecewiseFunction *fun)
+		vtkTypeMacro(SizeFunctionEventObserver,iEventObserver);
+		static SizeFunctionEventObserver* New(iPiecewiseFunction *fun = 0, iShell *s = 0)
 		{
-			return new SizeFunctionEventObserver(fun);
+			IERROR_ASSERT(fun);
+			IERROR_ASSERT(s);
+			return new SizeFunctionEventObserver(fun,s);
 		}
 
 		void AttachPipeline(iViewSubjectPipeline *pipe)
@@ -107,14 +116,9 @@ namespace iParticleGroup_Private
 			mPipeline = pipe;
 		}
 
-		virtual void Execute(vtkObject *caller, unsigned long event, void *)
-		{
-			if(caller==mFunction && event==vtkCommand::ModifiedEvent && mPipeline!=0) mPipeline->UpdateContents(iParticleGroupPipeline::_SizeFunction);
-		}
-
 	protected:
 
-		SizeFunctionEventObserver(iPiecewiseFunction *fun)
+		SizeFunctionEventObserver(iPiecewiseFunction *fun, iShell *s) : iEventObserver(s)
 		{
 			mFunction = fun; IERROR_ASSERT(fun);
 			mPipeline = 0;
@@ -122,9 +126,85 @@ namespace iParticleGroup_Private
 			mFunction->AddObserver(vtkCommand::ModifiedEvent,this);
 		}
 
+		virtual void ExecuteBody(vtkObject *caller, unsigned long event, void *)
+		{
+			if(caller==mFunction && event==vtkCommand::ModifiedEvent && mPipeline!=0) mPipeline->UpdateContents(iParticleGroupPipeline::_SizeFunction);
+		}
+
+	private:
+
 		iPiecewiseFunction *mFunction;
 		iViewSubjectPipeline *mPipeline;
 	};
+
+
+	class CameraEventObserver : public iEventObserver
+	{
+
+	public:
+
+		vtkTypeMacro(CameraEventObserver,iEventObserver);
+		static CameraEventObserver* New(iParticleGroup *parent = 0)
+		{
+			IERROR_ASSERT(parent);
+			return new CameraEventObserver(parent);
+		}
+
+		void Activate(bool s)
+		{
+			if(s)
+			{
+				mReferenceSize = mParent->GetFixedSize();
+				mParallelScale = mCamera->GetParallelScale();
+				mDistance = mCamera->GetDistance();
+			}
+			else
+			{
+				mReferenceSize = -1.0;
+			}
+		}
+
+	protected:
+
+		CameraEventObserver(iParticleGroup *parent) : iEventObserver(parent->GetViewModule()->GetControlModule()->GetShell())
+		{
+			mParent = parent;
+
+			mReferenceSize = -1.0;
+			mParallelScale = mDistance = 0.0;
+
+			mCamera = mParent->GetViewModule()->GetRenderer()->GetActiveCamera();
+			mCamera->AddObserver(vtkCommand::ModifiedEvent,this);
+			mCamera->Register(this);
+		}
+
+		~CameraEventObserver()
+		{
+			mCamera->RemoveObserver(this);
+			mCamera->UnRegister(this);
+		}
+
+		virtual void ExecuteBody(vtkObject *caller, unsigned long event, void *)
+		{
+			if(mReferenceSize>0.0 && caller==mCamera && event==vtkCommand::ModifiedEvent)
+			{
+				if(mCamera->GetParallelProjection() != 0)
+				{
+					mParent->SetFixedSize(mReferenceSize*mCamera->GetParallelScale()/mParallelScale);
+				}
+				else
+				{
+					mParent->SetFixedSize(mReferenceSize*mCamera->GetDistance()/mDistance);
+				}
+			}
+		}
+
+	private:
+
+		vtkCamera *mCamera;
+		iParticleGroup *mParent;
+		double mReferenceSize, mParallelScale, mDistance;
+	};
 }
 
 
@@ -133,28 +213,23 @@ using namespace iParticleGroup_Private;
 
 iParticleGroup* iParticleGroup::New(iParticlesViewSubject *parent)
 {
+	IERROR_ASSERT(parent);
 	iParticleGroup *tmp = new iParticleGroup(parent); IERROR_ASSERT(tmp);
 	tmp->Configure();
 	return tmp;
 }
 
 
-iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubject(parent->GetViewModule(),parent->GetDataType(),parent->GetObjectName(),1,0U)
+iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubject(parent->GetViewModule(),parent->GetDataType(),parent->GetObjectName(),2,_ViewSubjectSameColor|_ViewSubjectSameOpacity|_ViewSubjectSamePalette)
 {
 	mObjectType = _ObjectTypeParticles;
 
-	vtkPolyData *input = vtkPolyData::SafeDownCast(this->GetData()); // accepts any PolyData
-	if(input == 0)
-	{
-		IERROR_FINISH("iParticleGroup is configured incorrectly.");
-	}
-
 	mParent = parent;
 	mParentIndex = -1;
 
 	mAttSize = mAttColor = -1;
 
-	mAttSizeDirect = false;
+	mAttSizeDirect = mAutoScaled = false;
 	mAttSizeExtraFactor = 1.0;
 
 	mType = _PointTypePoint;
@@ -162,7 +237,6 @@ iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubjec
 	mStretchToColor = _StretchLog;
 	mLimitsToColor[0] = 0.1f;
 	mLimitsToColor[1] = 10.0f;
-	mKeepPoint = false;
 
 	mLineWidth = 1;
 	
@@ -174,15 +248,18 @@ iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubjec
 	mConnector = iParticleConnector::New(this); IERROR_ASSERT(mConnector);
 	mHistogramMaker = iHistogramMaker::New(this->GetViewModule()); IERROR_ASSERT(mHistogramMaker);
 	mFunction = new iFunctionMapping(mSF,mHistogramMaker,0); IERROR_ASSERT(mFunction);
-	mSizeFunctionEventObserver = SizeFunctionEventObserver::New(mSF);
-
-	mHistogramMaker->SetInput(mConnector->GetOutput(),-1);
+	mSizeFunctionEventObserver = SizeFunctionEventObserver::New(mSF,this->GetViewModule()->GetControlModule()->GetShell()); IERROR_ASSERT(mSizeFunctionEventObserver);
+	mCameraEventObserver = CameraEventObserver::New(this); IERROR_ASSERT(mCameraEventObserver);
 
 	iAbortRenderEventObserver *obsAbortRender = this->GetViewModule()->GetAbortRenderEventObserver();
 	mConnector->AddObserver(vtkCommand::ProgressEvent,obsAbortRender);
 
 	mActors[0]->GetProperty()->SetPointSize(mSize);
 	mActors[0]->GetProperty()->SetLineWidth(mLineWidth);
+	mActors[1]->GetProperty()->SetPointSize(1);
+	mActors[1]->GetProperty()->SetLineWidth(1);
+	mActors[1]->VisibilityOff();
+	mActors[1]->PickableOff();
 
 	this->SetColor(0,iColor(0,0,0));
 }
@@ -194,6 +271,7 @@ iParticleGroup::~iParticleGroup()
 	mSF->Register(this->Pipeline());
 	mSF->Delete();
 
+	mCameraEventObserver->Delete();
 	mSizeFunctionEventObserver->Delete();
 	mConnector->Delete();
 	mHistogramMaker->Delete();
@@ -207,7 +285,8 @@ void iParticleGroup::ConfigureBody()
 	//  Create pipeline (must be created after the object is fully created)
 	//	
 	this->AddMainPipeline(1);
-	mActors[0]->SetInput(this->Pipeline()->GetOutput(0));
+	mActors[0]->SetInput(mConnector->GetOutput());
+	mActors[1]->SetInput(this->Pipeline()->GetOutput(0));
 	this->Pipeline()->SetNthInput(0,mConnector->GetOutput());
 
 	this->SetStretchToColor(_StretchLog);
@@ -217,7 +296,7 @@ void iParticleGroup::ConfigureBody()
 
 void iParticleGroup::FinishInitialization()
 {
-	iPointerCast<SizeFunctionEventObserver,vtkCommand>(mSizeFunctionEventObserver)->AttachPipeline(this->Pipeline());
+	iRequiredCast<SizeFunctionEventObserver>(INFO,mSizeFunctionEventObserver)->AttachPipeline(this->Pipeline());
 }
 
 
@@ -228,11 +307,6 @@ void iParticleGroup::SetInput(vtkPolyData *input)
 }
 
 
-void iParticleGroup::ResetInput()
-{
-}
-
-
 void iParticleGroup::ResetPipeline()
 {
 }
@@ -249,14 +323,6 @@ void iParticleGroup::SetLineWidth(int w)
 }
 
 
-void iParticleGroup::SetShading(bool v)
-{
-	mShading = v;
-	this->SetType(mType); 
-	this->ClearCache();
-}
-
-
 void iParticleGroup::SetType(int t)
 { 
 	mType = t;
@@ -277,22 +343,19 @@ void iParticleGroup::SetType(int t)
 			mShading = true; 
 		}
 	}
-	this->UpdateMaterialProperties();
 
-	switch (mType)
+	if(mType == _PointTypePoint)
 	{
-	case _PointTypeCluster:
-	case _PointTypeGalaxy: 
-		{ 
-			mKeepPoint = true; 
-			break; 
-		}
-	default:
-		{
-			mKeepPoint = false;
-		}
+		mActors[0]->GetProperty()->SetPointSize(mSize);
+		mActors[1]->VisibilityOff();
 	}
-	if(mKeepPoint) mActors[0]->GetProperty()->SetPointSize(1.0); else mActors[0]->GetProperty()->SetPointSize(mSize); 
+	else
+	{
+		mActors[0]->GetProperty()->SetPointSize(1.0); 
+		mActors[1]->SetVisibility(mActors[0]->GetVisibility());
+	}
+
+	this->UpdateMaterialProperties();
 	this->ClearCache();
 }
 
@@ -304,12 +367,18 @@ void iParticleGroup::SetAttributeToColor(int a)
 	{
 		mActors[0]->SetScalarVisibility(true); 
 		mActors[0]->ColorByArrayComponent(0,mAttColor);
-		this->SetLowerLimitToColor(mLimitsToColor[0]);
-		this->SetUpperLimitToColor(mLimitsToColor[1]);
+		mActors[1]->SetScalarVisibility(true); 
+		mActors[1]->ColorByArrayComponent(0,mAttColor);
+		if(!this->GetSubject()->GetFixedLimits())
+		{
+			this->SetLowerLimitToColor(this->GetLimits()->GetMin(mAttColor));
+			this->SetUpperLimitToColor(this->GetLimits()->GetMax(mAttColor));
+		}
 	} 
 	else 
 	{
 		mActors[0]->SetScalarVisibility(false); 
+		mActors[1]->SetScalarVisibility(false); 
 	}
 	this->UpdateColorLookupTable();
 	this->ClearCache();
@@ -354,13 +423,25 @@ void iParticleGroup::SetFixedSize(float s)
 	if(s>0.0 && s<1000.1)
 	{
 		mSize = s;
-		if(mKeepPoint) mActors[0]->GetProperty()->SetPointSize(1.0); else mActors[0]->GetProperty()->SetPointSize(mSize); 
+		if(mType == _PointTypePoint) mActors[0]->GetProperty()->SetPointSize(mSize); 
 		this->Pipeline()->UpdateContents(iParticleGroupPipeline::_FixedSize);
 		this->ClearCache();
 	}
 }
 
 
+void iParticleGroup::SetAutoScaled(bool s)
+{
+	if(s != mAutoScaled)
+	{
+		mAutoScaled = s;
+		iRequiredCast<CameraEventObserver>(INFO,mCameraEventObserver)->Activate(s);
+		this->ClearCache();
+	}
+}
+
+
+
 void iParticleGroup::SetStretchToColor(int s)
 {
 	mStretchToColor = s;
@@ -397,6 +478,8 @@ void iParticleGroup::UpdateColorLookupTable()
 	{
 		mActors[0]->SetScalarRange(mLimitsToColor[0],mLimitsToColor[1]);
 		mActors[0]->GetLookupTable()->SetStretch(mStretchToColor);
+		mActors[1]->SetScalarRange(mLimitsToColor[0],mLimitsToColor[1]);
+		mActors[1]->GetLookupTable()->SetStretch(mStretchToColor);
 		this->ClearCache();
 	}
 }
@@ -480,10 +563,12 @@ void iParticleGroup::ShowBody(bool show)
 	{
 		this->SetStretchToColor(mStretchToColor);
 		mActors[0]->VisibilityOn();
+		if(mType != _PointTypePoint) mActors[1]->VisibilityOn();
 	} 
 	else 
 	{
 		mActors[0]->VisibilityOff();
+		mActors[1]->VisibilityOff();
 	}
 }
 
@@ -512,6 +597,7 @@ void iParticleGroup::SolidViewSubjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyAttributeSizeDirect(),mAttSizeDirect);
 	this->PackValue(s,KeyAttributeSizeExtraFactor(),mAttSizeExtraFactor);
 	this->PackValue(s,KeyLineWidth(),mLineWidth);
+	this->PackValue(s,KeyAutoScaled(),mAutoScaled);
 
 	this->PackValue(s,KeyAttributeToConnect(),this->GetAttributeToConnect());
 	this->PackValue(s,KeyAttributeToSeparate(),this->GetAttributeToSeparate());
@@ -537,6 +623,7 @@ void iParticleGroup::SolidViewSubjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyAttributeSizeDirect(),b)) this->SetAttributeSizeDirect(b);
 	if(this->UnPackValue(s,KeyAttributeSizeExtraFactor(),f)) this->SetAttributeSizeExtraFactor(f);
 	if(this->UnPackValue(s,KeyLineWidth(),i)) this->SetLineWidth(i);
+	if(this->UnPackValue(s,KeyAutoScaled(),b)) this->SetAutoScaled(b);
 	if(this->UnPackValue(s,KeyAttributeToConnect(),i)) this->SetAttributeToConnect(i);
 	if(this->UnPackValue(s,KeyAttributeToSeparate(),i)) this->SetAttributeToSeparate(i);
 	if(this->UnPackValuePiecewiseFunction(s,KeySizeFunction(),mSF)) this->ClearCache(); // this unpacks into the appropriate function automatically.
@@ -580,8 +667,24 @@ bool iParticleGroup::CanBeShown() const
 }
 
 
+iFunctionMapping* iParticleGroup::GetSizeFunction() const
+{
+	mCacheInvalid = true;
+	return mFunction;
+}
+
+
 void iParticleGroup::ViewSubjectSyncWithData(const iDataSyncRequest &r)
 {
+	if(this->IsThereData())
+	{
+		mHistogramMaker->SetInput(mConnector->GetOutput(),-1);
+	}
+	else
+	{
+		mHistogramMaker->SetInput(0,-1);
+	}
+
 	if(mAttColor > this->GetLimits()->GetNumVars()) this->SetAttributeToColor(-1);
 	if(mAttSize > this->GetLimits()->GetNumVars()) this->SetAttributeToSize(-1);
 	if(r.Var()>0 && r.Var()==mAttColor)
@@ -609,7 +712,7 @@ iViewSubjectPipeline* iParticleGroup::CreatePipeline(int)
 
 void iParticleGroup::ConfigureMainPipeline(iViewSubjectPipeline *p, int)
 {
-	iViewSubjectParallelPipeline *pp = iPointerCast<iViewSubjectParallelPipeline,iViewSubjectPipeline>(p);
+	iViewSubjectParallelPipeline *pp = iRequiredCast<iViewSubjectParallelPipeline>(INFO,p);
 
 	pp->GetDataManager()->AddDistributor(new iPolyDataDistributor(pp->GetDataManager()));
 	pp->GetDataManager()->AddCollector(new iPolyDataCollector(pp->GetDataManager(),0));
