@@ -35,7 +35,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ihistogrammaker.h"
 #include "irangecollection.h"
 #include "irangemapping.h"
-#include "itune.h"
 #include "iviewmodule.h"
 #include "iviewsubject.h"
 
@@ -101,9 +100,9 @@ bool Find(vtkIdType n, int ncom, int attSort, float *Atts, vtkIdType iStart, flo
 //
 //  QuickSort
 //
-#define SAVE(CELL,i1)    { for(ii=0; ii<3; ii++) poi##CELL[ii] = Points[3*(i1)+ii]; iTune::CopyFloatPointers(att##CELL,Atts+ncom*(i1),ncom); if(Nrms != 0) iTune::CopyFloatPointers(nrm##CELL,Nrms+3*(i1),3); }
-#define MOVE(i1,i2)      { for(ii=0; ii<3; ii++) Points[3*(i1)+ii] = Points[3*(i2)+ii]; iTune::CopyFloatPointers(Atts+ncom*(i1),Atts+ncom*(i2),ncom); if(Nrms != 0) iTune::CopyFloatPointers(Nrms+3*(i1),Nrms+3*(i2),3); }
-#define RESTORE(i2,CELL) { for(ii=0; ii<3; ii++) Points[3*(i2)+ii] = poi##CELL[ii]; iTune::CopyFloatPointers(Atts+ncom*(i2),att##CELL,ncom); if(Nrms != 0) iTune::CopyFloatPointers(Nrms+3*(i2),nrm##CELL,3); }
+#define SAVE(CELL,i1)    { for(ii=0; ii<3; ii++) poi##CELL[ii] = Points[3*(i1)+ii]; for(ii=0; ii<ncom; ii++) att##CELL[ii] = Atts[ncom*(i1)+ii]; if(Nrms != 0) for(ii=0; ii<3; ii++) nrm##CELL[ii] = Nrms[3*(i1)+ii]; }
+#define MOVE(i1,i2)      { for(ii=0; ii<3; ii++) Points[3*(i1)+ii] = Points[3*(i2)+ii]; for(ii=0; ii<ncom; ii++) Atts[ncom*(i1)+ii] = Atts[ncom*(i2)+ii]; if(Nrms != 0) for(ii=0; ii<3; ii++) Nrms[3*(i1)+ii] = Nrms[3*(i2)+ii]; }
+#define RESTORE(i2,CELL) { for(ii=0; ii<3; ii++) Points[3*(i2)+ii] = poi##CELL[ii]; for(ii=0; ii<ncom; ii++) Atts[ncom*(i2)+ii] = att##CELL[ii]; if(Nrms != 0) for(ii=0; ii<3; ii++) Nrms[3*(i2)+ii] = nrm##CELL[ii]; }
 #define SWAP(i1,i2)      { SAVE(1,i1); MOVE(i1,i2); RESTORE(i2,1); }
 
 //
@@ -576,7 +575,7 @@ void iParticleSplitter::ProduceOutput()
 #ifdef I_CHECK2
 		for(vtkIdType l=0; l<ntup-1; l++) if(pAtts[mAtt+ncom*l] > pAtts[mAtt+ncom*(l+1)])
 		{
-			IERROR_REPORT("Sorted incorrectly.");
+			IERROR_LOW("Sorted incorrectly.");
 			break;
 		}
 #endif
