@@ -47,7 +47,7 @@ class vtkFloatArray;
 class iParticleSplitter : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iParticleSplitter);
+	IGENERICFILTER_DECLARE(iParticleSplitter,vtkPolyDataToPolyDataFilter);
 
 public:
 	
@@ -87,6 +87,8 @@ protected:
 
 	virtual void ProduceOutput();
 	
+private:
+
 	void UpdateRange();
 
 	bool mRangeSet, mOwnsData;
