@@ -30,13 +30,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iactor.h"
+#include "icommoneventobservers.h"
 #include "idata.h"
+#include "idataformatter.h"
+#include "idatahelper.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatasubject.h"
 #include "ierror.h"
-#include "ieventobserver.h"
-#include "iextensionfactory.h"
+#include "iobjectfactory.h"
 #include "iprobefilter.h"
 #include "iviewmodule.h"
 #include "iviewsubjectobserver.h"
@@ -74,6 +76,8 @@ IOBJECT_DEFINE_KEY(iPicker,PointSize,ps,Float,1);
 
 namespace iPicker_Private
 {
+	const int NumPickMethods = 3;
+
 	class CellPicker : public vtkCellPicker
 	{
 
@@ -123,6 +127,92 @@ namespace iPicker_Private
 			return 0; // we do not highlight the picked prop
 		}
 	};
+
+
+	class PickHandler : public vtkPicker
+	{
+
+	public:
+
+		static PickHandler* New(iPicker *parent)
+		{
+			return new PickHandler(parent);
+		}
+
+		virtual vtkAssemblyPath* GetPath()
+		{
+			return 0; // we do not highlight the picked prop
+		}
+
+		virtual int Pick(double x, double y, double z, vtkRenderer *ren)
+		{
+			int pm = mParent->GetPickMethod();
+
+			if(pm>=0 && pm<NumPickMethods)
+			{
+				vtkPicker *p = vtkPicker::SafeDownCast(mDevices[pm]);
+				if(p != 0) p->SetTolerance(this->GetTolerance());
+
+				this->InvokeEvent(vtkCommand::StartPickEvent,0);
+				int ret = mDevices[pm]->Pick(x,y,z,ren);
+				mDevices[pm]->GetPickPosition(this->PickPosition);
+				this->SetPath(mDevices[pm]->vtkAbstractPropPicker::GetPath());
+				mParent->UpdateReport();
+				this->InvokeEvent(vtkCommand::EndPickEvent,0);
+
+				return ret;
+			}
+			else
+			{
+				vtkErrorMacro("Invalid pick method.");
+				return 0;
+			}
+		}
+
+		virtual void Modified()
+		{
+			int i;
+			for(i=0; i<NumPickMethods; i++) mDevices[i]->Modified();
+			this->vtkAbstractPropPicker::Modified();
+		}
+
+	private:
+
+		PickHandler(iPicker *parent)
+		{
+			mParent = parent; IERROR_ASSERT(parent);
+
+			//
+			//  Pickers
+			//
+			mDevices[0] = CellPicker::New(); IERROR_ASSERT(mDevices[0]);
+			mDevices[1] = PointPicker::New(); IERROR_ASSERT(mDevices[1]);
+			mDevices[2] = ObjectPicker::New(); IERROR_ASSERT(mDevices[2]);
+
+			//
+			//  Observer
+			//
+			mObserver = iPickEventObserver::New(mParent->GetViewModule()); IERROR_ASSERT(mObserver);
+			this->AddObserver(vtkCommand::StartPickEvent,mObserver);
+			this->AddObserver(vtkCommand::EndPickEvent,mObserver);
+			int i;
+			for(i=0; i<NumPickMethods; i++)
+			{
+				mDevices[i]->AddObserver(vtkCommand::AbortCheckEvent,mParent->GetViewModule()->GetAbortRenderEventObserver());
+			}
+		}
+
+		~PickHandler()
+		{
+			int i;
+			for(i=0; i<NumPickMethods; i++) mDevices[i]->Delete();
+			mObserver->Delete();
+		}
+
+		iPicker *mParent;
+		iPickEventObserver *mObserver;
+		vtkAbstractPropPicker *mDevices[NumPickMethods];
+	};
 };
 
 
@@ -132,38 +222,27 @@ using namespace iPicker_Private;
 	
 iPicker* iPicker::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	iPicker *tmp = new iPicker(vm); IERROR_ASSERT(tmp);
-	iExtensionFactory::InstallExtensions(tmp);
+	iObjectFactory::InstallExtensions(tmp);
 	return tmp;
 }
 
 
-iPicker::iPicker(iViewModule *vm) : iDataFormatter(vm), mPos(vm), mNumPickMethods(3)
+iPicker::iPicker(iViewModule *vm) : iExtendableObject("Picker"), mViewModule(vm), mDataFormatter(vm), mPos(vm)
 {
-	int i;
-
 	mObjName = "";
 	mObjType = _ObjectTypeUndefined;
 	mDataTypePointer = 0;
 	mPickMethod = _PickMethodObject;
 
 	//
-	//  Pickers
+	//  Handler
 	//
-	mDevices[0] = CellPicker::New(); IERROR_ASSERT(mDevices[0]);
-	mDevices[1] = PointPicker::New(); IERROR_ASSERT(mDevices[1]);
-	mDevices[2] = ObjectPicker::New(); IERROR_ASSERT(mDevices[2]);
+	mHandler = PickHandler::New(this); IERROR_ASSERT(mHandler);
 
 	this->SetAccuracy(0.02f);
 
-	mObserver = iPickEventObserver::New(this->GetViewModule()); IERROR_ASSERT(mObserver);
-	this->AddObserver(vtkCommand::StartPickEvent,mObserver);
-	this->AddObserver(vtkCommand::EndPickEvent,mObserver);
-	for(i=0; i<mNumPickMethods; i++)
-	{
-		mDevices[i]->AddObserver(vtkCommand::AbortCheckEvent,this->GetViewModule()->GetAbortRenderEventObserver());
-	}
-
 	//
 	//  Graphical representation
 	//
@@ -198,9 +277,7 @@ iPicker::iPicker(iViewModule *vm) : iDataFormatter(vm), mPos(vm), mNumPickMethod
 
 iPicker::~iPicker()
 {
-	int i;
-	mObserver->Delete();
-	for(i=0; i<mNumPickMethods; i++) mDevices[i]->Delete();
+	mHandler->Delete();
 	this->GetViewModule()->RemoveObject(mPointActor);
 	mPointActor->Delete();
 	mPointSource->Delete();
@@ -208,20 +285,9 @@ iPicker::~iPicker()
 }
 
 
-int iPicker::Pick(double x, double y, double z, vtkRenderer *ren)
-{
-	this->InvokeEvent(vtkCommand::StartPickEvent,0);
-	int ret = mDevices[mPickMethod]->Pick(x,y,z,ren);
-	this->InvokeEvent(vtkCommand::EndPickEvent,0);
-	return ret;
-}
-
-
 void iPicker::Modified()
 {
-	int i;
-	for(i=0; i<mNumPickMethods; i++) mDevices[i]->Modified();
-	vtkAbstractPropPicker::Modified();
+	mHandler->Modified();
 	this->ClearCache();
 }
 
@@ -229,12 +295,12 @@ void iPicker::Modified()
 void iPicker::UpdateReport()
 {
 	mObjName = "Unknown";
-	mPos = mDevices[mPickMethod]->GetPickPosition();
+	mPos = mHandler->GetPickPosition();
 
 	this->SetPointSize(mPointSize);
 	mPointActor->SetPosition(mPos);
 
-	this->ClearReport();
+	mDataFormatter->ClearReport();
 	this->UpdateReportBody(); // this can replace mPointObject via its extensions
 
 	mPointActor->SetInput(mPointSource->GetOutput());
@@ -244,13 +310,16 @@ void iPicker::UpdateReport()
 	//
 	//  Check if extensions want to modify the point actor
 	//
-	int i;
-	for(i=0; i<mExtensions.Size(); i++) if(iPickerExtension::RequiredCast(mExtensions[i])->IsUsingData(mDataTypePointer))
+	if(mDataTypePointer != 0)
 	{
-		iPickerExtension::RequiredCast(mExtensions[i])->ModifyActor(mPointActor); // the last installed extension prevails
+		int i;
+		for(i=0; i<mExtensions.Size(); i++) if(iRequiredCast<iPickerExtension>(INFO,mExtensions[i])->IsUsingData(*mDataTypePointer))
+		{
+			iRequiredCast<iPickerExtension>(INFO,mExtensions[i])->ModifyActor(*mDataTypePointer,mPointActor); // the last installed extension prevails
+		}
 	}
 
-	this->ShowPickedPoint(true);
+	this->ShowPickedPoint(mDataTypePointer != 0);
 }
 
 
@@ -263,9 +332,9 @@ void iPicker::UpdateReportBody()
 	//  Get the object info
 	//
 #ifdef IVTK_4
-	vtkProp *obj = mDevices[mPickMethod]->GetProp();
+	vtkProp *obj = mHandler->GetProp();
 #else
-	vtkProp *obj = mDevices[mPickMethod]->GetViewProp();
+	vtkProp *obj = mHandler->GetViewProp();
 #endif
 	if(obj == 0) 
 	{
@@ -273,7 +342,7 @@ void iPicker::UpdateReportBody()
 		mPointActor->VisibilityOff(); 
 		return;
 	}
-	iViewSubjectObserver *obs = iPointerCast<iViewSubjectObserver,vtkCommand>(obj->GetCommand(1));
+	iViewSubjectObserver *obs = iRequiredCast<iViewSubjectObserver>(INFO,obj->GetCommand(1));
 
 	if(obs != 0)
 	{
@@ -293,89 +362,47 @@ void iPicker::UpdateReportBody()
 	//
 	if(mDataTypePointer == 0) return;
 
-	iDataLimits *lim = this->GetViewModule()->GetReader()->GetLimits(*mDataTypePointer);
+	iDataSubject *subject = this->GetViewModule()->GetReader()->GetSubject(*mDataTypePointer);
+	iDataLimits *lim = subject->GetLimits();
 
-	if(mDataTypePointer->IsOfClass(iData::ParticleSet()))
+	//
+	//  Use the ProbeFilter to find attribute values
+	//
+	mProbeInput->GetPoints()->SetPoint(0,mPos);
+	iProbeFilter *probe = subject->CreateProbeFilter(obs->GetSubject());
+	probe->SetInput(mProbeInput);
+	probe->SetSource(subject->GetData());
+	probe->Update();
+	vtkPolyData *out = probe->GetPolyDataOutput();
+
+	if(out==0 || out->GetPointData()==0)
 	{
-		//
-		//  Do particles separately using a PointLocator - a faster approach
-		//
-		vtkDataSet *ds = this->GetViewModule()->GetReader()->GetOutput(*mDataTypePointer);
-		if(ds->IsA("vtkPolyData"))
-		{
-			vtkPolyData *data = vtkPolyData::SafeDownCast(ds);
-			vtkPointLocator *locator = vtkPointLocator::New(); IERROR_ASSERT(locator);
-			locator->SetDataSet(data);
-			vtkIdType pid = locator->FindClosestPoint(mDevices[mPickMethod]->GetPickPosition());
-			vtkFloatArray *s = vtkFloatArray::SafeDownCast(data->GetPointData()->GetScalars());
-			if(s != 0)
-			{
-				float *p = s->GetPointer(pid);
-				int natt = s->GetNumberOfComponents();
-				if(p!=0 && natt>0 && pid>=0 && pid<data->GetNumberOfPoints())
-				{
-					this->FormatScalarData(lim,natt,p);
-				}
-			}
-			locator->Delete();
-		}
-		else
-		{
-			IERROR_REPORT("ParticleSet data is not vtkPolyData - cannot pick.");
-		}
+		IERROR_LOW("Unable to probe data for the picked object");
+		return;
 	}
-	else
+
+	//
+	//  Ask extensions to provide extra information
+	//
+	int i;
+	for(i=0; i<mExtensions.Size(); i++) if(iRequiredCast<iPickerExtension>(INFO,mExtensions[i])->IsUsingData(*mDataTypePointer))
 	{
-		//
-		//  For a field, use the ProbeFilter will to find attribute values
-		//
-		iDataSubject *subject = this->GetViewModule()->GetReader()->GetSubject(*mDataTypePointer);
-
-		mProbeInput->GetPoints()->SetPoint(0,mPos);
-		iProbeFilter *probe = subject->CreateProbeFilter(obs->GetSubject());
-		probe->SetInput(mProbeInput);
-		probe->SetSource(subject->GetData());
-		probe->Update();
-		vtkPolyData *out = probe->GetPolyDataOutput();
-		
-		if(out==0 || out->GetPointData()==0)
-		{
-			IERROR_REPORT("Unable to probe data for the picked object");
-			return;
-		}
-
-		vtkDataArray *d = 0;
-		int i, nvar = 0;
-		switch(mDataTypePointer->GetRank())
-		{
-		case 0U:
-			{
-				d = out->GetPointData()->GetScalars();
-				nvar = lim->GetNumVars();
-				break;
-			}
-		case 1U:
-			{
-				d = out->GetPointData()->GetVectors();
-				nvar = 3;
-				break;
-			}
-		case 2U:
-			{
-				d = out->GetPointData()->GetTensors();
-				nvar = 9;
-				break;
-			}
-		}
+		iRequiredCast<iPickerExtension>(INFO,mExtensions[i])->AddInfo(*mDataTypePointer);
+	}
 
+	iDataHelper h(out);
+	vtkDataArray *d = 0;
+	int nvar = 0;
+	if(h.IsThereScalarData())
+	{
+		d = out->GetPointData()->GetScalars();
+		nvar = lim->GetNumVars();
 		if(d==0 || nvar<1 || d->GetNumberOfComponents()!=nvar || !d->IsA("vtkFloatArray"))
 		{
-			IERROR_REPORT("Unable to probe data for the picked object");
+			IERROR_LOW("Unable to probe data for the picked object");
 			return;
 		}
-
 		float *v = (float *)d->GetVoidPointer(0);
-
 		//
 		//  Make the correction for the surface
 		//
@@ -384,36 +411,36 @@ void iPicker::UpdateReportBody()
 			j = obs->GetIsoSurfaceData().Var;
 			if(j>=0 && j<nvar) v[j] = obs->GetIsoSurfaceData().Level;
 		}
-
-		//
-		//  Ask extensions to provide extra information
-		//
-		for(i=0; i<mExtensions.Size(); i++) if(iPickerExtension::RequiredCast(mExtensions[i])->IsUsingData(mDataTypePointer))
-		{
-			iPickerExtension::RequiredCast(mExtensions[i])->AddInfo(probe);
-		}
-
-		switch(mDataTypePointer->GetRank())
-		{
-		case 0U:
-			{
-				this->FormatScalarData(lim,nvar,v);
-				break;
-			}
-		case 1U:
-			{
-				this->FormatVectorData(lim,-1,v);
-				break;
-			}
-		case 2U:
-			{
-				this->FormatTensorData(lim,-1,v);
-				break;
-			}
-		}
-
-		probe->Delete();
+		mDataFormatter->FormatScalarData(lim,nvar,v);
 	}
+
+	if(h.IsThereVectorData())
+	{
+		d = out->GetPointData()->GetVectors();
+		nvar = 3;
+		if(d==0 || nvar<1 || d->GetNumberOfComponents()!=nvar || !d->IsA("vtkFloatArray"))
+		{
+			IERROR_LOW("Unable to probe data for the picked object");
+			return;
+		}
+		float *v = (float *)d->GetVoidPointer(0);
+		mDataFormatter->FormatVectorData(lim,-1,v);
+	}
+
+	if(h.IsThereTensorData())
+	{
+		d = out->GetPointData()->GetTensors();
+		nvar = 9;
+		if(d==0 || nvar<1 || d->GetNumberOfComponents()!=nvar || !d->IsA("vtkFloatArray"))
+		{
+			IERROR_LOW("Unable to probe data for the picked object");
+			return;
+		}
+		float *v = (float *)d->GetVoidPointer(0);
+		mDataFormatter->FormatTensorData(lim,-1,v);
+	}
+
+	probe->Delete();
 }
 
 
@@ -450,7 +477,7 @@ void iPicker::ExtendableObjectPackStateBody(iString &s) const
 {
 	this->PackValue(s,KeyPickMethod(),mPickMethod);
 	this->PackValue(s,KeyPointSize(),mPointSize);
-	this->PackValue(s,KeyAccuracy(),mAccuracy);
+	this->PackValue(s,KeyAccuracy(),float(mHandler->GetTolerance()));
 }
 
 
@@ -466,7 +493,7 @@ void iPicker::ExtendableObjectUnPackStateBody(const iString &s)
 
 void iPicker::SetPickMethod(int s)
 {
-	if(s>=0 && s<mNumPickMethods)
+	if(s>=0 && s<NumPickMethods)
 	{
 		mPickMethod = s;
 		this->ClearCache();
@@ -478,15 +505,7 @@ void iPicker::SetAccuracy(float s)
 {
 	if(s > 0.0f)
 	{
-		mAccuracy = s;
-		
-		int j;
-		vtkPicker *p;
-		for(j=0; j<mNumPickMethods; j++)
-		{
-			p = dynamic_cast<vtkPicker*>(mDevices[j]);
-			if(p != 0) p->SetTolerance(s);
-		}
+		mHandler->SetTolerance(s);
 		this->ClearCache();
 	}
 }
