@@ -31,35 +31,32 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iextendableobject.h"
-#include <vtkAbstractPropPicker.h>
-#include "idataformatter.h"
 
 
 #include "iposition.h"
 
 class iActor;
+class iDataFormatter;
 class iDataType;
-class iPickEventObserver;
-class iProbeFilter;
 
+class vtkPicker;
 class vtkPolyData;
 class vtkSphereSource;
 
 
-class iPicker : public iExtendableObject, public vtkAbstractPropPicker, public iDataFormatter
+class iPicker : public iExtendableObject
 {
 
-	friend class iPickEventObserver;
+	IPOINTER_AS_PART(ViewModule);
+	IPOINTER_AS_USER(DataFormatter);
 
 public:
 
-	vtkTypeMacro(iPicker,vtkAbstractPropPicker);
-	IOBJECT_DECLARE_SELF(iPicker,iExtendableObject);
-
+	vtkTypeMacro(iPicker,iExtendableObject);
 	static iPicker* New(iViewModule *vm = 0);
 	static const iObjectType& Type();
 
-	IOBJECT_DECLARE_GETSET1(Accuracy,float);
+	IOBJECT_DECLARE_GETSET2(Accuracy,float);
 	IOBJECT_DECLARE_GETSET1(PickMethod,int);
 	IOBJECT_DECLARE_GETSET1(PointSize,float);
 
@@ -68,33 +65,33 @@ public:
 
 	void ShowPickedPoint(bool s);
 
-	virtual int Pick(double x, double y, double z, vtkRenderer *ren);
+	inline vtkPicker* GetHandler() const { return mHandler; }
+
+	void UpdateReport();
 	virtual void Modified();
 
 protected:
-	
+
 	iPicker(iViewModule *vm);
 	virtual ~iPicker();
 
 	virtual void ExtendableObjectPackStateBody(iString &) const;
 	virtual void ExtendableObjectUnPackStateBody(const iString &);
 
-	void UpdateReport();
 	virtual void UpdateReportBody();
 
+private:
+
 	iPosition mPos;
 	iString mObjName;
-	int mObjType;
+	int mObjType, mPickMethod;
 	const iDataType *mDataTypePointer;
-	int mPickMethod;
-	const int mNumPickMethods;
 	vtkPolyData *mProbeInput;
 
 	//
-	//  Actual pickers
+	//  Actual workers
 	//
-	vtkAbstractPropPicker *mDevices[3];
-	iPickEventObserver *mObserver;
+	vtkPicker *mHandler;
 
 	//
 	//  Graphical representation
@@ -112,9 +109,9 @@ class iPickerExtension : public iObjectExtension
 
 public:
 
-	virtual bool IsUsingData(const iDataType *ptype) const = 0;
-	virtual void ModifyActor(iActor *actor) = 0;
-	virtual void AddInfo(iProbeFilter *probe) = 0;
+	virtual bool IsUsingData(const iDataType &type) const = 0;
+	virtual void ModifyActor(const iDataType &type, iActor *actor) = 0;
+	virtual void AddInfo(const iDataType &type) = 0;
 };
 
 #endif  // IPICKER_H
