@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iReducePolyDataFilter2 : public iGenericPolyDataToPolyDataFilter<vtkQuadricDecimation>
 {
 	
-	IGENERICFILTER_DECLARE(iReducePolyDataFilter2);
+	IGENERICFILTER_DECLARE(iReducePolyDataFilter2,vtkQuadricDecimation);
 	
 protected:
 	
