@@ -34,9 +34,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icamera.h"
 #include "icontrolmodule.h"
 #include "ierror.h"
+#include "ieventobserver.h"
 #include "iextensionfactory.h"
 #include "ilightkit.h"
 #include "imagnifier.h"
+#include "irendertoolbackground.h"
 #include "ishell.h"
 #include "ishellfactory.h"
 #include "istereoimage.h"
@@ -44,7 +46,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodule.h"
 
 #include <vtkActor2D.h>
-#include <vtkCommand.h>
+#include <vtkCamera.h>
 #include <vtkCuller.h>
 #include <vtkCullerCollection.h>
 #include <vtkLight.h>
@@ -69,80 +71,81 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Helper classes
 //
-class iDualWindowObserver : public vtkCommand
+class iDualWindowObserver : public iEventObserver
 {
 
 public:
 
-	static iDualWindowObserver* New(iRenderTool *rv)
+	vtkTypeMacro(iDualWindowObserver,iEventObserver);
+	static iDualWindowObserver* New(iRenderTool *rt = 0)
 	{
-		return new iDualWindowObserver(rv);
-	}
-
-	void Block(bool s)
-	{
-		mIsBlocked = s;
-	}
-
-	virtual void Execute(vtkObject * /*caller*/, unsigned long event, void * /*callData*/)
-	{
-		if(mIsBlocked || (event!=StartEvent && event!=EndEvent && event!=ModifiedEvent)) return;
-		
-		if(event == StartEvent)
-		{
-			if(mRenderTool->mMainWin->GetStereoRender() == 0)
-			{
-				if(mRenderTool->mDualWin != 0) mRenderTool->ShowDualWindow(false); 
-			}
-			else
-			{
-				if(mRenderTool->mDualWin == 0) mRenderTool->ShowDualWindow(true); 
-			}
-		}
-
-		if(event == EndEvent)
-		{
-			if(mRenderTool->mDualWin != 0) mRenderTool->mDualWin->Render();
-		}
-
-		if(event == ModifiedEvent)
-		{
-			if(mRenderTool->mDualWin != 0) mRenderTool->mDualWin->SetSize(mRenderTool->mMainWin->GetSize());
-		}
+		IERROR_ASSERT(rt);
+		return new iDualWindowObserver(rt);
 	}
 
 protected:
 
-	iDualWindowObserver(iRenderTool *rv)
+	iDualWindowObserver(iRenderTool *rt) : iEventObserver(rt->GetViewModule()->GetControlModule()->GetShell())
 	{
-		mRenderTool = rv;
-		mIsBlocked = false;
+		mRenderTool = rt;
 	}
 
-	bool mIsBlocked;
+	virtual void ExecuteBody(vtkObject *, unsigned long event, void *)
+	{
+		switch(event)
+		{
+		case StartEvent:
+			{
+				if(mRenderTool->mMainWin->GetStereoRender() == 0)
+				{
+					if(mRenderTool->mDualWin != 0) mRenderTool->ShowDualWindow(false); 
+				}
+				else
+				{
+					if(mRenderTool->mDualWin == 0) mRenderTool->ShowDualWindow(true); 
+				}
+				break;
+			}
+		case EndEvent:
+			{
+				if(mRenderTool->mDualWin != 0) mRenderTool->mDualWin->Render();
+				break;
+			}
+		case ModifiedEvent:
+			{
+				if(mRenderTool->mDualWin != 0) mRenderTool->mDualWin->SetSize(mRenderTool->mMainWin->GetSize());
+				break;
+			}
+		}
+	}
+
+private:
+
 	iRenderTool *mRenderTool;
 };
 
 
-class iRendererObserver : public vtkCommand
+class iRendererObserver : public iEventObserver
 {
 
 public:
 
-	static iRendererObserver* New(iRenderTool *rv)
+	vtkTypeMacro(iRendererObserver,iEventObserver);
+	static iRendererObserver* New(iRenderTool *rt = 0)
 	{
-		return new iRendererObserver(rv);
+		IERROR_ASSERT(rt);
+		return new iRendererObserver(rt);
 	}
 
-	void Block(bool s)
+protected:
+
+	iRendererObserver(iRenderTool *rt) : iEventObserver(rt->GetViewModule()->GetControlModule()->GetShell())
 	{
-		mIsBlocked = s;
+		mRenderTool = rt;
 	}
 
-	virtual void Execute(vtkObject * /*caller*/, unsigned long event, void * /*callData*/)
+	virtual void ExecuteBody(vtkObject *, unsigned long event, void *)
 	{
-		if(mIsBlocked) return;
-
 		switch(event)
 		{
 		case ModifiedEvent:
@@ -168,15 +171,8 @@ public:
 		}
 	}
 
-protected:
+private:
 
-	iRendererObserver(iRenderTool *rv)
-	{
-		mRenderTool = rv;
-		mIsBlocked = false;
-	}
-
-	bool mIsBlocked;
 	iRenderTool *mRenderTool;
 };
 
@@ -186,29 +182,31 @@ protected:
 //
 iRenderTool* iRenderTool::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	iRenderTool *tmp =  iExtensionFactory::CreateRenderTool(vm);
 	IERROR_ASSERT(tmp);
 	return tmp;
 }
 
 
-iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : iViewModuleComponent(vm), mObservers(Observer())
+iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : mViewModule(vm)
 {
 	//
 	//  Main Window stuff
 	//
+	mDualWin = 0;
 	mMainWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mMainWin);
 	if(ren == 0)
 	{
 		mMainRen = vtkRenderer::New(); IERROR_ASSERT(mMainRen);
 		mMainInt = iShellFactory::CreateRenderWindowInteractor(this); IERROR_ASSERT(mMainInt);
 		mMainCam = iCamera::New(this); IERROR_ASSERT(mMainCam);
-		mMainRen->SetActiveCamera(mMainCam);
-		mMainCam->Delete();
+		mMainRen->SetActiveCamera(mMainCam->GetDevice());
 		//
 		//  Configure Renderer. It is important to switch the backing store off for the
 		//  stereo mode to work properly.
 		//
+		mMainRen->SetLayer(IRENDERTOOLBACKGROUND_FRONT_LAYER);
 		mMainRen->BackingStoreOff();
 		mMainRen->TwoSidedLightingOff();
 		mMainRen->LightFollowCameraOn();
@@ -238,18 +236,25 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 		mMagnifier->Register(ren);
 	}
 
+	//
+	//  Create backgrounds
+	//
+	mMainBkg = iRenderToolBackground::New(); IERROR_ASSERT(mMainBkg);
+	mDualBkg = iRenderToolBackground::New(); IERROR_ASSERT(mDualBkg);
+
 	//
 	//  Configure Window
 	//
 	mMainWin->SetSize(640,480);
 	mMainWin->StereoCapableWindowOn();
+	mMainWin->SetNumberOfLayers(2);
+	mMainWin->AddRenderer(mMainBkg->GetRenderer());
 	mMainWin->AddRenderer(mMainRen);
 	mMainWin->SetWindowName("IFrIT - Visualization Window");
 
 	//
 	//  Dual window renderer and observer
 	//
-	mDualWin = 0;
 	mDualRen = this->CreateRenderer();
 
 	mDualRen->SetActiveCamera(mMainRen->GetActiveCamera());
@@ -361,6 +366,7 @@ iRenderTool::~iRenderTool()
 
 	if(mLights != 0) mLights->Delete();
 	if(mMainInt != 0) mMainInt->Delete();
+	if(mMainCam != 0) mMainCam->Delete();
 
 	mMainRen->SetRenderWindow(0);
 	mMainWin->RemoveRenderer(mMainRen);
@@ -395,38 +401,37 @@ void iRenderTool::Render()
 
 void iRenderTool::ResetCamera()
 {
-	double *dp = mMainRen->GetActiveCamera()->GetDirectionOfProjection();
-	int idir = 1; if(dp[0] > 0.0) idir = -1;
-	double dmax = fabs(dp[0]);
-	if(fabs(dp[1]) > dmax)
-	{
-		dmax = fabs(dp[1]);
-		idir = 2; if(dp[1] > 0.0) idir = -2;
-	}
-	if(fabs(dp[2]) > dmax)
-	{
-		idir = 3; if(dp[2] > 0.0) idir = -3;
-	}
+	const double scale = 1.6/sqrt(3.0);
 
-	mMainRen->GetActiveCamera()->SetFocalPoint(0.0,0.0,0.0);
-	mMainRen->GetActiveCamera()->SetPosition(0.0,0.0,7.0);
-	mMainRen->GetActiveCamera()->SetViewUp(0.0,1.0,0.0);
-	mMainRen->GetActiveCamera()->SetParallelScale(1.6);
+	int i;
+	double bounds[6], fp[3];
+	mMainRen->ComputeVisiblePropBounds(bounds);
+	mMainRen->GetActiveCamera()->GetFocalPoint(fp);
 
-	switch (idir)
+	for(i=0; i<3; i++)
 	{
-	case  1: { mMainRen->GetActiveCamera()->Azimuth(90.0); break; }
-	case -1: { mMainRen->GetActiveCamera()->Azimuth(-90.0); break; }
-	case  2: { mMainRen->GetActiveCamera()->Elevation(90.0); mMainRen->GetActiveCamera()->SetViewUp(0.0,0.0,-1.0); break; }
-	case -2: { mMainRen->GetActiveCamera()->Elevation(-90.0); mMainRen->GetActiveCamera()->SetViewUp(0.0,0.0,1.0); break; }
-	case  3: { break; }
-	case -3: { mMainRen->GetActiveCamera()->Azimuth(180.0); break; }
+		if(fabs(bounds[2*i+0]-fp[i]) > fabs(bounds[2*i+1]-fp[i]))
+		{
+			bounds[2*i+1] = 2*fp[i] - bounds[2*i+0];
+		}
+		else
+		{
+			bounds[2*i+0] = 2*fp[i] - bounds[2*i+1];
+		}
 	}
+	mMainRen->ResetCamera(bounds);
+
+	//
+	//  IFrIT-style reset
+	//
+	mMainCam->GetDevice()->SetParallelScale(scale*mMainCam->GetDevice()->GetParallelScale());
+	mMainCam->GetDevice()->Dolly(1.0/scale);
 
 	mMainRen->ResetCameraClippingRange();
 }
 
-void iRenderTool::AddObserver(unsigned long event, vtkCommand *command)
+
+void iRenderTool::AddObserver(unsigned long event, iEventObserver *command)
 {
 	Observer tmp;
 
@@ -484,10 +489,20 @@ void iRenderTool::ResetCameraClippingRange()
 }
 
 
-void iRenderTool::SetBackground(iColor &color)
+void iRenderTool::SetBackground(const iColor &color)
 {
 	mMainRen->SetBackground(color.ToVTK());
 	mDualRen->SetBackground(color.ToVTK());
+
+	mMainBkg->SetColor(color);
+	mDualBkg->SetColor(color);
+}
+
+
+void iRenderTool::SetBackground(const iImage &image)
+{
+	mMainBkg->SetImage(image);
+	mDualBkg->SetImage(image);
 }
 
 
@@ -569,7 +584,9 @@ void iRenderTool::SetAntialiasing(bool s)
 			mDualWin->SetPointSmoothing(0);
 		}
  	}
-	vtkOpenGLRenderWindow *w = dynamic_cast<vtkOpenGLRenderWindow*>(mMainWin);
+
+#ifndef I_OFFSCREEN
+	vtkOpenGLRenderWindow *w = vtkOpenGLRenderWindow::SafeDownCast(mMainWin);
 	if(w != 0)
 	{
 		w->MakeCurrent();
@@ -577,13 +594,14 @@ void iRenderTool::SetAntialiasing(bool s)
 	}
 	if(mDualWin != 0)
 	{
-		w = dynamic_cast<vtkOpenGLRenderWindow*>(mDualWin);
+		w = vtkOpenGLRenderWindow::SafeDownCast(mDualWin);
 		if(w != 0)
 		{
 			w->MakeCurrent();
 			w->OpenGLInit();
 		}
 	}
+#endif
 }
 
 
@@ -638,7 +656,6 @@ void iRenderTool::RenderStereoImage(int mag, iStereoImage &image)
 	mMagnifier->SetInput(mMainRen);
 	mMagnifier->Modified();
 	mMagnifier->UpdateWholeExtent();
-	mMagnifier->Update();
 	image.ReplaceData(0,mMagnifier->GetOutput());
 	mMainRen->SetLightFollowCamera(lfc);
 
@@ -733,7 +750,7 @@ void iRenderTool::ShowDualWindow(bool s)
 		{
 			if(mMainWin->GetStereoRender() == 0)
 			{
-				IERROR_REPORT("Creating DualWindow in the non-stereo mode.");
+				IERROR_LOW("Creating DualWindow in the non-stereo mode.");
 			}
 			mDualWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mDualWin);
 			int *s = mMainWin->GetSize();
@@ -754,6 +771,8 @@ void iRenderTool::ShowDualWindow(bool s)
 			mDualWin->SetLineSmoothing(mMainWin->GetLineSmoothing());
 			mDualWin->SetPointSmoothing(mMainWin->GetPointSmoothing());
 
+			mDualWin->SetNumberOfLayers(2);
+			mDualWin->AddRenderer(mDualBkg->GetRenderer());
 			mDualWin->AddRenderer(mDualRen);
 	
 			if(mStereoAlignmentMarkersActor!=0 && mStereoAlignmentMarkersOn) mStereoAlignmentMarkersActor->VisibilityOn();
@@ -766,7 +785,9 @@ void iRenderTool::ShowDualWindow(bool s)
 		{
 			this->WindowsModified();
 			mDualRen->SetRenderWindow(0);
+			mDualBkg->GetRenderer()->SetRenderWindow(0);
 			mDualWin->RemoveRenderer(mDualRen);
+			mDualWin->RemoveRenderer(mDualBkg->GetRenderer());
 			mDualWin->Delete();
 			mDualWin = 0;
 
@@ -788,6 +809,8 @@ vtkRenderer* iRenderTool::CreateRenderer() const
 	vtkRenderer *ren = vtkRenderer::New();
 	if(ren == 0) return 0;
 
+	ren->SetLayer(IRENDERTOOLBACKGROUND_FRONT_LAYER);
+
 	//
 	//  Copy the state of the primary renderer
 	//
@@ -837,3 +860,9 @@ vtkRenderer* iRenderTool::CreateRenderer() const
 	return ren;
 }
 
+
+int iRenderTool::GetFullScreenMode() const
+{
+	return 1;
+}
+
