@@ -41,7 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iReplicatedGridData : public iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>, protected iParallelWorker, public iReplicated
 {
 
-	IGENERICFILTER_DECLARE(iReplicatedGridData);
+	IGENERICFILTER_DECLARE(iReplicatedGridData,vtkStructuredPointsToStructuredPointsFilter);
 
 public:
 
@@ -51,10 +51,12 @@ protected:
 	
 	virtual void InitExecution();
 	virtual void ProduceOutput();
-	virtual void UpdateReplicas();
+	virtual void UpdateReplicasBody();
 
 	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
 
+private:
+
 	//
 	//  Work variables
 	//
