@@ -31,7 +31,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 #include "imath.h"
-#include "itune.h"
 #include "iviewmodule.h"
 
 #include <vtkCellArray.h>
@@ -175,7 +174,7 @@ iReplicatedPolyData::iReplicatedPolyData(iViewSubject *vo) : iGenericPolyDataToP
 }
 
 
-void iReplicatedPolyData::UpdateReplicas()
+void iReplicatedPolyData::UpdateReplicasBody()
 {
 	this->Modified();
 }
@@ -392,8 +391,8 @@ void iReplicatedPolyData::ExtendDirection(vtkPolyData *input, vtkPolyData *outpu
 			for(i=0; i<npts && i<maxCellSize; i++) pts[i] = pts1[i] + noff;
 			osrp->InsertNextCell(npts,pts);
 		}
-		if(nsca > 0) iTune::CopyFloatPointers(optrsca+off*nsca,iptrsca,nsca);
-		if(nnor > 0) iTune::CopyFloatPointers(optrnor+off*nnor,iptrnor,nnor);
+		if(nsca > 0) memcpy(optrsca+off*nsca,iptrsca,nsca*sizeof(float));
+		if(nnor > 0) memcpy(optrnor+off*nnor,iptrnor,nnor*sizeof(float));
 		off++;
 	}
 	
