@@ -40,7 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iReplicatedPolyData : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>, public iReplicated
 {
 
-	IGENERICFILTER_DECLARE(iReplicatedPolyData);
+	IGENERICFILTER_DECLARE(iReplicatedPolyData,vtkPolyDataToPolyDataFilter);
 
 public:
 
@@ -54,7 +54,9 @@ public:
 protected:
 	
 	virtual void ProduceOutput();
-	virtual void UpdateReplicas();
+	virtual void UpdateReplicasBody();
+
+private:
 
 	void ExtendDirection(vtkPolyData *input, vtkPolyData *output, int dim, int extDown, int extUp);
 };
