@@ -286,6 +286,10 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 	tmp->DefineSpecificCommandLineOptions();
 	tmp->ParseCommandLineOptions(argc,argv);
 
+#ifdef I_DEBUG
+	//tmp->mNumProcs = 2;
+#endif
+
 	if(tmp->mScriptFileName.IsEmpty())
 	{
 		tmp->PrepareForConstruction();
@@ -397,10 +401,10 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 		iControlScript *cs = tmp->mControlModule->GetControlScript();
 		iConsole::Display(iConsole::_Info,"Compiling the script...");
 
-		cs->Run(text,true);
-		if(cs->GetErrorStatus()->IsError())
+		cs->SetText(text);
+		if(!cs->Compile())
 		{
-			iConsole::Display(iConsole::_FatalError,iString("Syntax error in script, line ")+iString::FromNumber(cs->GetCurrentLine())+" : "+cs->GetErrorStatus()->Message());
+			iConsole::Display(iConsole::_FatalError,iString("Syntax error in script, line ")+iString::FromNumber(cs->GetThisLine())+" : "+cs->GetErrorStatus()->Message());
 			return 0;
 		}
 
@@ -408,11 +412,11 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 
 		iConsole::Display(iConsole::_Info,"Running the script...");
 		BatchModeObserver *obs = new BatchModeObserver(cs);
-		cs->Run(text);
+		cs->Execute();
 		if(obs != 0) delete obs;
 		if(cs->GetErrorStatus()->IsError())
 		{
-			iConsole::Display(iConsole::_HighError,iString("Runtime error in script, line ")+iString::FromNumber(cs->GetCurrentLine())+" : "+cs->GetErrorStatus()->Message());
+			iConsole::Display(iConsole::_HighError,iString("Runtime error in script, line ")+iString::FromNumber(cs->GetThisLine())+" : "+cs->GetErrorStatus()->Message());
 		}
 		else iConsole::Display(iConsole::_Info,"Done.");
 
