@@ -30,11 +30,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "idata.h"
+#include "idatahelper.h"
 #include "idatalimits.h"
 #include "ierror.h"
 #include "imath.h"
-#include "itune.h"
-#include "iuniformgriddatasubject.h"
 #include "iviewmodule.h"
 
 #include <vtkCellArray.h>
@@ -205,7 +204,7 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 	float *ptrNorms = 0;
 	if(source->GetPointData() != 0) 
 	{
-		vtkFloatArray *sn = dynamic_cast<vtkFloatArray*>(source->GetPointData()->GetNormals());
+		vtkFloatArray *sn = iRequiredCast<vtkFloatArray>(INFO,source->GetPointData()->GetNormals());
 		ptrNorms = sn->GetPointer(0);
 	}
 
@@ -305,8 +304,11 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 				//  Locate the starting point
 				//
 				l = l0;
-				iTune::CopyFloatPointers(v1,v0,3);
-				iTune::CopyDoublePointers(x1,x0,3);
+				for(i=0; i<3; i++)
+				{
+                    v1[i] = v0[i];
+					x1[i] = x0[i];
+				}
 				 
 				if(ptrNorms != 0)
 				{
@@ -559,7 +561,9 @@ bool iStreamLineFilter::DefinePointers(vtkImageData *input)
 
 void iStreamLineFilter::AssignScalars(float *p, vtkIdType l)
 {
-	iTune::CopyFloatPointers(p,wPtrSca+wNsca*l,wNsca);
+	int i;
+	float *org = wPtrSca + wNsca*l;
+	for(i=0; i<wNsca; i++) p[i] = org[i]; // # of scalars is likely to be small, no reason to do memcpy
 }
 
 
@@ -578,7 +582,7 @@ vtkIdType iStreamLineFilter::GetVector(double x[3], float v[3], float *ptrvec, i
 
 	bool per[3];
 	limits->GetPeriodicities(per);
-	iUniformGridDataSubject::GetCICInterpolation(per,dims,org,spa,x,ijk1,ijk2,w1,w2);
+	iDataHelper::CIC(per,dims,org,spa,x,ijk1,ijk2,w1,w2);
 
 	//
 	//  Vectors of the CIC neigbors
