@@ -87,10 +87,15 @@ public:
     int Find(char c, int index = 0) const;
     int Find(const char *str, int index = 0) const;
     int Find(const iString &str, int index = 0) const;  // inlined below
+    int FindIgnoringWhiteSpace(const iString &str, int index = 0, int *last = 0) const;
+	int FindFromSet(const char *set, int index = 0, int *length = 0) const;
+	void Replace(int index, char c);
 	void Replace(int index, int len, const iString &str);
 	void Replace(const iString &tar, const iString &str, int index = 0, bool once = false); 
 	iString Substitute(const iString &tar, const iString &str) const;
+	bool IsAt(const iString &str, int index) const;
 	bool EndsWith(const iString &str) const;
+	bool IsWhiteSpace(int i) const;
 
 	//
 	//  Getting parts of the string
@@ -107,11 +112,12 @@ public:
     static iString FromNumber(float n, const char *format = "%g");
     static iString FromNumber(double n, const char *format = "%lg");
     static iString FromNumber(void *n);
+    static iString FromNumber(bool n);
 	
 	int ToInt(bool &ok) const;
 	float ToFloat(bool &ok) const;
 	double ToDouble(bool &ok) const;
-	void * ToPointer(bool &ok) const;
+	void* ToPointer(bool &ok) const;
 
 	//
 	//  Using strings as buffers
@@ -122,8 +128,10 @@ public:
 	//  Formatting functions
 	//
 	void ReduceWhiteSpace();
-	void RemoveFormatting(const iString &tokBeg, const iString &tokEnd);
+	void RemoveWhiteSpace();
+	void RemoveFormatting(const iString &tokBeg, const iString &tokEnd, bool multiLevel = false);
 	void ReformatHTMLToText(int length = 0);
+	void FindTokenMatch(const iString &tokBeg, int &indBeg, const iString &tokEnd, int &indEnd, int index = 0, bool multiLevel = false) const;
 
 private:
 
@@ -197,6 +205,17 @@ inline bool iString::operator!=(const iString &str) const
 	return !(*this==str);
 }
 
+
+inline bool iString::IsWhiteSpace(int i) const
+{
+	if(i>=0 && i<mLen)
+	{
+		char p = this->operator[](i);
+		return p==32 || (p>=9 && p<=13);
+	}
+	else return false;
+}
+
 #endif // ISTRING_H
  
 
