@@ -37,6 +37,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iTensorGlyphFilter::iTensorGlyphFilter(iViewSubject *vo) : iGenericFilter<vtkTensorGlyph,vtkDataSet,vtkPolyData>(vo,1,true,false)
 {
+	this->ColorGlyphsOn();
+	this->SetColorModeToScalars();
 }
 
 
