@@ -37,33 +37,40 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkProp.h>
-#include "ioverlaybase.h"
 
 
-#include "icolor.h"
 #include "iparameter.h"
 #include "istring.h"
 
+#include "ipointermacro.h"
+
+class iOverlayHelper;
+class iRenderTool;
+
 class vtkViewport;
 
 
-class iText: public vtkProp, public iOverlayBase
+class iText: public vtkProp
 {
 	
+	IPOINTER_AS_USER(OverlayHelper);
+
 public:
 
 	virtual int RenderOverlay(vtkViewport *v) = 0;
 	virtual int RenderOpaqueGeometry(vtkViewport *v) = 0;
-	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
+	virtual int RenderTranslucentGeometry(vtkViewport * ){ return 0; }
 	virtual void ReleaseGraphicsResources(vtkWindow *w);
 	
-	virtual void SetColor(iColor &c){ mColor = c; }
-	virtual void SetBold(bool s){ mBold = s; }
-	virtual void SetHJustification(int s){ if(s>=0 && s<iParameter::__NumTextJusts) mHorJust = s; }
-	virtual void SetVJustification(int s){ if(s>=0 && s<iParameter::__NumTextJusts) mVerJust = s; }
-	virtual void SetPosition(float p[2]){ mPos[0] = p[0]; mPos[1] = p[1]; }
-	virtual void SetPosition(float p0, float p1){ mPos[0] = p0; mPos[1] = p1; }
-	virtual void Rotate(float a){ mAngle = a; }
+	void SetFontScale(int s){ mFontScale = s; }
+	inline int GetFontScale() const { return mFontScale; }
+
+	void SetBold(bool s){ mBold = s; }
+	void SetHJustification(int s){ if(s>=0 && s<iParameter::__NumTextJusts) mHorJust = s; }
+	void SetVJustification(int s){ if(s>=0 && s<iParameter::__NumTextJusts) mVerJust = s; }
+	void SetPosition(float p[2]){ mPos[0] = p[0]; mPos[1] = p[1]; }
+	void SetPosition(float p0, float p1){ mPos[0] = p0; mPos[1] = p1; }
+	void Rotate(float a){ mAngle = a; }
 
 	inline bool GetBold() const { return mBold; }
 	inline const float* GetPosition() const { return mPos; }
@@ -71,20 +78,19 @@ public:
 
 	virtual void GetSize(vtkViewport *v, float s[2]) = 0;
 
-	virtual void SetText(const iString &s);
+	void SetText(const iString &s);
 
 protected:
 	
-	iText(const iRenderTool *rv);
+	iText(iRenderTool *rv);
 	virtual ~iText();
 
 	void SetActorPosition(vtkViewport *viewport);
 
 	bool mBold;
-	int mHorJust, mVerJust;
+	int mHorJust, mVerJust, mFontScale;
 	float mPos[2], mActorPos[2];
 	float mAngle;
-	iColor mColor;
 	float mSize[2];
 	iString mText;
 };
