@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "ioverlayhelper.h"
 #include "iviewmodule.h"
 
 #include <vtkActor2D.h>
@@ -38,15 +39,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkViewport.h>
 
 
-iTextBitmap::iTextBitmap(const iRenderTool *rv) : iText(rv)
+iTextBitmap* iTextBitmap::New(iRenderTool *rt)
+{
+	IERROR_ASSERT(rt);
+	return new iTextBitmap(rt);
+}
+
+
+iTextBitmap::iTextBitmap(iRenderTool *rt) : iText(rt)
 {
 	mMapper = vtkTextMapper::New(); IERROR_ASSERT(mMapper);
 	mActor = vtkActor2D::New(); IERROR_ASSERT(mActor);
 	mActor->SetMapper(mMapper);
 	mActor->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
 
-	mMapper->GetTextProperty()->SetFontFamilyToArial();
-	mMapper->GetTextProperty()->ShadowOn();
 	mMapper->GetTextProperty()->SetJustificationToLeft(); 
 	mMapper->GetTextProperty()->SetVerticalJustificationToBottom();
 }
@@ -63,7 +69,8 @@ void iTextBitmap::GetSize(vtkViewport *viewport, float s[2])
 {
 	mMapper->SetInput(mText.ToCharPointer());
 
-	mMapper->GetTextProperty()->SetFontSize(this->GetFontSize(viewport));
+	mMapper->GetTextProperty()->SetFontSize(this->GetOverlayHelper()->GetFontSize(viewport,exp(0.3*mFontScale)));
+	this->GetOverlayHelper()->UpdateTextProperty(mMapper->GetTextProperty()); 
 	if(mBold) mMapper->GetTextProperty()->BoldOn(); else mMapper->GetTextProperty()->BoldOff();
 
 	double w = (float)mMapper->GetWidth(viewport);
@@ -90,13 +97,14 @@ int iTextBitmap::RenderOverlay(vtkViewport* viewport)
 
 int iTextBitmap::RenderOpaqueGeometry(vtkViewport* viewport)
 {
-	int mag = this->GetRenderingMagnification();
+	int mag = this->GetOverlayHelper()->GetRenderingMagnification();
+	mMapper->GetTextProperty()->SetFontSize(this->GetOverlayHelper()->GetFontSize(viewport,exp(0.3*mFontScale)*mag));
 
 	if(mag == 1)
 	{
 		this->SetActorPosition(viewport);
 
-		mMapper->GetTextProperty()->SetColor(mColor.ToVTK());
+		mMapper->GetTextProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
 
 		mActor->SetPosition(mActorPos[0],mActorPos[1]);
 		mActor->SetPosition2(mSize[0],mSize[1]);
@@ -104,12 +112,10 @@ int iTextBitmap::RenderOpaqueGeometry(vtkViewport* viewport)
 	else
 	{
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(winij);
+		this->GetOverlayHelper()->ComputePositionShiftsUnderMagnification(winij);
 		
 		mActor->SetPosition(mag*mActorPos[0]-winij[0],mag*mActorPos[1]-winij[1]);
 		mActor->SetPosition2(mag*mSize[0],mag*mSize[1]);
-
-		mMapper->GetTextProperty()->SetFontSize(this->GetFontSize(viewport,mag));
 	}
 
 	mActor->RenderOpaqueGeometry(viewport);
