@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 #include "imath.h"
+#include "ioverlayhelper.h"
 #include "itransform.h"
 #include "iviewmodule.h"
 
@@ -46,7 +47,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkVectorText.h>
 
 
-iTextVector::iTextVector(const iRenderTool *rv) : iText(rv)
+iTextVector* iTextVector::New(iRenderTool *rt)
+{
+	IERROR_ASSERT(rt)
+	return new iTextVector(rt);
+}
+
+
+iTextVector::iTextVector(iRenderTool *rt) : iText(rt)
 {
 	mSource = vtkVectorText::New(); IERROR_ASSERT(mSource);
 	mTransform = iTransform::New(); IERROR_ASSERT(mTransform);
@@ -82,7 +90,7 @@ iTextVector::~iTextVector()
 
 void iTextVector::GetSize(vtkViewport *viewport, float s[2])
 {
-	int mag = this->GetRenderingMagnification();
+	int mag = this->GetOverlayHelper()->GetRenderingMagnification();
 
 	float cosa = cos(mAngle*0.017453292);
 	float sina = sin(mAngle*0.017453292);
@@ -91,7 +99,7 @@ void iTextVector::GetSize(vtkViewport *viewport, float s[2])
 	mSource->Update();
 	double *b = mSource->GetOutput()->GetBounds();
 	
-	float ff = this->GetFontSize(viewport);
+	float ff = this->GetOverlayHelper()->GetFontSize(viewport,exp(0.3*mFontScale));
 	float w = 0.618*(b[1]-b[0])*ff;
 	float h = 0.953*ff;
 	float wt = w*fabs(cosa) + h*fabs(sina);
@@ -155,14 +163,14 @@ int iTextVector::RenderOpaqueGeometry(vtkViewport* viewport)
 
 	this->GetSize(viewport,mSize);
 
-	int mag = this->GetRenderingMagnification();
+	int mag = this->GetOverlayHelper()->GetRenderingMagnification();
 
 	if(mag == 1)
 	{
 		this->SetActorPosition(viewport);
 
-		mActor->GetProperty()->SetColor(mColor.ToVTK());
-		mActorShadow->GetProperty()->SetColor(mColor.Shadow().ToVTK());
+		mActor->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+		mActorShadow->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).Shadow().ToVTK());
 
 		mActor->SetPosition(mActorPos[0],mActorPos[1]);
 		mActor->SetPosition2(mSize[0],mSize[1]);
@@ -173,7 +181,7 @@ int iTextVector::RenderOpaqueGeometry(vtkViewport* viewport)
 	else
 	{
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(winij);
+		this->GetOverlayHelper()->ComputePositionShiftsUnderMagnification(winij);
 		
 		mActor->SetPosition(mag*mActorPos[0]-winij[0],mag*mActorPos[1]-winij[1]);
 		mActor->SetPosition2(mag*mSize[0],mag*mSize[1]);
