@@ -37,6 +37,17 @@ iTransform* iTransform::New()
 	return new iTransform;
 }
 
+
+iTransform::iTransform()
+{
+}
+
+
+iTransform::~iTransform()
+{
+}
+
+
 //
 // transform so that Z-axis becomes this direction 
 //
