@@ -31,9 +31,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iextendableobject.h"
-#include "icontrolmodulecomponent.h"
-#include "ierrorstatusholder.h"
-#include "ideletable.h"
 
 
 #include "iarray.h"
@@ -47,16 +44,17 @@ class iActor;
 class iActorCollection;
 class iAnimator;
 class iCaptionInteractorStyle;
+class iCameraOrthoActor;
 class iClipPlane;
 class iColor;
 class iColorBars;
+class iControlModule;
 class iCrossSectionViewSubject;
 class iCubeAxesActor;
 class iDataConsumer;
 class iDataReader;
 class iDataSyncRequest;
 class iDataType;
-class iImageComposer;
 class iInteractorEventRecorder;
 class iLegend;
 class iMarker;
@@ -105,17 +103,17 @@ class vtkTimerLog;
 	i##_name_##ViewSubject* Get##_name_##ViewSubject(int n = -1) const
 
 
-class iViewModule : public iExtendableObject, public iControlModuleComponent, public iErrorStatusHolder, public iDeletable
+class iViewModule : public iExtendableObject
 {
 	
 	friend class iControlModule;
-	friend class iExtensionFactory;
+
+	IPOINTER_AS_PART(ControlModule);
 
 public:
 
-	IOBJECT_DECLARE_SELF(iViewModule,iExtendableObject);
-
-	static iViewModule* New(iControlModule *cm);
+	vtkTypeMacro(iViewModule,iExtendableObject);
+	static iViewModule* New(iControlModule *cm = 0);
 	static const iObjectType& Type();
 		
 	IOBJECT_DECLARE_GETSET(UpdateRate,mRate,int);
@@ -126,11 +124,13 @@ public:
 	IOBJECT_DECLARE_GETSET1(FontType,int);
 	IOBJECT_DECLARE_GETSET1(Antialiasing,bool);
 	IOBJECT_DECLARE_GETSET1(MarkerLegendPosition,int);
-	IOBJECT_DECLARE_GETSET(BackgroundColor,mBgColor,const iColor&);
+	IOBJECT_DECLARE_GETSET(BackgroundColor,mBackgroundColor,const iColor&);
+	IOBJECT_DECLARE_GETSET(BackgroundImage,mBackgroundImage,const iString&);
 
 	static const iObjectKey& KeyFontSize();
 
 	IOBJECT_DECLARE_GETSET2(RulerScale,float);
+	IOBJECT_DECLARE_GETSET2(RulerTitle,const iString&);
 	IOBJECT_DECLARE_GETSET2(OpenGLCoordinates,bool);
 	IOBJECT_DECLARE_GETSET2(Stereo,bool);
 	IOBJECT_DECLARE_GETSET2(StereoType,int);
@@ -151,6 +151,10 @@ public:
 	//virtual void SetLabelUnit(const iString &s);
 	//inline const iString& GetLabelUnit() const { return mLabelUnit; }
 
+	IOBJECT_DECLARE_GETSET1(LabelOffset,float);
+	//virtual void SetLabelOffset(float v);
+	//inline float GetLabelOffset() const { return mLabelOffset; }
+
 	IOBJECT_DECLARE_GETSET1(LabelScale,float);
 	//virtual void SetLabelScale(float v);
 	//inline float GetLabelScale() const { return mLabelScale; }
@@ -163,7 +167,7 @@ public:
 //	int GetWindowNumber() const { return mWinNum; }
 	IOBJECT_DECLARE_GET2(CloneOfWindow,int);
 //	int GetCloneOfWindow() const;
-	bool IsClone() const;
+	bool IsClone(iViewModule *vm = 0) const;
 	static const iObjectKey& KeyNoClone();
 
 	//
@@ -183,6 +187,7 @@ public:
 	IVIEWMODULE_DECLARE_ISSHOW(GlassClipPlane);
 	IVIEWMODULE_DECLARE_ISSHOW(MarkerLegend);
 	IVIEWMODULE_DECLARE_ISSHOW(StereoAlignmentMarkers);
+	IVIEWMODULE_DECLARE_ISSHOW(CameraAlignmentLabel);
 
 	virtual void ShowLabel(bool s, float *v = 0);
     inline bool IsLabelVisible() const { return mIsLabelOn; } 
@@ -283,8 +288,8 @@ public:
 
 	iViewObject* GetParticlesObject(int n = -1) const;
 
-	inline iViewObjectFamily* GetViewObjectFamily(int n) const { return mViewObjectFamilies[n]; }
-	inline int GetNumberOfGetViewObjectFamilies() const { return mViewObjectFamilies.Size(); }
+	inline iViewObjectFamily* GetViewObjectFamily(int n) const { if(n>=0 && n<mViewObjectFamilies.Size()) return mViewObjectFamilies[n]; else return 0; }
+	inline int GetNumberOfViewObjectFamilies() const { return mViewObjectFamilies.Size(); }
 
 	IVIEWMODULE_DECLARE_VIEWSUBJECT(CrossSection);
 	IVIEWMODULE_DECLARE_VIEWSUBJECT(Particles);
@@ -298,8 +303,6 @@ public:
 	virtual int GetThisImageWidth();  // Get the image size of this window only
 	virtual int GetThisImageHeight();
 
-	void SetImageComposer(iImageComposer *ic);
-
 	inline bool IsRenderingImage() const { return mInImageRender; }
 	void ForceCrossSectionToUsePolygonalMethod(bool s);
 
@@ -312,13 +315,18 @@ public:
 	void SetDebugMode(bool s);
 
 protected:
-	
-	iViewModule(iControlModule *cm);
+
 	virtual ~iViewModule();
 
 	virtual void ExtendableObjectPackStateBody(iString &s) const;
 	virtual void ExtendableObjectUnPackStateBody(const iString &s);
 
+private:
+	
+	iViewModule(iControlModule *cm);
+
+	void NotifyDataConsumersBody(const iDataSyncRequest &r);
+
 	//
 	//  Members
 	//
@@ -328,12 +336,13 @@ protected:
 	iViewModule *mCloneOfModule;
 	iPointerArray<iViewModule> mClones;
 
-	iColor mBgColor;
+	iColor mBackgroundColor;
+	iString mBackgroundImage;
 	iStereoImageArray mImages;
 
 	bool mIsDebug, mInImageRender;
 
-	bool mIsLabelOn, mIsColorBarsOn, mIsBoundingBoxOn, mIsRulerOn, mIsMeasuringBoxOn;
+	bool mIsLabelOn, mIsColorBarsOn, mIsBoundingBoxOn, mIsRulerOn, mIsMeasuringBoxOn, mIsCameraAlignmentLabelOn;
 	bool mIsGlassClipPlaneOn, mIsClipPlaneOn, mAntialiasing;
 	bool mLabelJustificationLeft, mIsMarkerLegendOn, mIsStereoAlignmentMarkersOn;
 
@@ -341,7 +350,7 @@ protected:
 	float mBoxSize, mUpdateTime;
 
 	iString mLabelName, mLabelUnit;
-	float mLabelScale;
+	float mLabelScale, mLabelOffset;
 	int mLabelDigits;
 
 	//
@@ -361,6 +370,7 @@ protected:
 	iTextActor *mLabelActor;
 	iMeasuringBox *mMeasuringBox;
 	iColorBars *mColorBars;
+	iCameraOrthoActor *mCameraOrthoActor;
 
 	//
 	//  Prop registries
@@ -372,7 +382,6 @@ protected:
 	//
 	iAnimator *mAnimator;
 	iDataReader *mDataReader;
-	iImageComposer *mImageComposer;
 	iInteractorEventRecorder *mEventRecorder;
 	iLegend *mMarkerLegend;
 	iPicker *mPicker;
@@ -405,9 +414,9 @@ protected:
 };
 
 
-inline bool iViewModule::IsClone() const
+inline bool iViewModule::IsClone(iViewModule *vm) const
 {
-	return mCloneOfModule != 0;
+	if(vm == 0)	return (mCloneOfModule != 0); else return (mCloneOfModule == vm);
 }
 
 
