@@ -36,7 +36,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iobject.h"
 #include "imultitypedataconsumer.h"
-#include "ideletable.h"
 
 
 #include "iarray.h"
@@ -47,9 +46,11 @@ class iViewSubject;
 ///
 //  Helper intermediate class (need to avoid constructor recurrence)
 //
-class iViewObjectParent : public iViewModuleComponent
+class iViewObjectParent
 {
 	
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 		
 	iViewObjectParent(iViewModule *vm, const iObjectType &ot, const iDataType &dt);
@@ -67,17 +68,15 @@ protected:
 //
 //  Main class
 //
-class iViewObject : public iObject, public iMultiTypeDataConsumer, public iDeletable
+class iViewObject : public iObject, public iMultiTypeDataConsumer
 {
 	
-//	friend class iControlModule;
-	friend class iExtensionFactory;
+	friend class iObjectFactory;
 
 public:
 	
-	IOBJECT_DECLARE_SELF(iViewObject,iObject);
-
-	static iViewObject* New(iViewObjectParent *parent);
+	vtkTypeMacro(iViewObject,iObject);
+	static iViewObject* New(iViewObjectParent *parent = 0);
 
 	iViewSubject* GetViewSubject(int obs = -1) const;
 	iViewSubject* GetViewSubject(const iDataType &type) const;
@@ -93,7 +92,6 @@ public:
 
 protected:
 	
-	iViewObject(iViewObjectParent *parent, bool synced, bool single);
 	virtual ~iViewObject();
 
 	virtual void PackStateBody(iString &s) const;
@@ -102,6 +100,10 @@ protected:
 	virtual void UpdateDataType(int prev);
 	virtual void SyncWithDataBody(const iDataSyncRequest &r);
 
+private:
+
+	iViewObject(iViewObjectParent *parent, bool synced, bool single);
+
 	//
 	//  Members
 	//
@@ -109,8 +111,6 @@ protected:
 	iViewObjectParent *mParent;
 	iArray<iViewSubject*> mSubjects;
 
-private:
-
 	//
 	//  Constructor helpers accessible to iExtensionFactory only
 	//
