@@ -31,11 +31,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iviewfamily.h"
-#include "iviewmodulecomponent.h"
 
 
 class iDataType;
 class iObjectType;
+class iViewModule;
 class iViewObject;
 class iViewObjectParent;
 
@@ -59,6 +59,10 @@ public:
 
 protected:
 
+	virtual ~iViewObjectFamily();
+
+private:
+
 	iViewObjectFamily(iViewObjectParent *parent, bool singleInstance);
 
 	const bool mIsSingleInstance;
