@@ -29,11 +29,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewsubject.h"
 
 
+#include "icamera.h"
+#include "idatahelper.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "ierror.h"
 #include "imarker.h"
 #include "imarkerfamily.h"
+#include "ipicker.h"
+#include "irendertool.h"
 #include "iviewmodule.h"
 #include "iviewsubjectobserver.h"
 #include "iviewsubjectparallelpipeline.h"
@@ -48,6 +52,7 @@ using namespace iParameter;
 
 IVIEWSUBJECT_DEFINE_TYPE(iViewSubject,ViewSubject,-vo);  // helper type
 
+IOBJECT_DEFINE_KEY(iViewSubject,AttachToMarker,am,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iViewSubject,DataType,dt,Int,1);
 IOBJECT_DEFINE_KEY(iViewSubject,ClipPlane,cp,Bool,1);
 IOBJECT_DEFINE_KEY(iViewSubject,DataPresent,dp,Bool,1);
@@ -57,11 +62,15 @@ IOBJECT_DEFINE_KEY(iViewSubject,SpecularPower,mp,Float,1);
 IOBJECT_DEFINE_KEY(iViewSubject,Specular,ms,Float,1);
 IOBJECT_DEFINE_KEY(iViewSubject,Shading,mw,Bool,1);
 IOBJECT_DEFINE_KEY(iViewSubject,NumReplicas,nr,Int,6);
+IOBJECT_DEFINE_KEY(iViewSubject,DirectionIsPeriodic,-dp,Bool,3);
 IOBJECT_DEFINE_KEY(iViewSubject,Ready,r,Bool,1);
+IOBJECT_DEFINE_KEY(iViewSubject,MoveTo,to,Int,1);
 IOBJECT_DEFINE_KEY(iViewSubject,Visible,vis,Bool,1);
 
+IOBJECT_DEFINE_POSITION_KEY(iViewSubject,Position,x);
 
-iViewSubject::iViewSubject(iViewModule *vm, const iDataType &type, const iString &name, unsigned int flags) : iDataConsumer(vm,type), iReplicated(0,false), mObjectName(name), mPosition(vm), mAlwaysShaded((flags&_ViewSubjectAlwaysShaded)!=0U), mNoReplicating((flags&_ViewSubjectNoReplicating)!=0U), mPipelines(0)
+
+iViewSubject::iViewSubject(iViewModule *vm, const iDataType &type, const iString &name, unsigned int flags) : iObject(name), iDataConsumer(vm,type), iReplicated(0,false), mObjectName(name), mPosition(vm), mAlwaysShaded((flags&_ViewSubjectAlwaysShaded)!=0U), mNoReplicating((flags&_ViewSubjectNoReplicating)!=0U), mHasPosition((flags&_ViewSubjectHasPosition)!=0U)
 {
 	mObjectType = _ObjectTypeUndefined;
 
@@ -104,7 +113,7 @@ iViewSubject::~iViewSubject()
 void iViewSubject::Delete()
 {
 	this->ShowColorBars(false);
-	iDeletable::Delete();
+	this->iObject::Delete();
 }
 
 	
@@ -121,7 +130,7 @@ void iViewSubject::Configure()
 	}
 	else
 	{
-		IERROR_FINISH("ViewSubject has been already configured.");
+		IERROR_FATAL("ViewSubject has been already configured.");
 	}
 }
 
@@ -179,6 +188,12 @@ iDataLimits* iViewSubject::GetLimits() const
 }
 
 
+iDataSubject* iViewSubject::GetSubject() const
+{
+	return this->GetViewModule()->GetReader()->GetSubject(this->GetDataType());
+}
+
+
 void iViewSubject::SetShading(bool s)
 {
 	if(!mAlwaysShaded)
@@ -264,9 +279,17 @@ void iViewSubject::PackStateBody(iString &s) const
 	if(!mNoReplicating)
 	{
 		this->PackValue(s,KeyNumReplicas(),mNumReplicas,6);
+		bool per[3];
+		this->GetLimits()->GetPeriodicities(per);
+		this->PackValue(s,KeyDirectionIsPeriodic(),per,3);
+	}
+	if(mHasPosition)
+	{
+		this->PackValue(s,KeyAttachToMarker(),mAttachedMarkerIndex);
+		this->PackValuePosition(s,KeyPosition(),mPosition);
 	}
 	this->PackValue(s,KeyVisible(),this->IsVisible());
-	this->PackValue(s,KeyDataPresent(),this->IsDataPresent());
+	this->PackValue(s,KeyDataPresent(),this->IsThereData());
 	this->PackValue(s,KeyReady(),this->IsReady());
 
 	this->ViewSubjectPackStateBody(s);
@@ -293,6 +316,18 @@ void iViewSubject::UnPackStateBody(const iString &s)
 		if(this->UnPackValue(s,KeyNumReplicas(),d,6)) this->SetNumReplicas(d);
 	}
 
+	if(mHasPosition)
+	{
+		if(this->UnPackValuePosition(s,KeyPosition(),mPosition)) this->SetPosition(mPosition);
+		if(this->UnPackValue(s,KeyAttachToMarker(),i)) this->AttachToMarker(i);
+		//
+		//  "Action" key
+		//
+		iObject::ReportMissingKeys(false); //action keys are not part of the states
+		if(this->UnPackValue(s,KeyMoveTo(),i)) this->SetPosition(i);
+		iObject::ReportMissingKeys(true);
+	}
+
 	this->ViewSubjectUnPackStateBody(s);
 }
 
@@ -301,13 +336,20 @@ void iViewSubject::SyncWithDataBody(const iDataSyncRequest &r)
 {
 	if(this->IsUsingData(r.Data(),true))
 	{
+		//
+		//  If we are visible, but data disappeared, hide us.
+		//
 		if(this->IsVisible())
 		{
-			//
-			//  If we are visible, but data disappeared, hide us.
-			//
 			if(!this->IsReady()) this->ShowBody(false);
 		}
+		//
+		//  If data is non-periodic, remove replicas (done inside UpdateReplicas())
+		//
+		if(this->IsReplicated())
+		{
+			this->UpdateReplicas(true);
+		}
 	}
 	
 	if(this->IsUsingData(r.Data(),false))
@@ -318,11 +360,18 @@ void iViewSubject::SyncWithDataBody(const iDataSyncRequest &r)
 }
 
 
+iDataHelper* iViewSubject::CreateDataHelper(vtkDataSet *ds) const
+{
+	iDataHelper *h = new iDataHelper(ds); IERROR_ASSERT(h);
+	return h;
+}
+
+
 void iViewSubject::Show(bool s)
 {
 	if(!mIsConfigured)
 	{
-		IERROR_FINISH("ViewSubject has not been configured.");
+		IERROR_FATAL("ViewSubject has not been configured.");
 		return;
 	}
 	if(s && !mIsInitialized)
@@ -350,21 +399,42 @@ void iViewSubject::Show(bool s)
 
 bool iViewSubject::IsReady() const
 {
-	return this->CanBeShown() && this->IsDataPresent();
+	return this->CanBeShown() && this->IsThereData();
 }
 
 
-void iViewSubject::UpdateReplicas()
+void iViewSubject::UpdateReplicasBody()
 {
-	mReplicator->Update();
-
 	//
-	//  We modify objects inside pipelines, but pipelines themselves would not execute if they remain unmodified.
+	//  If data is non-periodic, remove replicas
 	//
 	int i;
-	for(i=0; i<mPipelines.Size(); i++) mPipelines[i]->UpdateContents(iViewSubjectPipeline::_Replicas);
+	bool per[3];
+	this->GetLimits()->GetPeriodicities(per);
 
-	this->ClearCache();
+	for(i=0; i<3; i++) if(!per[i])
+	{
+		mNumReplicas[2*i] = mNumReplicas[2*i+1] = 0;
+	}
+
+	//
+	//  Replicas might have changed, check that we still need to update
+	//
+	bool work = false;
+	for(i=0; !work && i<6; i++)
+	{
+		if(mOldNumReplicas[i] != mNumReplicas[i]) work = true;
+	}
+
+	if(work)
+	{
+		mReplicator->Update();
+		//
+		//  We modify objects inside pipelines, but pipelines themselves would not execute if they remain unmodified.
+		//
+		for(i=0; i<mPipelines.Size(); i++) mPipelines[i]->UpdateContents(iViewSubjectPipeline::_Replicas);
+		this->ClearCache();
+	}
 }
 
 
@@ -392,3 +462,84 @@ iViewSubjectPipeline* iViewSubject::CreatePipeline(int)
 	return 0;
 }
 
+
+void iViewSubject::AttachToMarker(int m)
+{
+	this->DetachFromMarker();
+
+	if(m>=0 && m<=this->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex())
+	{
+		mAttachedMarkerIndex = m;
+		mAttachedMarker = this->GetViewModule()->GetMarkerFamily()->GetMember(mAttachedMarkerIndex);
+		mAttachedMarker->AttachViewSubject(this);
+
+		this->SetPosition(mAttachedMarker->GetPosition(),false);
+	}
+}
+
+
+void iViewSubject::DetachFromMarker()
+{
+	if(mAttachedMarker != 0)
+	{
+		mAttachedMarker->DetachViewSubject(this);
+		mAttachedMarker = 0;
+		mAttachedMarkerIndex = -1;
+	}
+}
+
+
+void iViewSubject::UpdateAfterMarkerMove()
+{
+	if(mAttachedMarker != 0)
+	{
+		this->SetPosition(mAttachedMarker->GetPosition(),false);
+	}
+}
+
+
+void iViewSubject::SetPosition(int location, bool detach)
+{
+	switch(location)
+	{
+	case _LocationPickedPoint:
+		{
+			if(!this->GetViewModule()->GetPicker()->GetObjectName().IsEmpty())
+			{
+				this->SetPosition(this->GetViewModule()->GetPicker()->GetPosition(),detach);
+			}
+			break;
+		}
+	case _LocationFocalPoint:
+		{
+			this->SetPosition(this->GetViewModule()->GetRenderTool()->GetCamera()->GetFocalPoint(),detach);
+			break;
+		}
+	case _LocationBoxCenter:
+		{
+			iPosition p(this->GetViewModule());
+			p[0] = p[1] = p[2] = 0.0;
+			this->SetPosition(p,detach);
+			break;
+		}
+	}
+}
+
+
+void iViewSubject::SetPosition(const iPosition &p, bool detach)
+{
+	if(detach) this->DetachFromMarker();
+
+	iPosition oldPos(this->GetViewModule());
+	oldPos = mPosition;
+	mPosition = p;
+
+	this->UpdatePosition(oldPos);
+	this->ClearCache();
+}
+
+
+void iViewSubject::UpdatePosition(const iPosition &)
+{
+}
+
