@@ -171,7 +171,7 @@ namespace iHelpFactory_Private
 			pb = iHelpFactory::FindData(info.SectionTags[i],source);
 			if(pb != 0)
 			{
-				text += pb->GetExtraTag(_BeginExtraTag) + "<p><h3>" + pb->GetTitle() + "</h3><p>\n" + pb->GetHTML() + pb->GetExtraTag(_EndExtraTag);
+				text += pb->GetExtraTag(_BeginExtraTag) + "<a name=\"" + info.SectionTags[i] + "\"></a><p><h3>" + pb->GetTitle() + "</h3><p>\n" + pb->GetHTML(true) + pb->GetExtraTag(_EndExtraTag);
 				delete pb;
 			}
 		}
