@@ -29,7 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iimagefactory.h"
 
 #include "iarray.h"
-#include "idatasubject.h"
+#include "ifileloader.h"
 #include "ierror.h"
 #include "ifile.h"
 #include "iimage.h"
@@ -47,7 +47,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
-bool iImageFactory::mInitialized = false;
+bool iImageFactory::mInitialized(false);
+iImageFactoryHelper iImageFactory::mHelper;
 
 
 namespace iImageFactory_Private
@@ -103,7 +104,7 @@ namespace iImageFactory_Private
 
 	public:
 
-		List() : iOrderedArray<ListItem>(ListItem(),100)
+		List() : iOrderedArray<ListItem>(100)
 		{
 		}
 	};
@@ -133,7 +134,7 @@ namespace iImageFactory_Private
 		iFile f(outname);
 		if(!f.Open(iFile::_Write,iFile::_Text))
 		{
-			IERROR_FINISH("Unable to open output file.");
+			IERROR_FATAL("Unable to open output file.");
 		}
 
 		f.WriteLine("//LICENSE A");
@@ -147,10 +148,12 @@ namespace iImageFactory_Private
 		{
 			f.Close();
 			dir->Delete();
-			IERROR_FINISH("Unable to open images directory.");
+			IERROR_FATAL("Unable to open images directory.");
 		}
 
-		iConsole::Instance()->DisplayTextMessage("Packing images:");
+#ifdef I_DEBUG
+		iConsole::PrintDebugMessage("Packing images:");
+#endif
 
 		int i, j, nj, *d;
 		for(i=0; i<dir->GetNumberOfFiles(); i++) if(dir->GetFile(i)[0]>=sel[0] && dir->GetFile(i)[0]<=sel[1])
@@ -158,7 +161,7 @@ namespace iImageFactory_Private
 			if(tmp.LoadFromFile(dirname+"/"+dir->GetFile(i)))
 			{
 #ifdef I_DEBUG
-				iConsole::Instance()->OutputDebugMessage(dir->GetFile(i));
+				iConsole::PrintDebugMessage(dir->GetFile(i));
 #endif
 				//
 				//  Int array name
@@ -208,7 +211,7 @@ namespace iImageFactory_Private
 			tmp = new iImage;
 			if(isBigEndianMachine != isBigEndianData)
 			{
-				iDataSubject::SwapBytesRange((int *)data[i].Data,(data[i].Width*data[i].Height*data[i].Depth+sizeof(int)-1)/sizeof(int));
+				iFileLoader::SwapBytesRange((int *)data[i].Data,(data[i].Width*data[i].Height*data[i].Depth+sizeof(int)-1)/sizeof(int));
 			}
 			tmp->SetDataPointer((unsigned char *)data[i].Data,data[i].Width,data[i].Height,data[i].Depth);
 			list.Add(ListItem(data[i].Name,tmp));
@@ -236,6 +239,48 @@ namespace iImageFactory_Private
 using namespace iImageFactory_Private;
 
 
+//
+//  Helper class
+//
+iImageFactoryHelper::iImageFactoryHelper()
+{
+}
+
+
+iImageFactoryHelper::~iImageFactoryHelper()
+{
+	while(mItems.Size() > 0) delete mItems.RemoveLast().Image;
+}
+
+	
+const iImage* iImageFactoryHelper::FindImage(const iString &name)
+{
+	int i;
+	for(i=0; i<mItems.Size(); i++)
+	{
+		if(mItems[i].Name == name) return mItems[i].Image;
+	}
+
+	iImage *tmp = new iImage;
+	if(tmp == 0) return 0;
+
+	if(!tmp->LoadFromFile(name))
+	{
+		delete tmp;
+		return 0;
+	}
+
+	mItems.Add(Item());
+	mItems.Last().Image = tmp;
+	mItems.Last().Name = name;
+
+	return tmp;
+}
+
+
+//
+//  Main class
+//
 const iImage* iImageFactory::FindIcon(const iString &name)
 {
 	if(!mInitialized)
@@ -245,11 +290,7 @@ const iImage* iImageFactory::FindIcon(const iString &name)
 	}
 
 	int n = IconList().Find(ListItem(name));
-	if(n >= 0) return IconList()[n].Image; else
-	{
-		IERROR_REPORT("Missing image.");
-		return 0;
-	}
+	if(n >= 0) return IconList()[n].Image; else return mHelper.FindImage(name);
 }
 
 
@@ -262,9 +303,6 @@ const iImage* iImageFactory::FindHelpChart(const iString &name)
 	}
 
 	int n = HelpList().Find(ListItem(name));
-	if(n >= 0) return HelpList()[n].Image; else
-	{
-		return 0;
-	}
+	if(n >= 0) return HelpList()[n].Image; else return 0;
 }
 
