@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgmenuwindowsubject.h"
 
 
@@ -44,3 +48,4 @@ ibgMenuWindowSubject::~ibgMenuWindowSubject()
 {
 }
 
+#endif
