@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
   
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgrenderwindowsubject.h"
 
 
@@ -146,3 +150,4 @@ bool ibgRenderWindowSubject::IsInteractorPresent()
 	return mInteractor != 0;
 }
 
+#endif
