@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgshellsubject.h"
 
 
@@ -42,3 +46,4 @@ ibgShellSubject::~ibgShellSubject()
 {
 }
 
+#endif
