@@ -35,6 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetsubject.h"
 
 
+class iImage;
 class iString;
 
 
@@ -103,6 +104,7 @@ public:
 	virtual const iString GetText(int index = -1) const = 0;
 	virtual void SetText(const iString &text) = 0;
 	virtual void InsertItem(const iString &text, int index = -1) = 0;
+	virtual void InsertItem(const iImage &icon, const iString &text, int index = -1) = 0;
 	virtual void SetItem(const iString &text, int index, bool vis) = 0;
 	virtual void RemoveItem(int index) = 0;
 	virtual int Count() = 0;
@@ -129,6 +131,7 @@ public:
 	//  Decorator functions
 	//
 	virtual void InsertItem(const iString &text, int index = -1) = 0;
+	virtual void InsertItem(const iImage &icon, const iString &text, int index = -1) = 0;
 	virtual void SetItem(const iString &text, int index, bool vis) = 0;
 	virtual void RemoveItem(int index) = 0;
 	virtual int Count() = 0;
