@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_CL)
+
+
 #include "iclshell.h"
 
 
@@ -182,3 +186,4 @@ bool iclShell::SaveShellStateToFileBody(iFile &) const
 	return true;
 }
 
+#endif
