@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggabstractextension.h"
 
 
@@ -290,3 +294,4 @@ iggExtensionCreator::iggExtensionCreator(int n) : mId(iAbstractExtension::Define
 	iggExtensionWindow::AttachCreator(this);
 }
 
+#endif
