@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialog.h"
 
 
@@ -213,3 +217,4 @@ void iggDialog::Close()
 	if(this->CanBeClosed()) this->Show(false);
 }
 
+#endif
