@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogfilesetexplorer.h"
 
 
@@ -268,3 +272,4 @@ void iggDialogFileSetExplorer::LoadData(const iString &fname)
 	}
 }
 
+#endif
