@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogpaletteeditor.h"
 
 
@@ -446,3 +450,5 @@ bool iggDialogPaletteEditor::CanBeClosed()
 	this->Apply(true);
 	return true;
 }
+
+#endif
