@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogpickerwindow.h"
 
 
@@ -194,3 +198,5 @@ void iggDialogPickerWindow::DisplayData(const iPicker *picker)
 		mInfo->AppendTextLine("Nothing is picked.");
 	}
 }
+
+#endif
