@@ -57,6 +57,7 @@ public:
 	iggDialogScriptDebugger(iggMainWindow *parent);
 	virtual ~iggDialogScriptDebugger();
 
+	virtual void Show(bool s);
 	virtual void OnMenuBody(int id, bool on);
 
 	inline iAnimator* GetAnimator();
@@ -94,7 +95,7 @@ protected:
 
 	int mRunState, mCurIter, mNumIter, mDebugFlag;
 	float mDelayTime;
-	bool mDebugging, mAllowFrameStep, mInsideALine;
+	bool mDebugging, mAllowFrameStep, mInsideALine, mFirstShow;
 	iString mCurrentFileName;
 	iAnimator *mCurrentAnimator;
 	vtkTimerLog *mTimer;
