@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframeboxsize.h"
 
 
@@ -52,13 +56,28 @@ namespace iggFrameBoxSize_Private
 		
 	public:
 		
-		LineEdit(const iString &label, const iObjectKey &key, iggFrameBoxSize *parent) : iggWidgetKeyFloatLineEdit(label,key,_RenderModeUseGlobal,parent)
+		LineEdit(iggWidgetKeyCheckBox *cb, const iString &label, const iObjectKey &key, iggFrameBoxSize *parent) : iggWidgetKeyFloatLineEdit(label,key,_RenderModeUseGlobal,parent)
 		{
 			mRealParent = parent;
+			mCheckBox = cb;
 		}
 
 	protected:
 
+		virtual void UpdateWidgetBody()
+		{
+			bool val;
+			mCheckBox->QueryValue(val);
+			if(val)
+			{
+				this->Enable(false);
+			}
+			else
+			{
+				this->iggWidgetKeyFloatLineEdit::UpdateWidgetBody();
+			}
+		}
+
 		virtual void OnVoid1Body()
 		{
 			iggWidgetKeyFloatLineEdit::OnVoid1Body();
@@ -80,6 +99,7 @@ namespace iggFrameBoxSize_Private
 	private:
 
 		iggFrameBoxSize *mRealParent;
+		iggWidgetKeyCheckBox *mCheckBox;
 	};
 	
 
@@ -91,33 +111,13 @@ namespace iggFrameBoxSize_Private
 		CheckBox(const char* text, const iObjectKey &key, iggFrameBoxSize *parent) : iggWidgetKeyCheckBox(text,key,parent)
 		{
 			mRealParent = parent;
-			mBuddy = 0;
-		}
-
-		void SetBuddy(LineEdit *buddy)
-		{
-			mBuddy = buddy;
-			this->UpdateWidget();
-			this->UpdateBuddy();
 		}
 
 	protected:
 
-		void UpdateBuddy()
-		{
-			if(mBuddy != 0)
-			{
-				bool val;
-				this->QueryValue(val);
-				mBuddy->Enable(!val);
-				mBuddy->UpdateWidget();
-			}
-		}
-
 		virtual void OnVoid1Body()
 		{
 			iggWidgetKeyCheckBox::OnVoid1Body();
-			this->UpdateBuddy();
 			if(mRealParent != 0)
 			{
 				mRealParent->UpdatePositions();
@@ -127,9 +127,7 @@ namespace iggFrameBoxSize_Private
 	private:
 
 		iggFrameBoxSize *mRealParent;
-		LineEdit *mBuddy;
 	};
-	
 };
 
 
@@ -139,8 +137,8 @@ using namespace iggFrameBoxSize_Private;
 iggFrameBoxSize::iggFrameBoxSize(iggFrame *parent) : iggFrame("Coordinates",parent,1)
 {
 	CheckBox *cb = new CheckBox("Use OpenGL coordinates",iViewModule::KeyOpenGLCoordinates(),this);
-	LineEdit *le = new LineEdit("Box size",iViewModule::KeyBoxSize(),this);
-	cb->SetBuddy(le);
+	LineEdit *le = new LineEdit(cb,"Box size",iViewModule::KeyBoxSize(),this);
+	cb->AddDependent(le);
 
 	this->AddLine(cb);
 	this->AddLine(le);
@@ -158,3 +156,4 @@ void iggFrameBoxSize::UpdatePositions()
 	}
 }
 
+#endif
