@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframedatatypeselector.h"
 
 
@@ -367,3 +371,5 @@ void iggFrameDataTypeSelector::UpdateWidgetBody()
 
 	this->iggFrame::UpdateWidgetBody();
 }
+
+#endif
