@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframedatatypewidgetlist.h"
 
 
@@ -102,3 +106,4 @@ const iObjectKey& iggFrameDataTypeWidgetList::Translate(const iObjectKey &key, c
 	}
 }
 
+#endif
