@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframematerialproperties.h"
 
 
@@ -110,3 +114,5 @@ void iggFrameMaterialProperties::UpdateChildren()
 		for(i=0; i<4; i++) mSlider[i]->Enable(b);
 	}
 }
+
+#endif
