@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframepaletteselection.h"
 
 
@@ -81,3 +85,4 @@ int iggFramePaletteSelection::GetCurrentPaletteIndex() const
 	return mDummy->GetValue();
 }
 
+#endif
