@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframepaletteselectionbase.h"
 
 
@@ -97,7 +101,12 @@ namespace iggFramePaletteSelectionBase_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			this->Enable(mFrame->GetCurrentPaletteIndex() != 0);
+			if(mFrame->GetCurrentPaletteIndex() != 0)
+			{
+				this->Enable(true);
+				this->SetChecked(mFrame->GetCurrentPaletteIndex() < 0);
+			}
+			else this->Enable(false);
 		}
 
 		virtual void OnChecked(bool s)
@@ -248,3 +257,4 @@ iPalette* iggFramePaletteSelectionBase::GetCurrentPalette() const
 	return this->GetShell()->GetControlModule()->GetPalette(iMath::Abs(this->GetCurrentPaletteIndex())-1);
 }
 
+#endif
