@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggmainwindow.h"
 
 
@@ -393,7 +397,7 @@ namespace iggMainWindow_Private
 				data = dataM;
 				n = sizeof(dataM)/sizeof(Entry);
 			}
-			if(this->GetShell()->GetControlModule()->QueryValue(iAnimator::KeyMode(),i) && i==4)
+			if(this->GetShell()->GetControlModule()->QueryValue(iAnimator::KeyStyle(),i) && i==4)
 			{
 				data = dataC;
 				n = sizeof(dataC)/sizeof(Entry);
@@ -2316,7 +2320,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				if(!mStateFileName.IsEmpty())
 				{
 					bool ok = true;
-					if(iFile::IsWritable(mStateFileName))
+					if(iFile::IsReadable(mStateFileName))
 					{
 						if(this->PopupWindow("Do you want to overwrite the existing file?",iggParameter::_PopupWindowWarning,"Ok","Cancel") == 1) ok = false;
 					}
@@ -2993,3 +2997,5 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 		IERROR_LOW("Invalid menu item id.");
 	}
 }
+
+#endif
