@@ -26,17 +26,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpagedata.h"
 
 
 #include "ibasicdatasubjects.h"
+#include "icalculator.h"
 #include "icontrolmodule.h"
 #include "idata.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatastretch.h"
 #include "ierror.h"
-#include "iexpressionparser.h"
 #include "iimagefactory.h"
 #include "ishell.h"
 #include "iviewmodule.h"
@@ -71,6 +75,7 @@ using namespace iParameter;
 //  Templates
 //
 #include "iarraytemplate.h"
+#include "icalculatortemplate.h"
 #include "iggreloadingtemplate.h"
 #include "iggwidgetkeylineedittemplate.h"
 #include "iggwidgetkeyslidertemplate.h"
@@ -81,33 +86,6 @@ namespace iggPageData_Private
 	//
 	//  Helper widgets
 	//
-	class KeyArea : public iggWidgetKeyHandler<iString>
-	{
-		
-	public:
-		
-		KeyArea(const iObjectKey &key, iggFrame *parent, int index) : iggWidgetKeyHandler<iString>(_WidgetTypeOther,key,_RenderModeNoRender,parent,index,0)
-		{
-			mSubject = iggSubjectFactory::CreateWidgetDisplayAreaSubject(this,"");
-			mNeedsBaloonHelp = false;
-		}
-
-	protected:
-
-		virtual void QueryValue(iString &val) const
-		{
-			IERROR_LOW("This function should never be called.");
-		}
-
-		virtual void UpdateValue(iString val)
-		{
-			mSubject->SetText(val);
-		}
-
-		ibgWidgetDisplayAreaSubject *mSubject;
-	};
-
-
 	class LimitsExpandButton : public iggWidgetSimpleButton
 	{
 		
@@ -119,7 +97,28 @@ namespace iggPageData_Private
 			mOut = out;
 			mIndex = index;
 
-			if(out) mSubject->SetIcon(*iImageFactory::FindIcon("expand.png")); else mSubject->SetIcon(*iImageFactory::FindIcon("contract.png"));
+			if(min)
+			{
+				if(out)
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("range_ol.png"));
+				}
+				else
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("range_il.png"));
+				}
+			}
+			else
+			{
+                if(out)
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("range_or.png"));
+				}
+				else
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("range_ir.png"));
+				}
+			}
 
 			mNeedsBaloonHelp = false;
 		}
@@ -609,17 +608,19 @@ namespace iggPageData_Private
 
 			if(mText.IsEmpty())
 			{
-				if(line.Part(line.Length()-6) == "Vector")
+				if(line.IsEmpty()) return;
+
+				if(line.Length()>2 && line.Part(line.Length()-3)=="Vec")
 				{
 					//
-					//  Remove 'Vector'
+					//  Remove 'Vec'
 					//
-					line = line.Part(0,line.Length()-6);
+					line = line.Part(0,line.Length()-3);
 				}
-				else if(line.Part(line.Length()-4,3) == "Var")
+				else if(line.Length()>3 && line.Part(line.Length()-4)=="Var[")
 				{
 					//
-					//  Remove 'Var#'
+					//  Remove 'Var['
 					//
 					line = line.Part(0,line.Length()-4);
 				}
@@ -661,38 +662,36 @@ namespace iggPageData_Private
 		{
 			mLineEdit = le;
 
-			mParser = iExpressionParser::New(); IERROR_ASSERT(mParser);
-
-			mParser->SetScalarVariableValue("Var1",1.0);
-			mParser->SetScalarVariableValue("Var2",1.0);
-			mParser->SetScalarVariableValue("Var3",1.0);
-			mParser->SetVectorVariableValue("Vector",0.0,0.0,0.0);
-
 			mCalculatorLineEdit = new CalculatorLineEdit(mFrame);
 			mFrame->AddLine(mCalculatorLineEdit,2);
 
-			iggFrame *f1 = new iggFrame(mFrame,4);
+			iggFrame *f1 = new iggFrame(mFrame,6);
 			f1->AddLine(
-                new CalculatorButton("Variable 1","Var1",mCalculatorLineEdit,f1),
-				new CalculatorButton("Variable 2","Var2",mCalculatorLineEdit,f1),
-				new CalculatorButton("Variable 3","Var3",mCalculatorLineEdit,f1),
-				new CalculatorButton("Vector field","Vector",mCalculatorLineEdit,f1));
+                new CalculatorButton("+","+",mCalculatorLineEdit,f1),
+				new CalculatorButton("-","-",mCalculatorLineEdit,f1),
+				new CalculatorButton("x","*",mCalculatorLineEdit,f1),
+				new CalculatorButton("/","/",mCalculatorLineEdit,f1),
+				new CalculatorButton("^","^",mCalculatorLineEdit,f1),0);
+			f1->SetColStretch(5,10);
 			mFrame->AddLine(f1,2);
 
-			iggFrame *f2 = new iggFrame(mFrame,5);
-			f2->AddLine(
-                new CalculatorButton("+","+",mCalculatorLineEdit,f2),
-				new CalculatorButton("-","-",mCalculatorLineEdit,f2),
-				new CalculatorButton("x","*",mCalculatorLineEdit,f2),
-				new CalculatorButton("/","/",mCalculatorLineEdit,f2),
-				new CalculatorButton("^","^",mCalculatorLineEdit,f2));
-			mFrame->AddLine(f2,2);
+			iggFrame *f2a = new iggFrame("Variables",mFrame,3);
+			f2a->AddLine(
+				new CalculatorButton("Scalar var[#]","Var[",mCalculatorLineEdit,f2a),
+				new CalculatorButton("]","]",mCalculatorLineEdit,f2a),
+				new CalculatorButton("Vector field","Vec",mCalculatorLineEdit,f2a));
+			iggFrame *f2b = new iggFrame("Vector operations",mFrame,3);
+			f2b->AddLine(0,
+				new CalculatorButton(".",".",mCalculatorLineEdit,f2b),
+				new CalculatorButton("X","><",mCalculatorLineEdit,f2b));
+			f2b->SetColStretch(0,10);
+			mFrame->AddLine(f2a,f2b);
 
 			iggFrame *f3 = new iggFrame("",mFrame,3);
 			f3->AddLine(
                 new CalculatorButton("abs","abs(",mCalculatorLineEdit,f3),
-				new CalculatorButton("+/-","-",mCalculatorLineEdit,f3),
-				new CalculatorButton("||  ||","mag(",mCalculatorLineEdit,f3));
+				new CalculatorButton("min","min(",mCalculatorLineEdit,f3),
+				new CalculatorButton("max","max(",mCalculatorLineEdit,f3));
 			f3->AddLine(
 				new CalculatorButton("log","log(",mCalculatorLineEdit,f3),
 				new CalculatorButton("exp","exp(",mCalculatorLineEdit,f3),
@@ -734,11 +733,6 @@ namespace iggPageData_Private
 			mFrame->AddLine(f3,f4);
 		}
 
-		virtual ~CalculatorDialog()
-		{
-			mParser->Delete();
-		}
-
 		virtual void Show(bool s)
 		{
 			if(s)
@@ -762,11 +756,14 @@ namespace iggPageData_Private
 		virtual bool CanBeClosed()
 		{
 			iString line = mCalculatorLineEdit->GetText();
+			if(line.IsEmpty()) return true;
 
-			if(line.IsEmpty() || mParser->CheckSyntax(line))
+			iCalculator<float> calc;
+			iCalculator<float>::real_var var("Var",3,&calc);
+			iCalculator<float>::real_var vec("Vec",3,&calc);
+			if(calc.Evaluate(line))
 			{
-				double tmp[3];
-				if(line.IsEmpty() || mParser->GetScalarResult(tmp[0]))
+				if(calc.GetResultSize() == 1)
 				{
 					iString oldLine;
 					mLineEdit->QueryValue(oldLine);
@@ -779,29 +776,22 @@ namespace iggPageData_Private
 					}
 					return true;
 				}
-				else if(mParser->GetVectorResult(tmp))
-				{
-					mFrame->GetMainWindow()->PopupWindow("Result is a vector",_PopupWindowError);
-					return false;
-				}
 				else
 				{
-					mCalculatorLineEdit->SelectText(mParser->GetErrorPosition());
-					mFrame->GetMainWindow()->PopupWindow(mParser->GetErrorMessage(),_PopupWindowError);
+					mFrame->GetMainWindow()->PopupWindow("Result is not a scalar",_PopupWindowError);
 					return false;
 				}
 			}
 			else
 			{
-				mCalculatorLineEdit->SelectText(mParser->GetErrorPosition());
-				mFrame->GetMainWindow()->PopupWindow(mParser->GetErrorMessage(),_PopupWindowError);
+				mCalculatorLineEdit->SelectText(calc.GetErrorPosition());
+				mFrame->GetMainWindow()->PopupWindow(calc.GetErrorMessage(),_PopupWindowError);
 				return false;
 			}
 		}
 
 		iString mLine;
 		const iDataInfo &mInfo;
-		iExpressionParser *mParser;
 		iggWidgetKeyTextLineEdit *mLineEdit;
 		CalculatorLineEdit *mCalculatorLineEdit;
 	};
@@ -1139,3 +1129,4 @@ void iggPageData::OnInt1Body(int i)
 	}
 }
 
+#endif
