@@ -48,7 +48,7 @@ public:
 
 	iggFrameBook* GetBook() const { return mBook; }
 
-	void SetCurrentParticleSet(int n);
+	void SetCurrentParticles(int n);
 	void AddIcon(const iImage *image);
 
 	iViewObject* GetParticlesObject() const;
@@ -59,7 +59,7 @@ protected:
 
 private:
 
-	int mCurrentParticleSet;
+	int mCurrentParticles;
 	iArray<const iImage*> mIcons;
 };
 
