@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpagesurface.h"
 
 
@@ -621,3 +625,4 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	page3->SetColStretch(1,3);
 }
 
+#endif
