@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpagevectorfield.h"
 
 
@@ -324,3 +328,4 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageObject(par
 	page3->SetColStretch(1,3);
 }
 
+#endif
