@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpageview.h"
 
 
@@ -1101,7 +1105,7 @@ namespace iggPageView_Private
 		virtual void UpdateWidgetBody()
 		{
 			iAnimator *an = this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator();
-			this->Enable(an->GetMode() == 4);
+			this->Enable(an->GetStyle() == 4);
 			iRequiredCast<iggAnimatorEventObserver>(INFO,an->GetObserver())->AddDependent(this);
 			this->SetRange(0,this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetNumberOfCameraPathSteps()-1);
 			this->iggWidgetKeyIntSlider::UpdateWidgetBody();
@@ -1140,7 +1144,7 @@ namespace iggPageView_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			this->Enable(this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetMode() == 4);
+			this->Enable(this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetStyle() == 4);
 		}
 
 		bool mInDemo;
@@ -1350,7 +1354,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		iggWidgetKeyColorSelection *wid = new iggWidgetKeyColorSelection(iViewModule::KeyBackgroundColor(),fb3,true);
 		if(this->GetMainWindow()->GetDialogImageComposer() != 0) wid->AddDependent(this->GetMainWindow()->GetDialogImageComposer()->GetArea());
 		fb3->AddLine(wid);
-		fb3->AddLine(new iggWidgetKeyFileNameButton("Load wallpaper image","Load image","Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)",iViewModule::KeyBackgroundImage(),fb3));
+		fb3->AddLine(new iggWidgetKeyFileNameButton(" Load wallpaper image ","Load image","Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)",iViewModule::KeyBackgroundImage(),fb3));
 		fb2->AddLine(fb3);
 
 		page0->AddLine(fb,fb2);
@@ -1527,11 +1531,11 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *abpage0 = new iggFrame(ab,3);
 			ab->AddPage("Style",icon,abpage0);
 
-			iggWidgetKeyRadioBox *as = new iggWidgetKeyRadioBox(1,"Style",0,iAnimator::KeyMode(),abpage0);
+			iggWidgetKeyRadioBox *as = new iggWidgetKeyRadioBox(1,"Style",0,iAnimator::KeyStyle(),abpage0);
 			as->InsertItem("Static");
 			as->InsertItem("Rotate/scale");
 			as->InsertItem("Tumble");
-			as->InsertItem("Fly-by");
+			as->InsertItem("Flyby");
 			as->InsertItem("Camera path");
 
 			iggFrame *tmp = new iggFrame(abpage0);
@@ -1580,27 +1584,27 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *abpage1 = new iggFrame(ab,2);
 			ab->AddPage("Settings",icon,abpage1);
 
-			iggWidgetKeyFloatSlider *tmpfs = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,0,"Fly-by speed",iAnimator::KeyFlybySpeed(),_RenderModeNoRender,abpage1);
+			iggWidgetKeyFloatSlider *tmpfs = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,0,"Flyby speed",iAnimator::KeyFlybySpeed(),_RenderModeNoRender,abpage1);
 			tmpfs->SetStretch(2,10);
 			abpage1->AddLine(tmpfs);
-			tmpfs = new iggWidgetKeyFloatSlider(0.0,0.1,30,0,0,"Cross section speed",iAnimator::KeySlideSpeed(),_RenderModeNoRender,abpage1);
+			tmpfs = new iggWidgetKeyFloatSlider(0.0,0.1,30,0,0,"Cross section speed",iAnimator::KeyCrossSectionSpeed(),_RenderModeNoRender,abpage1);
 			tmpfs->SetStretch(2,10);
 			abpage1->AddLine(tmpfs);
 
 			abpage1->AddSpace(2);
 
 			iggFrame *ar = new iggFrame("Rotations",abpage1,1);
-			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Azimuth",iAnimator::KeyPhi(),_RenderModeNoRender,ar);
+			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Azimuth (phi)",iAnimator::KeyPhi(),_RenderModeNoRender,ar);
 			tmpfs->SetStretch(3,10,0);
 			ar->AddLine(tmpfs);
-			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Elevation",iAnimator::KeyTheta(),_RenderModeNoRender,ar);
+			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Elevation (theta)",iAnimator::KeyTheta(),_RenderModeNoRender,ar);
 			tmpfs->SetStretch(3,10,0);
 			ar->AddLine(tmpfs);
 			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Roll angle",iAnimator::KeyRoll(),_RenderModeNoRender,ar);
 			tmpfs->SetStretch(3,10,0);
 			ar->AddLine(tmpfs);
 			abpage1->AddLine(ar);
-			abpage1->AddLine(new iggWidgetKeyFloatSlider(0.98,1.02,400,1,5,"Scale",iAnimator::KeyZoom(),_RenderModeNoRender,abpage1));
+			abpage1->AddLine(new iggWidgetKeyFloatSlider(0.98,1.02,400,1,5,"Zoom",iAnimator::KeyZoom(),_RenderModeNoRender,abpage1));
 
 			abpage1->AddSpace(10);
 			abpage1->SetColStretch(0,10);
@@ -1921,3 +1925,4 @@ iggFrame* iggPageView::CreateFlipFrame(iggFrameBase *parent) const
 	return tmp;
 }
 
+#endif
