@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
   
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggrenderwindow.h"
 
 
@@ -452,3 +456,4 @@ void iggRenderWindow::OnCloseAttempt()
 	this->GetMainWindow()->PopupWindow(this,"Render Window can not be closed. Use window controls in the main window to delete Render Windows.");
 }
 
+#endif
