@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggshell.h"
 
 
@@ -614,3 +618,4 @@ void iggShell::OnLoadStateFileAtomBody(int prog)
 	}
 }
 
+#endif
