@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishell.h"
 
 
-class iggDialog;
+class iggDialogFlashWindow;
 class iggMainWindow;
 
 class ibgShellSubject;
@@ -50,25 +50,22 @@ class iggShell : public iShell
 
 public:
 
-	virtual ~iggShell();
+	vtkTypeMacro(iggShell,iShell);
 
 	inline iggMainWindow* GetMainWindow() const { return mMainWindow; }
 
-	virtual bool LoadShellStateFromFile(iFile &F);
-	virtual bool SaveShellStateToFile(iFile &F) const;
-
 	virtual void Exit();
 
-#ifdef I_DEBUG
-	virtual void OutputDebugMessage(const iString &message) const;
-#endif
+	bool IsDesktopSmall(bool vert) const;
 
 	void GetDesktopDimensions(int &w, int &h) const;
 	void ProcessEvents(bool sync = false);
+	bool IsWindowManagerModern() const;
 
 protected:
 
 	iggShell(const iString &type, int argc, char **argv);
+	virtual ~iggShell();
 
 	virtual void ConstructorBody();  
 	virtual void DestructorBody();  
@@ -76,25 +73,21 @@ protected:
 	virtual void Start();
 	virtual void RunBody();
 	virtual void PrepareForConstruction();
+	virtual void PrepareToLoadStateFile();
+	virtual bool LoadShellStateFromFileBody(iFile &F);
+	virtual bool SaveShellStateToFileBody(iFile &F) const;
 	virtual void DefineSpecificCommandLineOptions();
-	virtual void LoadStateFile(const iString &fname);
-	virtual void OutputStartupMessage(const iString &message);
 	virtual bool AnalyseOneExtendedCommandLineOption(const struct Option &o);
 
 	virtual void OnInitAtomBody(bool timed);
-
-#if defined(I_DEBUG) && defined(I_EDITION)
-	double mTotalTime;
-#endif
-
-	ibgShellSubject *mSubject;
-	iggMainWindow *mMainWindow;
-	iString mScriptFileName;
-	bool mShowFlashWindow, mAccept8BitDisplay, mStartDocked;
+	virtual void OnLoadStateFileAtomBody(int prog);
 
 private:
 
-	iggDialog *mFlashWindow;
+	ibgShellSubject *mSubject;
+	iggMainWindow *mMainWindow;
+	bool mShowFlashWindow, mAccept8BitDisplay, mStartDocked, mUseOldWindowManager, mSmallDesktop;
+	iggDialogFlashWindow *mFlashWindow;
 };
 
 #endif  // IGGSHELL_H
