@@ -128,6 +128,10 @@ public:
 	inline bool GetLogScale() const { return mInLog; }
 	void SetLogScale(bool s);
 
+	void SetFullResolution(bool s);
+	bool GetFullResolution() const;
+	bool SupportsFullResolution() const;
+
 	void AddExtra(iggFrameHistogramAreaExtra *extra);
 
 protected:
