@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtextensionwindowsubject.h"
 
 
@@ -142,3 +146,5 @@ void iqtExtensionWindowSubject::closeEvent(QCloseEvent *e)
 	e->ignore();
 	mExtensionWindow->OnCloseAttempt();
 }
+
+#endif
