@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtmainwindowsubject.h"
 
 
@@ -435,3 +439,4 @@ void iqtMainWindowSubject::closeEvent(QCloseEvent *e)
 	mMainWindow->Exit();
 }
 
+#endif
