@@ -56,7 +56,7 @@ class iqtRenderWindowSubject : public QGLWidget, public ibgRenderWindowSubject
 
 public:
 
-	void AttachToParent(QWidget *parent);
+	void AttachToParent(QWidget *parent, bool border = true);
 
 protected:
 
@@ -70,6 +70,7 @@ protected:
 	virtual void Render();
 	virtual void SwapBuffers();
 
+	virtual void SetBorder(bool);
 	virtual void SetFullScreen(bool);
 	virtual void MakeCurrent();
 
@@ -98,10 +99,10 @@ protected:
 	virtual void paintGL();
 	virtual void resizeGL(int w, int h);
 
-	virtual void mouseMoveEvent(QMouseEvent *);
-	virtual void mousePressEvent(QMouseEvent *);
-	virtual void mouseReleaseEvent(QMouseEvent *);
-	virtual void keyPressEvent(QKeyEvent *);
+	virtual void mouseMoveEvent(QMouseEvent *e);
+	virtual void mousePressEvent(QMouseEvent *e);
+	virtual void mouseReleaseEvent(QMouseEvent *e);
+	virtual void keyPressEvent(QKeyEvent *e);
 
 	//
 	// Every focus-in and focus-out event results in a repaint 
