@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtshellsubject.h"
 
 
@@ -154,3 +158,4 @@ bool iqtShellSubject::IsWindowManagerModern() const
 	return true;  // seems not possible to discover from Qt?
 }
 
+#endif
