@@ -52,23 +52,18 @@ protected:
 	//  System-level operations
 	//
 	virtual void GetDesktopDimensions(int &w, int &h) const;
-	virtual void OutputStartupMessage(const iString &message);
 	virtual void ProcessEvents(bool sync);
 	virtual void CompleteStartUp();
 	virtual void EnterEventLoop();
 	virtual void Exit();
 
-#ifdef I_DEBUG
-	virtual void OutputDebugMessage(const iString &message) const;
-#endif
-
 	//
 	//  Shell capabilities
 	//
 	virtual bool CanRecognize8BitDisplay(bool check = false) const;
 	virtual bool CanDockWindows() const;
 	virtual bool CanChangeFontSize() const;
-	virtual bool CanRenderOffScreen() const;
+	virtual bool IsWindowManagerModern() const;
 };
 
 #endif  // IQTSHELLSUBJECT_H
