@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwindowhelper.h"
 
 
@@ -164,3 +168,4 @@ void iqtWindowHelper::ShowAsWindow()
 	}
 }
 
+#endif
